@@ -20,17 +20,23 @@
 #ifndef ___M_NETUTILS_H___
 #define ___M_NETUTILS_H___
 
+#include	<netdb.h>
 
-struct hostent {
+struct hostent_ext {
+
+#ifdef NON_UNIVERSAL
 	char h_name[256];  /* official name of host */
 	char *h_aliases[1];   /* alias list (always set to be 0) */
 	int  h_addrtype;    /* host address type */
 #define AF_INET 2
 	int  h_length; /* length of address */
 	char h_addr_list[1][4]; /* list of addresses from name server */
-	
+#endif
+
+	struct hostent d;
 	struct hostent *next;
 };
+
 #define   h_addr  h_addr_list[0]   /* address, for backward compatibility */
 
 #if !__MACH__
