@@ -26,17 +26,17 @@ extern "C"  {
 
 class VCustomizedMenuBarImp {
   public:
-	static void	switch_to_menu(VCustomizedMenuBar *bar);
+	static void	switch_to_menu(VCustomizedMenuBar *bar, bool window_menu_flag);
 	static void update_window_menu();
 
   protected:
 	static void	install_menu_items(VMenuItem *items);
 	static void	install_menu_items_sub(VMenuItem *items, LMenu *lm);
 
-	static void	remove_current_menu_items();
+	static void	remove_current_menu_items(VMenuItem*);
 	static void	remove_current_menu_items_sub(VMenuItem *items);
 
-	static void setup_window_menu(VMenuItem *items);
+	static void setup_window_menu(VMenuItem *items, bool window_menu_flag);
 
 };
 
