@@ -52,7 +52,7 @@ typedef struct connect_t {
 	int			len;
 	int			ret;
 	int			err;
-	int			tid;
+	CHIMERA_HTID		tid;
 } CONNECT_T;
 
 typedef struct connect_list {
@@ -86,6 +86,7 @@ CONNECT_T * arg;
 			do_connect_waiting_cnt --;
 		}
 		arg = connect_t_head;
+		arg->tid = _chimera_get_tid();
 		connect_t_head = arg->next;
 		if ( connect_t_head == 0 )
 			connect_t_tail = 0;
@@ -129,8 +130,8 @@ void
 timeout_connect(CONNECT_T * c)
 {
 	lock_task(stream_lock);
-	if ( c->tid >= 0 )
-		throw_signal(c->tid,SIGUSR1);
+	if ( c->tid.valid )
+		pthread_kill((pthread_t)c->tid.tid, SIGUSR1);
 	unlock_task(stream_lock,"timeout_connect");
 }
 
@@ -225,7 +226,7 @@ retry:
 		perror("Error(clinet): can't bind\n");
 		con_err = 3;
 
-		close(id);
+		secure_close(id);
 		if ( func )
 			(*func)(1,work);
 		*cerr = errno;
@@ -244,7 +245,8 @@ con_retry:
 	c.id = id;
 	c.server = (struct sockaddr*)&server;
 	c.len = len;
-	c.tid = get_tid();
+	c.tid.tid = -1;
+	c.tid.valid = 0;
 
 	new_tick((void(*)(int))timeout_connect,-2*CON_TIMEOUT,(int)&c);
 
@@ -254,7 +256,8 @@ con_retry:
 
 	lock_task(stream_lock);
 	c.id = -1;
-	c.tid = -1;
+	c.tid.tid = -1;
+	c.tid.valid = 0;
 	unlock_task(stream_lock,"connect");
 
 	wd_ret = wait_data_unlock(ent);
@@ -266,7 +269,7 @@ con_retry:
 		if ( ft.err ) {
 
 			if ( wd_ret == 0 )
-				close(id);
+				secure_close(id);
 			goto retry;
 		}
 		if ( c.err != ECONNREFUSED ) {
@@ -278,7 +281,7 @@ con_retry:
 				con_err = 4;
 				*cerr = ESYS_CTIMEOUT;
 				if ( wd_ret == 0 )
-					close(id);
+					secure_close(id);
 				goto err2;
 			}
 			if ( wd_ret ) {
@@ -292,7 +295,7 @@ con_retry:
 		con_err = 5;
 
 		if ( wd_ret == 0 )
-			close(id);
+			secure_close(id);
 		if ( func )
 			(*func)(1,work);
 		*cerr = c.err;
@@ -305,7 +308,7 @@ con_retry:
 
 	runlock_fork(&ft);
 	if ( ft.err ) {
-		close(id);
+		secure_close(id);
 		goto retry;
 	}
 ok:
