@@ -34,7 +34,7 @@
 #include	"utils.h"
 #include	"machine/chimera.h"
 #include	"machine/err.h"
-
+#include	"pri_level.h"
 
 int pri_table[PRI_MAX] = {0,10,20,30,40,50};
 
@@ -61,6 +61,31 @@ int i = 0;
 	return s;
 }
 
+CHIMERA_HTID
+_chimera_get_tid()
+{
+CHIMERA_HTID ret;
+	ret.tid = (int)pthread_self();
+	ret.valid = 1;
+	return ret;
+}
+
+int
+chimera_get_tid()
+{
+CHIMERA_HTID ret;
+	ret = _chimera_get_tid();
+	return ret.tid;
+}
+
+CHIMERA_HTID
+chimera_get_hart_tid(int tid)
+{
+CHIMERA_HTID ret;
+	ret.tid = tid;
+	ret.valid = 1;
+	return ret;
+}
 
 void
 chimera_lock_task(CHIMERA_SEM s,char * file,int line)
@@ -74,7 +99,7 @@ retry:
 	}
 	s->lock_file = file;
 	s->lock_line = line;
-	s->lock_htid = _get_tid();
+	s->lock_htid = _chimera_get_tid();
 }
 
 void
@@ -83,7 +108,7 @@ chimera_unlock_task(CHIMERA_SEM s,char *str,char * file,int line)
 int er;
 	s->unlock_file = file;
 	s->unlock_line = line;
-	s->unlock_htid = _get_tid();
+	s->unlock_htid = _chimera_get_tid();
 	
 	er = 1;
 	for ( ; er ; ) {
@@ -197,3 +222,82 @@ int policy;
 	}
 	return ret;
 }
+
+typedef struct do_t {
+	struct do_t *		next;
+	unsigned		finish_flag:1;
+	int			err;
+	int			tid;
+	void *			arg;
+	void			(*func)(void*);
+} DO_T;
+
+
+int do_waiting_cnt;
+DO_T * do_t_head,*do_t_tail;
+extern CHIMERA_SEM task_lock;
+
+
+
+
+void
+chimera_do_task(TKEY a)
+{
+DO_T * d;
+
+	chimera_lock_task(task_lock,__FILE__,__LINE__);
+	do_waiting_cnt --;
+	for ( ; ; ) {
+		for ( ; do_t_head == 0 ; ) {
+			if ( do_waiting_cnt ) {
+				chimera_unlock_task(task_lock,"connect",__FILE__,__LINE__);
+				return;
+			}
+			do_waiting_cnt ++;
+			chimera_sleep_task((int)&do_t_head,task_lock,0);
+			chimera_lock_task(task_lock,__FILE__,__LINE__);
+			do_waiting_cnt --;
+		}
+		d = do_t_head;
+		do_t_head = d->next;
+		if ( do_t_head == 0 )
+			do_t_tail = 0;
+		chimera_unlock_task(task_lock,"connect",__FILE__,__LINE__);
+		
+		errno = 0;
+		(*d->func)(d->arg);
+		d->err = errno;
+		d->finish_flag = 1;
+		normal_wakeup_task((int)d,1);
+
+
+		chimera_lock_task(task_lock,__FILE__,__LINE__);
+	}
+}
+
+
+void
+chimera_do(void (*func)(void*),void * arg)
+{
+DO_T d;
+	d.finish_flag = 0;
+	d.arg = arg;
+	d.func = func;
+	d.err = 0;
+	chimera_lock_task(task_lock,__FILE__,__LINE__);
+	if ( do_waiting_cnt == 0 ) {
+		chimera_create_task(chimera_do_task,0,PRI_FETCH);
+		do_waiting_cnt ++;
+	}
+	d.next = 0;
+	if ( do_t_head ) {
+		do_t_tail->next = &d;
+		do_t_tail = &d;
+	}
+	else	do_t_head = do_t_tail = &d;
+	chimera_wakeup_task((int)&do_t_head,0);
+	chimera_unlock_task(task_lock,"chimera_do",__FILE__,__LINE__);
+	for ( ; d.finish_flag == 0 ; )
+		sleep_task((int)&d,SEM_NULL);
+}
+
