@@ -247,7 +247,7 @@ int er;
 	id = (int)GET_TKEY(d);
 
 c_retry:
-	er = close(id);
+	er = secure_close(id);
 	if ( er < 0 && errno == EINTR )
 		goto c_retry;
 }
