@@ -65,6 +65,27 @@ int		len;
 	return ret;
 }
 
+char *
+get_path_from_mac_fs_alloc(FSSpec inMacFSSpec, Boolean isFolder)
+{
+char	*ret = 0;
+FSRef	ref;
+int		len;
+
+	if( FSpMakeFSRef(&inMacFSSpec, &ref) == noErr ) {
+		ret = (char*)malloc(1025);
+		if ( FSRefMakePath(&ref, ret, 1024) == noErr ) {
+			len = strlen(ret);
+			if ( isFolder && ret[len-1] != '/' ) {
+				ret[len++] = '/';
+				ret[len] = 0;
+			}
+		}
+	}
+	return ret;
+}
+
+
 char *
 get_peripheral_path()
 {
@@ -123,6 +144,38 @@ unsigned char * name;
 	}
 }
 
+char *
+get_path_from_mac_fs_alloc(FSSpec inMacFSSpec, Boolean isFolder)
+{
+char *ret, buf[1024], *ptr;
+unsigned char * name;
+
+	ptr = buf+sizeof(buf)-1;
+	*ptr = 0;
+	if ( isFolder ) {
+		ptr--;
+		*ptr = ':';
+	}
+	for ( ; ; ) {
+		name = inMacFSSpec.name;
+		ptr -= name[0]+1;
+		if ( ptr < buf )
+			er_panic("get_path_from_mac_fs buffer under error");
+		memcpy(ptr+1, name+1, name[0]);
+		if ( inMacFSSpec.parID != fsRtParID ) {
+			*ptr = ':';
+		} else {
+			ret = malloc(buf+sizeof(buf)-ptr-1);
+			strcpy(ret,ptr+1);
+			return ret;
+		}
+		if ( noErr != FSMakeFSSpec(inMacFSSpec.vRefNum, 
+					inMacFSSpec.parID, "\p", &inMacFSSpec) ) 
+			er_panic("get_path_from_mac_fs");
+	}
+}
+
+
 
 char *
 get_peripheral_path()
