@@ -36,7 +36,7 @@ int
 u_close(int fd)
 {
 force_scheduling();
-	return close(fd);
+	return secure_close(fd);
 }
 
 int
