@@ -58,7 +58,7 @@ int fd;
 			p1 = p3;
 			continue;
 		}
-		close(fd);
+		secure_close(fd);
 		buf[path_len] = 0;
 		goto end;
 	}
