@@ -33,6 +33,7 @@ public:
 	
 	void			SetupMenu(LMenu *menu);
 	void			UpdateMenu();
+	void			SetEnabled(bool enabled) { menuEnabled = enabled; }
 	
 	static CWindowMenuAttachment *	GetMain() { return sMain; }
 	
@@ -50,6 +51,7 @@ protected:
 	
 	UInt16	num, first;
 	static CWindowMenuAttachment *sMain;
+	bool menuEnabled;
 };
 
 #endif
\ No newline at end of file
