@@ -56,7 +56,7 @@ int i;
 	
 printf("Making Font Table...");
 fflush(stdout);
-	lock_task(app_lock);
+	int al_stk = get_app_lock();
 	FMCreateFontFamilyIterator(NULL, NULL, 0, &fi);
 	while ( FMGetNextFontFamily(&fi, &family) != kFMIterationCompleted ) {
 		VFONT_LIST *list = d_alloc(sizeof(VFONT_LIST));
@@ -82,7 +82,7 @@ fflush(stdout);
 	FMDisposeFontFamilyIterator(&fi);
 	for ( i = 0 ; mac_script_tbl[i].script != -1 ; i ++ )
 		sc_tbl[mac_script_tbl[i].script] = &mac_script_tbl[i];
-	unlock_task(app_lock,"");
+	release_app_lock(al_stk);
 printf("done\n");
 }
 
