@@ -66,7 +66,7 @@ typedef struct {
 #define V_WINDOW_MIN_HEIGHT	50
 
 #define _V_OP_START(err) {	\
-	lock(this,__FILE__,__LINE__);	\
+	lock(this,(char*)__FILE__,__LINE__);	\
 	if ( destroy_time != V_OBJECT_ALIVE ) {	\
 		unlock(this);	\
 		return err;	\
@@ -74,7 +74,7 @@ typedef struct {
 }
 
 #define _V_OP_START_VOID {	\
-	lock(this,__FILE__,__LINE__);	\
+	lock(this,(char*)__FILE__,__LINE__);	\
 	if ( destroy_time != V_OBJECT_ALIVE ) {	\
 		unlock(this);	\
 		return;	\
@@ -86,7 +86,7 @@ typedef struct {
 
 
 #define _V_OP_START_EX(c) \
-	lock(this,__FILE__,__LINE__);	\
+	lock(this,(char*)__FILE__,__LINE__);	\
 	if ( destroy_time != V_OBJECT_ALIVE ) {	\
 	VExError er;				\
 		er.code = c;			\
@@ -103,7 +103,7 @@ typedef struct {
 
 #ifdef __cplusplus
 extern "C" void exec_in_gtk_main(void(*func)(void*), void *arg);
-extern "C" int ms_do(int (*func)(void*), void * arg,int, char str[]);
+extern "C" int ms_do(int (*func)(void*), void * arg,int,const  char str[]);
 #define V_SERIALIZED_EXEC(func, arg)  exec_in_gtk_main((void(*)(void*))func, arg)
 #else
 int ms_do(int (*func)(void*), void * arg,int, char str[]);
@@ -171,7 +171,9 @@ v_serialized_exec_func(g_signal_connect_data,	\
 
 #define RGB8_MAX	255
 
-
+#define MENU_ITEM_INHERIT
+#define vq_insert_callback_machine(object,handler,usr_arg,sys_arg,sys_arg_size,skey,inherit) \
+	xx_vq_insert_callback((object),handler,(usr_arg),(sys_arg),(sys_arg_size),(skey),__FILE__,__LINE__)
 
 // MACHINE DEPENDENT CONSTANTS & PROTOTYPES
 
