@@ -34,6 +34,13 @@ struct hostent *
 gethostbyname_r(const char *hostname, struct hostent *dest,
 		void *buf, size_t buf_size, int *error);
 
+#define CW_ACTIVE	0
+#define CW_LAST_INVOKE_INTERVAL 60
+#define CW_TH		20
+#define CW_PITCH	10
+#define CW_INTERVAL	2
+
+
 #endif
 
 
