@@ -32,9 +32,12 @@ init_thread_block()
 {
 int i;
 D_SEM s;
+pthread_mutexattr_t attr;
 	s = &tb[0].sem;
-	s->s = new_semaphore();
-	s->value = 1;
+	pthread_mutexattr_init(&attr);
+	pthread_mutexattr_settype(&attr,PTHREAD_MUTEX_ERRORCHECK);
+	pthread_mutex_init(&s->mx,&attr);
+	pthread_mutexattr_destroy(&attr);
 	block_lock = s;
 	_lock_task(block_lock,__FILE__,__LINE__);
 	for ( i = 1 ; i < THREAD_BLOCK_SIZE ; i ++ ) {
