@@ -26,7 +26,7 @@
 typedef struct _sem {
 	HTID		tid;
 	int		value;
-	sem_t *		s;
+	pthread_mutex_t		mx;
 
 	char *		lock_file;
 	int		lock_line;
