@@ -32,19 +32,19 @@ int ret;
 	pipe(p);
 	id = fork();
 	if ( id == 0 ) {
-		close(1);
+		secure_close(1);
 		dup(p[1]);
-		close(p[0]);
+		secure_close(p[0]);
 		for ( id = 3 ; id <= sys_param.max_fd ; id ++ )
-			close(id);
+			secure_close(id);
 	      /*system("uname -X | egrep NumCPU");*/
                 system("cat /proc/cpuinfo | egrep processor");
 		exit(0);
 	}
-	close(p[1]);
+	secure_close(p[1]);
 	/*er = read(p[0],buf,100);*/
         er = 1 + read(p[0],buf,100);
-	close(p[0]);
+	secure_close(p[0]);
 	if ( er < 0 )
 		return 1;
 	buf[er] = 0;
