@@ -27,5 +27,12 @@
 #define stat64_t	stat64
 #define WAT_DEFAULT_INTERVAL	10
 
+#define CW_ACTIVE	0
+#define CW_LAST_INVOKE_INTERVAL 60
+#define CW_TH		20
+#define CW_PITCH	10
+#define CW_INTERVAL	2
+
+
 #endif
 
