@@ -47,7 +47,7 @@ char filename[100];
 		return -1;
 	}
 	ret = info.pr_size;
-	close(fd);
+	secure_close(fd);
 	return ret*1024; 
 }
 
