@@ -169,7 +169,7 @@ retry:
 		perror("Error(clinet): can't bind\n");
 		con_err = 3;
 
-		close(id);
+		secure_close(id);
 		if ( func )
 			(*func)(1,work);
 		*cerr = errno;
@@ -214,7 +214,7 @@ printf("server_addr %x\n",ntohl(server.sin_addr.s_addr));
 		if ( ft.err ) {
 
 			if ( wd_ret == 0 )
-				close(id);
+				secure_close(id);
 			goto retry;
 		}
 		if ( c.err != ECONNREFUSED &&
@@ -230,7 +230,7 @@ printf("server_addr %x\n",ntohl(server.sin_addr.s_addr));
 				con_err = 4;
 				*cerr = ESYS_CTIMEOUT;
 				if ( wd_ret == 0 )
-					close(id);
+					secure_close(id);
 				goto err2;
 			}
 			if ( wd_ret ) {
@@ -244,7 +244,7 @@ printf("server_addr %x\n",ntohl(server.sin_addr.s_addr));
 		con_err = 5;
 
 		if ( wd_ret == 0 )
-			close(id);
+			secure_close(id);
 		if ( func )
 			(*func)(1,work);
 		*cerr = c.err;
@@ -257,7 +257,7 @@ printf("server_addr %x\n",ntohl(server.sin_addr.s_addr));
 
 	runlock_fork(&ft);
 	if ( ft.err ) {
-		close(id);
+		secure_close(id);
 		goto retry;
 	}
 ok:
