@@ -55,13 +55,13 @@ char * dm;
 				dmp ++);
 		*dmp = 0;
 		dm = d_re_alloc(dm,strlen(dm)+1);
-		fclose(fd);
+		secure_fclose(fd);
 		dm_static = dm;
 		return dm;
 	}
 	if ( dm )
 		d_f_ree(dm);
-	fclose(fd);
+	secure_fclose(fd);
 	dm_static = 0;
 	return 0;
 }
