@@ -27,7 +27,7 @@
 HTID (*get_tid_ptr)();
 
 void
-er_panic(char * str)
+er_panic(const char * str)
 {
 	fprintf(stderr,"\n************\n%s (%i)\n************\n",str,
 		(int)getpid());
@@ -44,7 +44,7 @@ er_panic(char * str)
 }
 
 void
-er_panic_x(char * str)
+er_panic_x(const char * str)
 {
 	er_panic(str);
 }
