@@ -42,7 +42,7 @@ int er;
 	if ( id == 0 ) {
 		for ( i = 1 ; i <= sys_param.max_fd ; i ++  ) {
 		p1:
-			er = close(i);
+			er = secure_close(i);
 			if ( er < 0 && errno == EINTR )
 				goto p1;
 		}
