@@ -38,7 +38,7 @@ int er;
 	if ( id == 0 ) {
 		for ( i = 3 ; i <= max_fid ; i ++  ) {
 		p1:
-			er = close(i);
+			er = secure_close(i);
 			if ( er < 0 && errno == EINTR )
 				goto p1;
 		}
