@@ -152,7 +152,7 @@ retry:
 		/* child process */
 
 	p1:
-		cer = close(p[1]);
+		cer = secure_close(p[1]);
 		if ( cer < 0 && errno == EINTR )
 			goto p1;
 		if ( cer < 0 && (errno == EIO || errno == ENOSPC) ) {
@@ -167,7 +167,7 @@ retry:
 		for ( i = 3 ; i <= sys_param.max_fd ; i ++ )
 			if ( fp[i] == 0 ) {
 			p2:
-				cer = close(i);
+				cer = secure_close(i);
 				if ( cer < 0 && errno == EINTR )
 					goto p2;
 			}
@@ -176,7 +176,7 @@ retry:
 			perror("launch");
 		}
 	p3:
-		cer = close(p[0]);
+		cer = secure_close(p[0]);
 		if ( cer < 0 && errno == EINTR )
 			goto p3;
 		if ( cer < 0 && (errno == EIO || errno == ENOSPC) ) {
@@ -195,7 +195,7 @@ retry:
 	}
 	ret_errno = errno;
 p4:
-	cer = close(p[0]);
+	cer = secure_close(p[0]);
 	if ( cer < 0 && errno == EINTR )
 		goto p4;
 	if ( cer < 0 && (errno == EIO || errno == ENOSPC) ) {
@@ -212,7 +212,7 @@ p4:
 			write(*_stpfd,ret_str_parent,slen);
 		if ( *cf ) {
 		p5:
-			cer = close(*_stpfd);
+			cer = secure_close(*_stpfd);
 			if ( cer < 0 && errno == EINTR )
 				goto p5;
 		}
@@ -228,7 +228,7 @@ p4:
 
 	if ( id == -1 ) {
 	p6:
-		cer = close(p[1]);
+		cer = secure_close(p[1]);
 		if ( cer < 0 && errno == EINTR )
 			goto p6;
 		d_f_ree(fp);
@@ -244,7 +244,7 @@ p4:
 	if ( errno )
 		printf("write %i\n",errno);
 p7:
-	cer = close(p[1]);
+	cer = secure_close(p[1]);
 	if ( cer < 0 && errno == EINTR )
 		goto p7;
 	if ( cer < 0 && (errno == EIO || errno == ENOSPC) ) {
