@@ -109,8 +109,8 @@ s_close_fpipe(STREAM * s)
 PIPE_READ_BUF * b;
 	wakeup_task((int)s);
 	_s_close_sync(s);
-	close(s->fpipe.fid_read);
-	close(s->fpipe.fid_write);
+	secure_close(s->fpipe.fid_read);
+	secure_close(s->fpipe.fid_write);
 	for ( ; s->fpipe.head ; ) {
 		b = s->fpipe.head;
 		s->fpipe.head = b->next;
