@@ -47,7 +47,7 @@ int cw_th = CW_TH;
 //int cw_pitch = CW_PITCH;
 int cw_interval = CW_INTERVAL;
 int cw_task_count;
-int cw_th_count;
+int cw_th_count = CW_TH;
 INTEGER64 cw_th_time;
 
 #define DTI_LENGTH		10000
@@ -678,6 +678,10 @@ int er;
 		b.finish_time = get_xltime();
 	re_sleep:
 		cw_task_count --;
+/*
+printf("wait the create grue %i %i %i %i\n",
+task_cnt,cw_task_count,cw_th,cw_th_count);
+*/
 		if ( create_wait_head )
 {
 //printf("_create_wait_task gure ---- wakeup\n");
@@ -712,7 +716,7 @@ void
 _create_wait_task()
 {
 INTEGER64 now;
-CREATE_WAIT * cw;
+//CREATE_WAIT * cw;
 INTEGER64 last_invoke;
 //printf("_create_wait_task start\n");
 	for ( ; ; ) {
@@ -723,6 +727,7 @@ INTEGER64 last_invoke;
 			_unlock_task(task_lock,"create_wait_task",__FILE__,__LINE__);
 			break;
 		}
+/*
 		for ( cw = create_wait_head ; cw ; cw = cw->next ) {
 			if ( now - cw->ins_time < cw_interval )
 				break;
@@ -732,8 +737,16 @@ INTEGER64 last_invoke;
 			cw_th_time = now;
 			last_invoke = now;
 		}
+*/
+		if ( create_wait_head && (now - create_wait_head->ins_time > cw_interval ) )
+		{
+			t_wakeup_task((int)create_wait_head,0);
+			cw_th_count ++;
+			cw_th_time = now;
+			last_invoke = now;
+		}
 		_unlock_task(task_lock,"create_wait_task",__FILE__,__LINE__);
-		sleep_sec(1);
+		sleep_sec(cw_interval);
 	}
 //printf("_create_wait_task end\n");
 }
@@ -765,7 +778,11 @@ retry:
 		t_wakeup_task((int)b,0);
 	}
 	else {
-
+/*
+printf("wait the create 1(%s %i) %i %i %i %i\n",
+__f,__l,
+task_cnt,cw_task_count,cw_th,cw_th_count);
+*/
 		if ( cw_active == 1 && retry_cnt == 0 && cw_task_count > cw_th_count ) {
 			if ( get_xltime() - cw_th_time > cw_last_invoke_interval ) {
 				cw_th_count --;
@@ -774,7 +791,6 @@ retry:
 				if ( cw_th_count < cw_th )
 					cw_th_count = cw_th;
 			}
-//printf("wait the create 1 %i %p\n",task_cnt,&cw);
 			cw.next = 0;
 			cw.ins_time = get_xltime();
 			if ( create_wait_head == 0 ) {
@@ -788,15 +804,29 @@ retry:
 				create_wait_tail->next = &cw;
 				create_wait_tail = &cw;
 			}
+		sleep_more:
 			t_sleep_task((int)&cw,task_lock,0);
 			_lock_task(task_lock,__FILE__,__LINE__);
+			if ( get_xltime() - cw.ins_time < cw_interval )
+				goto sleep_more;
 			for ( cwp = &create_wait_head ; *cwp ; cwp = &(*cwp)->next )
 				if ( *cwp == &cw )
 					break;
-			*cwp = cw.next;
-			if ( create_wait_head == 0 )
-				create_wait_tail = 0;
-			retry_cnt = 1;
+			if ( create_wait_tail == &cw ) {
+				*cwp = cw.next;
+				create_wait_tail = create_wait_head;
+				if ( create_wait_tail )
+					for ( ;
+						create_wait_tail->next;
+						create_wait_tail 
+							= create_wait_tail->next );
+			}
+			else {
+				*cwp = cw.next;
+				if ( create_wait_head == 0 )
+					create_wait_tail = 0;
+			}
+			retry_cnt = 0;
 //printf("wait the create 2\n");
 			goto retry;
 		}
@@ -1078,10 +1108,10 @@ call_main(int argc,char ** argv,int (*main_ptr)(int,char**))
 
 void
 set_create_wait(
-	active,
-	last_invoke_interval,
-	th,
-	interval)
+	int active,
+	int last_invoke_interval,
+	int th,
+	int interval)
 {
 	cw_active = active;
 	cw_last_invoke_interval = last_invoke_interval;
@@ -1089,4 +1119,22 @@ set_create_wait(
 	cw_interval = interval;
 }
 
+void
+get_create_wait(
+	int * active,
+	int * last_invoke_interval,
+	int * th,
+	int * interval)
+{
+	if ( active )
+		*active = cw_active;
+	if ( last_invoke_interval )
+		*last_invoke_interval = cw_last_invoke_interval;
+	if ( th )
+		*th = cw_th;
+	if ( interval )
+		*interval = cw_interval;
+}
+
+
 
