@@ -211,7 +211,7 @@ int er;
 				goto next;
 			*bp = blk->next;
 		r1:
-			er = close(blk->send);
+			er = secure_close(blk->send);
 			if ( er < 0 && errno == EINTR )
 				goto r1;
 			if ( er < 0 && (errno == EIO || errno == ENOSPC) ) {
@@ -219,7 +219,7 @@ int er;
 				goto r1;
 			}
 		r2:
-			er = close(blk->recv);
+			er = secure_close(blk->recv);
 			if ( er < 0 && errno == EINTR )
 				goto r2;
 			if ( er < 0 && (errno == EIO || errno == ENOSPC) ) {
@@ -244,8 +244,8 @@ UFR_BLK * blk;
 	lock_task(ufr_lock);
 	ufr_disable = 1;
 	for ( blk = ufr_blk_list ; blk ; blk = blk->next ) {
-		close(blk->send);
-		close(blk->recv);
+		secure_close(blk->send);
+		secure_close(blk->recv);
 	}
 	unlock_task(ufr_lock,"ufr_last_access_task");
 }
@@ -317,7 +317,7 @@ int er;
 			if ( recv[1] == i )
 				continue;
 		r1:
-			er = close(i);
+			er = secure_close(i);
 			if ( er < 0 && errno == EINTR )
 				goto r1;
 		}
@@ -329,11 +329,11 @@ int er;
 			ufr_do(write,recv[1],&ret,sizeof(ret));
 			ufr_do(write,recv[1],&seq,sizeof(seq));
 		r2:
-			er = close(recv[1]);
+			er = secure_close(recv[1]);
 			if ( er < 0 && errno == EINTR )
 				goto r2;
 		r3:
-			er = close(send[0]);
+			er = secure_close(send[0]);
 			if ( er < 0 && errno == EINTR )
 				goto r3;
 			exit(1);
@@ -354,20 +354,20 @@ int er;
 	wunlock_fork();
 	if ( id < 0 ) {
 	r4:
-		er = close(send[0]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(send[0]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r4;
 	r5:
-		er = close(recv[0]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(recv[0]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r5;
 	r6:
-		er = close(send[1]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(send[1]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r6;
 	r7:
-		er = close(recv[1]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(recv[1]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r7;
 		ret.ufr_code = UFR_E_FORK;
 		ret.r.sys_code = errno;
@@ -383,12 +383,12 @@ int er;
 		ret.ufr_code = 0;
 
 	r8:
-		er = close(send[0]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(send[0]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r8;
 	r9:
-		er = close(recv[1]);
-		if ( er < 0 && errno == EINTR )
+		er = secure_close(recv[1]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 			goto r9;
 
 		memset(&rq,0,sizeof(rq));
@@ -410,12 +410,12 @@ int er;
 
 		if ( rq.ret.ufr_code ) {
 		r10:
-			er = close(send[1]);
-			if ( er < 0 && errno == EINTR )
+			er = secure_close(send[1]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 				goto r10;
 		r11:
-			er = close(recv[0]);
-			if ( er < 0 && errno == EINTR )
+			er = secure_close(recv[0]);
+		if ( er < 0 && (errno == EINTR || errno == EIO) )
 				goto r11;
 			free(blk);
 			return rq.ret;
@@ -555,11 +555,11 @@ retry:
 						wakeup_task((int)p);
 					}
 				r12:
-					er = close(blk->send);
+					er = secure_close(blk->send);
 					if ( er < 0 && errno == EINTR )
 						goto r12;
 				r13:
-					er = close(blk->recv);
+					er = secure_close(blk->recv);
 					if ( er < 0 && errno == EINTR )
 						goto r13;
 					blk->send = blk->recv = -1;
@@ -664,11 +664,11 @@ UFR_LOG * lg;
 	ret.r.sys_code = 0;
 	return ret;
 err:
-	er = close(blk->send);
+	er = secure_close(blk->send);
 	if ( er < 0 && errno == EINTR )
 		goto err;
 err2:
-	er = close(blk->recv);
+	er = secure_close(blk->recv);
 	if ( er < 0 && errno == EINTR )
 		goto err2;
 	blk->send = blk->recv = -1;
