@@ -55,7 +55,7 @@ int get_userinterface_tid();
 int get_v_loop_tid();
 
 void ms_unlock();
-void ms_lock(char * file,int line);
+int ms_lock(int wait_flag,char * file,int line);
 void ms_inheritance(int,char*,int);
 
 
