@@ -70,6 +70,7 @@ public:
 /* windows dependent VObject information */
 class VInfo {
 private:
+	int vinfoTypeVal;
 	HWND hwnd;
 	VObject *obj;
 	VFONT *font;
@@ -104,6 +105,7 @@ public:
 	VInfo(VObject *o, HWND h, int id);
 	virtual ~VInfo();
 
+	static void init();
 	friend class VContainerInfo;
 };
 
