@@ -42,9 +42,23 @@ VContainerInfo::VContainerInfo(VObject *o, HWND h, int id,
 	memset(&siv, 0, sizeof(siv));
 
 	hAncestorDialog = h;
+	for(;;){
+		if(hAncestorDialog == NULL){
+			break;
+		}
+		VContainerInfo *vi = dynamic_cast<VContainerInfo*>(VInfo::get_from_hwnd(hAncestorDialog));
+		if(vi != NULL && vi->is_dialog){
+			break;
+		}
+		hAncestorDialog = GetParent(hAncestorDialog);
+	}
+	
+	/*
 	while ( hAncestorDialog && ! dynamic_cast<VContainerInfo*>(
 				VInfo::get_from_hwnd(hAncestorDialog))->is_dialog )
 		hAncestorDialog = GetParent(hAncestorDialog);
+	*/
+
 	if ( hAncestorDialog == NULL )
 		er_panic("VContainerInfo without ancestor dialog");
 }
