@@ -110,7 +110,7 @@ VRadioButton::set_status(const VObjectStatus *s, int flags)
 		flags &= ~VSF_VALUE;
 	}
 
-	if ( flags & (VSF_DESC | VSF_VERTD) ) {
+	if( flags & (VSF_DESC | VSF_VERTD | VSF_FSIZE | VSF_WS) ) {
 		sts.min_size.w += 16;
 	}
 	
