@@ -94,9 +94,12 @@ VWindowInfo::translate_accel(MSG *msg)
 	HWND parent, toplevel = msg->hwnd;
 	while ( (parent = GetParent(toplevel)) != 0 )
 		toplevel = parent;
-	VWindowInfo *info = dynamic_cast<VWindowInfo*>(get_from_hwnd(toplevel));
+
+	VInfo *vinfo = get_from_hwnd(toplevel);
+	VWindowInfo *info = dynamic_cast<VWindowInfo*>(vinfo);
 	if ( info == 0 )
 		return 0;
+
 	return TranslateAccelerator(toplevel, info->menu_info->get_haccel(), msg);
 }
 
@@ -422,6 +425,13 @@ VWindow::set_status(const VObjectStatus *s, int flags)
 			window_style |= WS_SIZEBOX | WS_MAXIMIZEBOX;
 		else
 			window_style &= ~(WS_SIZEBOX | WS_MAXIMIZEBOX);
+		
+		if ( s->attr & modal)
+			window_style &= ~WS_SYSMENU;
+		else
+			window_style |= WS_SYSMENU;
+		// v_serialized_exec_sub(::RemoveMenu, GetSystemMenu(hwnd, NULL), SC_CLOSE, MF_BYCOMMAND);
+		
 		v_serialized_exec_sub(::SetWindowLong, hwnd, GWL_STYLE, window_style);
 
 		window_style = ::GetWindowLong(hwnd, GWL_EXSTYLE);
@@ -429,6 +439,7 @@ VWindow::set_status(const VObjectStatus *s, int flags)
 			window_style |= WS_EX_PALETTEWINDOW;
 		else
 			window_style &= ~WS_EX_PALETTEWINDOW;
+		
 		v_serialized_exec_sub(::SetWindowLong, hwnd, GWL_EXSTYLE, window_style);
 
 		if ( s->attr & (modal | floating) )
@@ -437,6 +448,7 @@ VWindow::set_status(const VObjectStatus *s, int flags)
 			v_serialized_exec_sub(::SetWindowPos, hwnd, HWND_NOTOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
 		
 		err.subcode1 &= ~VSF_ATTR;
+
 	}
 
 	if ( flags & VSF_DESC ) {
