@@ -35,6 +35,11 @@
 
 #include	"v/v.h"
 #include	"v/vobj_utils.h"
+#include	"fa_cache.h"
+
+
+
+MAIN_WINDOWS *main_windows;
 
 void v_loop_init();
 void main_task();
@@ -81,6 +86,7 @@ printf("============== gv-syn\n");
 void
 main_task()
 {
+MAIN_WINDOWS* win;
 XL_INTERPRETER * xli;
 	xli = new_xl_interpreter();
 	xli->a_type = XLA_SELF;
@@ -90,8 +96,11 @@ XL_INTERPRETER * xli;
 
 //		if ( view_agent_switch == 0 )
 //			start_gbview();
-
-	call_window_function("main-window");
+	
+	win = (MAIN_WINDOWS*)d_alloc(sizeof(MAIN_WINDOWS));
+	win->win = (VObject*)call_window_function("main-window");
+	win->next = main_windows;
+	main_windows = win;
 
 	finish_initialize();
 }
@@ -117,6 +126,8 @@ _main(int argc,char ** argv)
 // OK
 		start_alloc_time_list();
 
+		set_fd_max(10000);
+
 		tick_start_lock();
 
 		init_sg();
@@ -143,6 +154,7 @@ char * a;
 		init_polling_class(gblisp_top_env0);
 		init_html_db();
 // unlock NG
+		fac_general_info.total_entries = 256*256*2/FAC_SIZE;
 
 		init_main();
 // unlock NG
@@ -178,6 +190,8 @@ char * a;
 			argv[1]);
 		exit(1);
 	}
+for( ; ; )
+sleep_sec(1);
 	exit(0);
 	return 0;
 }
