@@ -717,7 +717,11 @@ ss_printf("CW %p %i\n",cw,cw->mode);
 	flags = get_sf_attribute(sf,l_string(std_cm,"cache_file"));
 	if ( flags && (l_strcmp(flags,l_string(std_cm,"on")) == 0 ) )
 		pw.p.flags |= MPF_CACHE_FILE;
-	
+	flags = get_sf_attribute(sf,l_string(std_cm,"node_dipendent"));
+	if ( flags && (l_strcmp(flags,l_string(std_cm,"on")) == 0 ) )
+		pw.p.flags |= MPF_NODE_DIPENDENT;
+
+
 	env = new_env(new_env_pair(env,a));
 	set_env_work(env,&pw);
 	for ( s = cdr(s) ; get_type(s) == XLT_PAIR ; s = cdr(s) ) {
