@@ -82,7 +82,7 @@ typedef struct hl_que_data {
 void hl_close_matrix_file(MATRIX*);
 void hl_new_token(MATRIX_TOKEN*,int);
 void hl_free_token(MATRIX_TOKEN*,int);
-void hl_trigger(int type,void* t);
+int hl_trigger(int type,void* t);
 
 INTEGER64 invalid_hide_time = 300;
 SYS_QUEUE hl_que;
@@ -148,8 +148,12 @@ int err_code;
 	if ( ow->r->h.cache_file_id ) {
 
 		m->filename = get_filepath_from_file_id(ow->r->h.cache_file_id,".mtx");
-		err = load_matrix_header(m,O_RDWR,0644);
+		err = load_matrix_header(m,O_RDWR|O_CREAT,0644);
 
+		if ( err == ME_CANNOT_OPEN_FILE ) {
+			err = load_matrix_header(m,O_RDWR|O_CREAT|O_TRUNC,0644);
+ss_printf("OLD_MATRIX RETRY ERR %i\n",err);
+		}
 
 ss_printf("old_matrix err %i\n",err);
 		if ( err == 0 ) {
@@ -336,8 +340,9 @@ void hl_free_token(MATRIX_TOKEN* t,int u)
 {
 }
 
-void hl_trigger(int type,void* t)
+int hl_trigger(int type,void* t)
 {
+	return 0;
 }
 
 HL_PATTERN *
@@ -801,7 +806,7 @@ FAVT64_ROOT * rt;
 	vp.dim = 1;
 	vp.ix_size = &ix;
 	vp.default_data = &int64_zero;
-	data = get_matrix_node_channel(&err,&n,m,dc,HL_CH_PATTERN_INT,GN_NODE,GN_NODE_CREATE,&vp);
+	data = get_matrix_node_channel(&err,&n,m,dc,HL_CH_PATTERN_INT,GN_NODE,GN_NODE_CREATE,&vp,0);
 	if ( n == 0 )
 		er_panic("open_hl_matrix(1)");
 	w->param_node = n;
@@ -829,7 +834,7 @@ FAVT64_ROOT * rt;
 	vp.dim = PTN_ORG + m->p.dim;
 	vp.ix_size = &ix;
 	vp.default_data = &double_zero;
-	data = get_matrix_node_channel(&err,&n,m,dc,HL_CH_PATTERN_DBL,GN_NODE,GN_NODE_CREATE,&vp);
+	data = get_matrix_node_channel(&err,&n,m,dc,HL_CH_PATTERN_DBL,GN_NODE,GN_NODE_CREATE,&vp,0);
 	get_matrix_dh_set(&dh,data);
 	w->param_d = (double*)dh.offset;
 	if ( w->param_d[PTN_BASE_RESO] == 0 ) {
@@ -1369,7 +1374,7 @@ int er;
 		/* save tree */
 
 		get_matrix_node_channel(&er,&n,
-				r->h.mtx,dc,HL_CH_DATA,GN_TREE,GN_LIST_CREATE,0);
+				r->h.mtx,dc,HL_CH_DATA,GN_TREE,GN_LIST_CREATE,0,0);
 		if ( n == 0 )
 			er_panic("get_matrix_node_wait");
 		b = get_channel_struct_block(n,HL_CH_DATA);
