@@ -41,6 +41,7 @@ MPI_HEADER	mpi_h;
 int mpi_list_length;
 SEM mpi_lock;
 AVT_NODE * purge_timeout_list;
+int loop_check_nos;
 
 void (*trigger_around_func)
 	(int ses,L_CHAR * my_path,AROUND_LIST * al,int flags);
@@ -1676,6 +1677,60 @@ copy_invalid_data_set(INVALID_DATA_SET * d1,INVALID_DATA_SET * d2)
 	d1->start_point = ll_copy_str(d2->start_point);
 }
 
+int
+get_ipt_nos(INVALID_PRI_TABLE * tbl);
+
+
+int
+get_ipt_nos_entry(INVALID_PRI_ENTRY * e)
+{
+int ret;
+INVALID_PRI * p;
+	ret = 0;
+	for ( p = e->pri ; p ; p = p->next , ret ++ );
+	ret += get_ipt_nos(e->tbl);
+	return ret;
+}
+
+int
+get_ipt_nos(INVALID_PRI_TABLE * tbl)
+{
+int i;
+int ret;
+	if ( tbl == 0 )
+		return 0;
+	ret = 0;
+	for ( i = 0 ; i < ACRP_SUBID_NOS ; i ++ )
+		ret += get_ipt_nos_entry(&tbl->ent[i]);
+	return ret;
+}
+
+void
+_log_ipt(char * msg)
+{
+static int start_flag;
+static int lcn;
+static int ipt;
+int _lcn;
+int _ipt;
+	_lcn = loop_check_nos;
+	_ipt = get_ipt_nos(invalid_pri_tbl);
+	if ( start_flag == 0 ) {
+		start_flag = 1;
+		goto ok;
+	}
+	if ( _lcn != lcn || _ipt != ipt )
+		goto ok;
+	return;
+ok:
+	log_printf(LOG_WARNING,LOG_LAYER_GB,0,
+		"EM-ACRP %s time " I64_FORMAT " lc-nos %i ipt-nos %i\n",
+		   msg,(INTEGER64)get_xltime(),
+		   _lcn,_ipt);
+	lcn = _lcn;
+	ipt = _ipt;
+}
+
 
 INVALID_PRI *
 _search_ipt(int * target,L_CHAR * pri,INVALID_DATA_SET * ds,int new_flag)
@@ -1766,6 +1821,7 @@ s_print_cid(target));
 ss_printf("S IPT-NEW HIT(%i) %s\n",new_flag,
 s_print_cid(target));
 */
+_log_ipt("INSERT");
 	return ret;
 }
 
@@ -1841,6 +1897,7 @@ INVALID_PRI * d;
 	d = _search_ipt(target,pri,0,0);
 	if ( d )
 		d->access_time = 0;
+_log_ipt("DELETE");
 	unlock_task(mpi_lock,"search_ipt");
 }
 
@@ -1884,6 +1941,7 @@ int len;
 		ret = 1;
 		d_f_ree(target);
 	}
+_log_ipt("CLEAN1");
 	unlock_task(mpi_lock,"search_ipt");
 	return ret;
 }
@@ -1907,6 +1965,7 @@ int len;
 				0) == 0 )
 		invalid_pri_tbl = 0;
 	d_f_ree(target);
+_log_ipt("CLEAN2");
 	unlock_task(mpi_lock,"search_ipt");
 }
 
