@@ -20,7 +20,6 @@
 #include	"xlerror.h"
 #include	"xl.h"
 #include	"mx_format.h"
-#include	"mx_format.h"
 
 void
 init_gmxCreate(XLISP_ENV * env0,XLISP_ENV * env1)
@@ -80,6 +79,6 @@ open_err:
 		s->h.line,
 		XLE_PROTO_OPEN_FILE,
 		l_string(std_cm,"gmxCreate"),
-		0);
+		n_get_string("gmxCreate open file error"));
 }
 
