@@ -55,7 +55,7 @@ int size;
 retry:
 	dim_code = get_dim_code_from_sexp(m,inp);
 	err = 0;
-	n = get_matrix_node(&err,m,dim_code,GN_ERROR_NORETRY,0,0);
+	n = get_matrix_node(&err,m,dim_code,GN_ERROR_NORETRY,0,0,0);
 	info = List(
 		get_integer(err,0),
 		get_sexp_from_dim_code(m,dim_code),
@@ -171,7 +171,7 @@ int i,pp_len;
 retry:
 	dim_code = get_dim_code_from_sexp(m,inp);
 	err = 0;
-	n = get_matrix_node(&err,m,dim_code,GN_ERROR_NORETRY,0,0);
+	n = get_matrix_node(&err,m,dim_code,GN_ERROR_NORETRY,0,0,0);
 	info = List(
 		get_integer(err,0),
 		get_sexp_from_dim_code(m,dim_code),
@@ -219,7 +219,7 @@ retry:
 	if ( n->nlist_dim_bit_field ) {
 		ix = 1;
 		for ( i = 0 ; i < m->p.dim ; i ++ )
-			ix *= 1<<m->dim_divide[i];
+			ix *= ((int)1)<<m->dim_divide[i];
 		ix = ix - 1;
 		children_info1 = 0;
 		for ( ; ix >= 0 ; ix -- ) {
@@ -576,6 +576,8 @@ MX_ENTRY * e;
 XL_SEXP * filename;
 XL_SEXP * ret;
 XL_SEXP * pdata;
+XL_SEXP * sym;
+char idd[30];
 	path_type = get_sf_attribute(sf,l_string(std_cm,"path-type"));
 	if ( s_flag == 0 ) {
 		if ( path_type == 0 )
@@ -614,7 +616,12 @@ XL_SEXP * pdata;
 		ret = read_point(e,pdata,sf);
 	}
 	else	goto inv_param;
-	return ret;
+	if ( get_type(ret) == XLT_ERROR )
+		return ret;
+	sym = car(ret);
+	sprintf(idd,"%i",e->id);
+	set_attribute(sym,l_string(std_cm,"id"),l_string(std_cm,idd));
+	return cons(sym,cdr(ret));
 open_err:
 	return get_error(
 		s->h.file,
