@@ -76,7 +76,9 @@ L_CHAR * _transparent;
 unsigned char * valid,* vp;
 XL_SEXP * ret;
 
+/*
 int gn_tree_node,gn_create,gn_wait;
+*/
 
 unsigned char aa;
 
@@ -152,7 +154,7 @@ ss_printf("TRANSPARENT = %x\n",transparent);
 	u_lseek(ppm.pi_fd,ppm.pi_offset,SEEK_SET);
 
 	flush_mx_cache(&mx_e->c,0);
-
+/*
 	gn_tree_node = mx_e->c.gn_tree_node;
 	gn_create = mx_e->c.gn_create;
 	gn_wait = mx_e->c.gn_wait;
@@ -160,7 +162,11 @@ ss_printf("TRANSPARENT = %x\n",transparent);
 	mx_e->c.gn_tree_node = GN_TREE;
 	mx_e->c.gn_create = GN_LIST_CREATE;
 	mx_e->c.gn_wait = GN_LIST_CREATE;
-
+*/
+	push_gn(&mx_e->c,
+		GN_TREE,
+		GN_LIST_CREATE,
+		GN_LIST_CREATE);
 
 	set_matrix_env(mx_e->c.m,"create-node","enable");
 
@@ -240,9 +246,12 @@ ss_printf("TRANSPARENT = %x\n",transparent);
 	next_stage(prog_id,0,0,0);
 	close_progressive(prog_id,0);
 
+/*
 	mx_e->c.gn_tree_node = gn_tree_node;
 	mx_e->c.gn_create = gn_create;
 	mx_e->c.gn_wait = gn_wait;
+*/
+	pop_gn(&mx_e->c);
 
 	mxc_free(&mx_e->c,col);
 	mxc_free(&mx_e->c,buffer);
