@@ -204,12 +204,14 @@ MX_CACHE_PARAM p_utm;
 int ds_pos,ds_from;
 int target_x,target_y;
 int index_src,index_dest;
+/*
 int	m_utm_gn_tree_node,
 	m_utm_gn_create,
 	m_utm_gn_wait,
 	m_bl_gn_tree_node,
 	m_bl_gn_create,
 	m_bl_gn_wait;
+*/
 INTEGER64 tim;
 int index_l,index_x,index_y;
 char * flags_p;
@@ -248,7 +250,8 @@ ss_printf("load_zone-2\n");
 		ud->ep.org_X0 = 0;
 	else	ud->ep.org_X0 = 10000000;
 	ud->ep.org_Y0 = 500000;
-	
+
+/*	
 	m_utm_gn_tree_node = ud->m_utm->c.gn_tree_node;
 	m_utm_gn_create = ud->m_utm->c.gn_create;
 	m_utm_gn_wait = ud->m_utm->c.gn_wait;
@@ -256,6 +259,12 @@ ss_printf("load_zone-2\n");
 	ud->m_utm->c.gn_tree_node = GN_NODE;
 	ud->m_utm->c.gn_create = GN_READ_ONLY;
 	ud->m_utm->c.gn_wait = GN_ERROR_NORETRY;
+*/
+	push_gn(&ud->m_utm->c,
+		GN_NODE,
+		GN_READ_ONLY,
+		GN_ERROR_NORETRY);
+
 	set_matrix_env(ud->m_utm->c.m,"create-node","disable");
 	
 	p_utm = ud->m_utm->p;
@@ -277,17 +286,27 @@ ss_printf("load_zone-2\n");
 		}
 	}
 	
+/*
 	m_bl_gn_tree_node = ud->m_bl->c.gn_tree_node;
 	m_bl_gn_create = ud->m_bl->c.gn_create;
 	m_bl_gn_wait = ud->m_bl->c.gn_wait;
+*/
 
 	for ( i = 0 ; i < ud->m_bl->c.ds_len ; i ++ )
 		if ( ud->m_bl->c.access_ch[i] == ud->bl_channel )
 			ds_pos = i;
 
+/*
 	ud->m_bl->c.gn_tree_node = GN_TREE;
 	ud->m_bl->c.gn_create = GN_LIST_CREATE;
 	ud->m_bl->c.gn_wait = GN_LIST_CREATE;
+*/
+	push_gn(&ud->m_bl->c,
+		GN_TREE,
+		GN_LIST_CREATE,
+		GN_LIST_CREATE);
+		
+
 	set_matrix_env(ud->m_utm->c.m,"create-node","enable");
 
 //print_elipsoid(&ud->ep);
@@ -478,7 +497,7 @@ ud->zone_offset_x,ud->zone_offset_y,ud->zone_reso_x,ud->zone_reso_y);
 		next_stage(prog_id,0,0,0);
 		close_progressive(prog_id,0);
 	}
-
+/*
 	ud->m_bl->c.gn_tree_node = m_bl_gn_tree_node;
 	ud->m_bl->c.gn_create = m_bl_gn_create;
 	ud->m_bl->c.gn_wait = m_bl_gn_wait;
@@ -486,6 +505,9 @@ ud->zone_offset_x,ud->zone_offset_y,ud->zone_reso_x,ud->zone_reso_y);
 	ud->m_utm->c.gn_tree_node = m_utm_gn_tree_node;
 	ud->m_utm->c.gn_create = m_utm_gn_create;
 	ud->m_utm->c.gn_wait = m_utm_gn_wait;
+*/
+	pop_gn(&ud->m_bl->c);
+	pop_gn(&ud->m_utm->c);
 
 	flush_mx_cache(&ud->m_bl->c,0);
 	flush_mx_cache(&ud->m_utm->c,0);
