@@ -224,6 +224,8 @@ check_mx_entry(e);
 		set_attribute(sym2,l_string(std_cm,"index_hem"),l_string(std_cm,"on"));
 	if ( m->p.flags & MPF_CACHE_FILE ) 
 		set_attribute(sym2,l_string(std_cm,"cache_file"),l_string(std_cm,"on"));
+	if ( m->p.flags & MPF_NODE_DIPENDENT ) 
+		set_attribute(sym2,l_string(std_cm,"node_dipendent"),l_string(std_cm,"on"));
 	sprintf(buf,"%i",m->p.dim);
 	set_attribute(sym2,l_string(std_cm,"dim"),l_string(std_cm,buf));
 	sprintf(buf,"%i",m->p.channel_nos);
