@@ -72,10 +72,14 @@ change_endian_pmd_header(PN_PMD_HEADER * h)
 	change_endian_i(h->ix_timeout);
 }
 
-void
+int
 change_endian_pmd_node_to_host(PN_PMD_NODE * n)
 {
+int size;
 	change_endian_header(&n->h);
+	size = n->h.size;
+	if ( sizeof(*n)-sizeof(L_CHAR) > size )
+		return -1;
 	change_endian_gb_rect(&n->minrect);
 	change_endian_f(n->resolution);
 	change_endian_gb_time(&n->content_period_from);
@@ -84,14 +88,35 @@ change_endian_pmd_node_to_host(PN_PMD_NODE * n)
 	change_endian_i(n->md_fofs);
 	change_endian_s(n->category);
 	change_endian_s(n->target);
+	if ( ((unsigned int)(&n->str[l_strlen(n->str)+1]))-
+			((unsigned int)n) > size )
+		return -2;
 	change_endian_l_char(n->str);
+	if ( ((unsigned int)(&n->str[n->target+l_strlen(&n->str[n->target])+1]))-
+			((unsigned int)n) > size )
+		return -3;
 	change_endian_l_char(&n->str[n->target]);
+	return 0;
 }
 
 
 void
 change_endian_pmd_node_to_net(PN_PMD_NODE * n)
 {
+int size;
+	size = n->h.size;
+	if ( ((unsigned int)(&n->str[l_strlen(n->str)+1]))-
+			((unsigned int)n) > size ) {
+		ss_printf("pmd_endian ----1 %i %i\n",
+			((unsigned int)(&n->str[l_strlen(n->str)+1]))-
+				((unsigned int)n),
+				size);
+		er_panic("---");
+	}
+	if ( ((unsigned int)(&n->str[n->target+l_strlen(&n->str[n->target])+1]))-
+			((unsigned int)n) > size )
+		ss_printf("pmd_endian ----2\n");
+
 	change_endian_header(&n->h);
 	change_endian_gb_rect(&n->minrect);
 	change_endian_f(n->resolution);
@@ -445,13 +470,16 @@ get_temp_db(PMD_WORK * w,unsigned int fofs)
 {
 ACC_PN_PMD_NODE * n;
 PMD_TEMP * ret;
+void fs_test();
+int er;
 	if ( fofs == 0 )
 		return 0;
 	n = read_filespace(w->p,fofs);
 	if ( n == 0 )
 		return 0;
-	change_endian_pmd_node_to_host(&n->d);
-	if ( n->d.h.type != PNT_PMD_NODE ) {
+	er = change_endian_pmd_node_to_host(&n->d);
+
+	if ( er < 0 || n->d.h.type != PNT_PMD_NODE ) {
 		d_f_ree(n);
 		return 0;
 	}
