@@ -32,17 +32,20 @@ int rcache_run_flag;
 int rcache_stop_flag;
 
 int rcache_flush();
+int rcache_int_handler();
 int rcache_exit_flag;
 void rcache_exit_tick();
 void rcache_task();
 XL_SEXP * xl_rcache_enable(XLISP_ENV * e,XL_SEXP * s);
 
+int (*rcache_int_handler_backup)();
 
 void
 init_rcache()
 {
 	rcache_lock = new_lock(LL_RCACHE);
-	int_handler = rcache_flush;
+	rcache_int_handler_backup = int_handler;
+	int_handler = rcache_int_handler;
 	new_tick((void(*)(int))rcache_exit_tick,1,0);
 	init_rt_cache();
 	init_rs_cache();
@@ -61,6 +64,17 @@ rcache_flush()
 	return 0;
 }
 
+int
+rcache_int_handler()
+{
+int ret;
+	ret = -1;
+	if ( rcache_int_handler_backup )
+		ret = (*rcache_int_handler_backup)();
+	ret = rcache_flush();
+	return ret;
+}
+
 void
 rcache_exit_tick()
 {
