@@ -1101,7 +1101,7 @@ L_CHAR * tmp;
 			continue;
 		ff = new_file_list(d->d_name,ff);
 	}
-	closedir(dd);
+	secure_closedir(dd);
 	len = strlen(n_string(std_cm,dir_path));
 	for ( _f = ff ; _f ; _f = _f->next ) {
 		buf = d_alloc(len + strlen(_f->name) + 10);
