@@ -1129,7 +1129,7 @@ get_init_status_info(RESOURCE * r)
 			get_symbol(l_string(std_cm,"initial-status")),
 			get_string(l_string(std_cm,
 				status_msg_table[r->h.initial_status])),
-			err_handler(r->h.initial_error,0,0),
+			err_handler(r->h.initial_error,0,0,0),
 			-1);
 	}
 	else {
@@ -1149,7 +1149,7 @@ get_inc_status_info(RESOURCE * r)
 			get_symbol(l_string(std_cm,"incremental-status")),
 			get_string(l_string(std_cm,
 				status_msg_table[r->h.incremental_status])),
-			err_handler(r->h.incremental_error,0,0),
+			err_handler(r->h.incremental_error,0,0,0),
 			-1);
 	}
 	else {
