@@ -42,6 +42,13 @@ RESOURCE * rr;
 		ret = eval(e,r);
 		if ( get_type(ret) != XLT_ERROR )
 			rret = ret;
+else {
+ss_printf("root_tag_func ERROR ");
+print_sexp(s_stdout,r,0);
+ss_printf(" => ");
+print_sexp(s_stdout,ret,0);
+ss_printf("\n");
+}
 	}
 	return rret;
 err:
