@@ -39,7 +39,8 @@ cache_image(
 	MAP_HISTORY * mh,
 	SURP_SET * surp,
 	int method,
-	int flags)
+	int flags,
+	void * dw_work)
 {
 DRAW_WORK dw;
 int i;
@@ -57,8 +58,9 @@ int i;
 	dw.method = method;
 	dw.surp = *surp;
 	dw.data_request = 0;
-	dw.flags = flags;
+	dw.flags = flags&(~WFF_FLUSH);
 	dw.wfid = wfid;
+	dw.work = dw_work;
 
 	if ( wf_active_check_2(gf,dw.wfid) == 0 ) {
 		dw.ses = open_session(SEST_OPTIMIZE);
