@@ -28,8 +28,9 @@
 #include	"lock_level.h"
 #include	"pri_level.h"
 #include	"xl.h"
-
-
+/*
+#define COORDINATE_DEBUG
+*/
 
 typedef struct _bw_map {
 	RESOURCE *		r;
@@ -85,7 +86,7 @@ extern XLISP_ENV * gv_resource_env[];
 }
 
 void
-load_coordinate_option()
+load_coordinate_option(RESOURCE * r)
 {
 	assert_ls_all(LSF_ASSERT);
 }
@@ -330,6 +331,9 @@ int i;
 int cnt;
 cnt = 0;
 
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP load children %ls\n",get_url_str2(&r->h.entry));
+#endif
 
 	if ( (r->h.flags & (RF_LOAD_EXTEND|RF_LOAD_EXTEND_PROC)) == 0 )
 		lr_extend(r,0);
@@ -347,7 +351,12 @@ cnt ++;
 			len = l_strlen(m->src_url.resource);
 			if ( l_strcmp(&m->src_url.resource[len-4],
 					l_string(std_cm,".crd")) == 0 )
+{
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP load children %ls CONT-1\n",get_url_str2(&r->h.entry));
+#endif
 				continue;
+}
 		}
 
 		if ( r->h.flags & RF_FORCE_LOAD_CHI )
@@ -363,12 +372,18 @@ cnt ++;
 			unlock_task(res_lock,"write_lock");
 			if ( g )
 				d_f_ree(g);
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP load children %ls CONT-2\n",get_url_str2(&r->h.entry));
+#endif
 			continue;
 		cross_next:	;
 		}
 	loading:
 
 		if ( m->src == 0 ) {
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP LOAD %ls\n",get_url_str2(&m->src_url));
+#endif
 			ret = new_lrw(ret);
 			copy_url(&ret->url,&m->src_url);
 			if ( r->h.flags & RF_INHERIT )
@@ -378,6 +393,9 @@ cnt ++;
 
 
 		if ( m->map_file == 0 ) {
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP LOAD %ls\n",get_url_str2(&m->map_url));
+#endif
 			ret = new_lrw(ret);
 			copy_url(&ret->url,&m->map_url);
 			if ( r->h.flags & RF_INHERIT )
@@ -407,6 +425,9 @@ int i;
 int len;
 LOAD_RESOURCE_WORK * wp;
 
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP children %ls\n",get_url_str2(&r->h.entry));
+#endif
 	ret = 0;
 	wp = w;
 	this_coord = 0;
@@ -449,8 +470,9 @@ LOAD_RESOURCE_WORK * wp;
 			
 			if ( m->src )
 				this_coord = 1;
-
-//ss_printf("MAP OK %ls\n",get_url_str2(&m->map_url));
+#ifdef COORDINATE_DEBUG
+ss_printf("MAP OK %ls\n",get_url_str2(&m->map_url));
+#endif
 		}
 
 /***/
@@ -488,7 +510,9 @@ LOAD_RESOURCE_WORK * wp;
 			if ( m->src->h.notes )
 				call_gv_event(m->src->h.no,
 					l_string(std_cm,"set-note"));
-//ss_printf("SRC OK %ls\n",get_url_str2(&m->src_url));
+#ifdef COORDINATE_DEBUG
+ss_printf("SRC OK %ls\n",get_url_str2(&m->src_url));
+#endif
 		}
 
 
@@ -528,6 +552,11 @@ LOAD_RESOURCE_WORK * wp;
 		wf_insert_dirty_rect(r,
 				&r->h.minrect,WFF_DIRTY,120,10);
 		force_change_task();
+/*
+		wir = wf_search_wfid_include_resource(r);
+		for ( p = wir ; p ; p = p->next )
+			wakeup_wf(p->gf,p->id);
+*/
 	}
 	return ret;
 }
@@ -980,6 +1009,7 @@ LOAD_RESOURCE_SERVICE_CODE * cl;
 		return 0 ;
 	}
 	else {
+//ss_printf("browse_coord\n");
 		w = load_children_map(r,bw);
 		load_resource_list(w,Q_PRI_OBJ,1);
 		ret = browse_children_map(bw->ses,r,bw,w);
@@ -1040,9 +1070,12 @@ int reso_cnt,minus_cnt,rect_cnt;
 int proc;
 
 
-
-	proc = 0;
-
+	if ( (r->h.flags & RF_LOAD_EXTEND) == 0 )
+		proc = 7;
+	else	proc = 0;
+/*
+ss_printf("draw_coordinate %ls %x %x\n",get_url_str2(&r->h.entry),r->h.flags,RF_LOAD_EXTEND);
+*/
 	dw->limit_reso = 0;
 	if ( dw->pt_list &&
 	     (r->c.geometory_type & GT_T_MASK) == GT_T_GLOBE_SUR )
