@@ -103,7 +103,7 @@ scan_dm_point_list(DRAW_MATRIX * dm)
 {
 POINT_LIST * p;
 OBJ * obj;
-printf("scan_dm_point\n");
+//printf("scan_dm_point\n");
 
 	lock_pdb_lock(dm->r,0);
 	for ( ; dm->dm_point_list ; ) {
@@ -126,7 +126,7 @@ printf("scan_dm_point\n");
 		touch_obj_mem(-sizeof(*p));
 	}
 	unlock_pdb_lock(dm->r);
-printf("scan_dm_point end\n");
+//printf("scan_dm_point end\n");
 
 }
 
