@@ -34,6 +34,10 @@
 #include	"tr_html.h"
 #include	"mx_format.h"
 
+void
+gc_tick_notin_tick(char * msg,int no);
+
+
 void gc_gb_sexp(XL_SEXP * p);
 void loading_file(L_CHAR *, L_CHAR *,int);
 XL_SEXP *
@@ -737,6 +741,9 @@ xl_reset_status(XLISP_ENV * e,XL_SEXP * s)
 STREAM * st;
 char * file;
 
+	gc_tick_notin_tick(0,0);
+
+
 	file = d_alloc(100);
 	sprintf(file,"%s%s",get_preference_path(),GBVIEW_PARAM);
 	u_mkdir(get_preference_path(),0700);
@@ -1115,7 +1122,7 @@ XL_SEXP * lst,* ret;
 				if ( get_type(ret) == XLT_ERROR ) {
 					print_sexp(s_stderr,ret,0);
 					s_printf(s_stderr,"\n");
-					closedir(dd);
+					secure_closedir(dd);
 					exit(1);
 				}
 				gc_pop(0,0);
@@ -1123,7 +1130,7 @@ XL_SEXP * lst,* ret;
 		}
 
 
-		closedir(dd);
+		secure_closedir(dd);
 */
 	}
 /*end:*/
