@@ -1199,6 +1199,7 @@ RESOURCE * r;
 
 	for ( ; ; ) {
 
+		gc_push(0,0,"beam");
 		cnt = 0;
 		n2 = 0;
 		for ( ; cnt < 1 ; ) {
@@ -1237,9 +1238,10 @@ r->h.loop_no - n1->process_node->process_token_key,get_url_str2(&r->h.entry));
 			otw1->next = n2;
 			n2 = n1;
 		}
-		if ( n2 == 0 )
+		if ( n2 == 0 ) {
+			gc_pop(0,0);
 			break;
-		gc_push(0,0,"beam");
+		}
 		n3 = 0;
 		data = 0;
 		tmp = 0;
