@@ -115,6 +115,7 @@ typedef struct vm_plot {
 	int			direct_onmap_ref_field;
 	L_CHAR *		direct_onmap_ref_field_str;
 	int			direct_onmap_fontcolor;
+	int			direct_onmap_backcolor;
 } VM_PLOT;
 
 typedef struct vm_pg_data {
@@ -184,6 +185,7 @@ vmp_initialize(VM_PLOT * vmp)
 		vmp->direct_onmap_ref_field = -1;
 		vmp->direct_onmap_ref_field_str = 0;
 		vmp->direct_onmap_fontcolor = 0;
+		vmp->direct_onmap_backcolor = 0xff;
 		vmp->h.flags &= ~VMWF_NOT_INITIALIZE;
 	}
 }
@@ -342,8 +344,13 @@ char * e_param;
 	vmp_initialize(vmp);
 
 	color = get_sf_attribute(sf,l_string(std_cm,"color"));
-	if ( color )
-		sscanf(n_string(std_cm,color),"%i",&vmp->default_color);
+	if ( color ) {
+		if ( color[0] == '0' && color[1] == 'x' )
+			sscanf(n_string(std_cm,color),"%i",&vmp->default_color);
+		else if ( color[0] == '#' )
+			sscanf(n_string(std_cm,&color[1]),"%x",&vmp->default_color);
+		else	vmp->color_field = atoi(n_string(std_cm,color));
+	}
 	level = get_sf_attribute(sf,l_string(std_cm,"level"));
 	if ( level ) {
 		_level = atoi(n_string(std_cm,level));
@@ -421,16 +428,22 @@ char * e_param;
 			_transparent = -1;
 			__transparent = -1;
 		}
-		else if ( transparent[0] == '#' )
-			_transparent = atoi(n_string(std_cm,&transparent[1]));
+		else if ( transparent[0] == '#' ) {
+			__transparent = -1;
+			sscanf(n_string(std_cm,&transparent[1]),"%x",&_transparent);
+		}
 		else {
+			__transparent = atoi(n_string(std_cm,transparent));
 			_transparent = -1;
-			sscanf(n_string(std_cm,transparent),"%i",&__transparent);
 		}
 		
 		if ( vmp->default_logo_len <= _level ) {
 			vmp->default_logo = d_re_alloc(vmp->default_logo,
 				(_level+1)*sizeof(VM_DEFAULT_VALUES));
+/*
+			memset(&vmp->default_logo[vmp->default_logo_len],0,
+				(_level+1-vmp->default_logo_len)*sizeof(VM_DEFAULT_VALUES));
+*/
 			vmp->default_logo_len = _level+1;
 		}
 		vp = &vmp->default_logo[_level];
@@ -501,6 +514,10 @@ L_CHAR * direct;
 	if ( direct ) {
 		sscanf(n_string(std_cm,&direct[1]),"%x",&vmp->direct_onmap_fontcolor);
 	}
+	direct = get_sf_attribute(sf,l_string(std_cm,"direct-onmap-backcolor"));
+	if ( direct ) {
+		sscanf(n_string(std_cm,&direct[1]),"%x",&vmp->direct_onmap_backcolor);
+	}
 	vmp->ind_convert = new_matrix_sexp(get_el(s,1));
 	return 0;
 }
@@ -797,8 +814,11 @@ get_logo_info(VM_PLOT * vmp,INTERNAL_PLOT * pt,int logo,L_CHAR ** url,int * alig
 {
 VM_DEFAULT_VALUES * vp;
 FIELD_RGBA_T * rgba;
-	if ( pt->fields == 0 )
-		return -1;
+int er;
+	if ( pt->fields == 0 ) {
+		er = -1;
+		goto err0;
+	}
 	if ( vmp->default_logo_len <= logo )
 		logo = vmp->default_logo_len - 1;
 	for ( ; logo > 0 ; logo -- ) {
@@ -807,14 +827,20 @@ FIELD_RGBA_T * rgba;
 		if ( vmp->default_logo[logo].logo_field >= 0 )
 			break;
 	}
-	if ( logo <= 0 )
-		return -1;
+	if ( logo <= 0 ) {
+		er = -2;
+		goto err0;
+	}
 	vp = &vmp->default_logo[logo];
 	if ( vp->logo_field >= 0 ) {
-		if ( pt->fields[0].len <= vp->logo_field )
-			return -1;
-		if ( pt->fields[vp->logo_field].type != CH_STRING )
-			return -1;
+		if ( pt->fields[0].len <= vp->logo_field ) {
+			er = -3;
+			goto err0;
+		}
+		if ( pt->fields[vp->logo_field].type != CH_STRING ) {
+			er = -4;
+			goto err0;
+		}
 		*url = nl_copy_str(&utf8_cm,pt->fields[vp->logo_field].d.str);
 	}
 	else {
@@ -822,8 +848,10 @@ FIELD_RGBA_T * rgba;
 	}
 
 	if ( vmp->anchor_field >= 0 ) {
-		if ( pt->fields[0].len <= vmp->anchor_field )
-			return -1;
+		if ( pt->fields[0].len <= vmp->anchor_field ) {
+			er = -5;
+			goto err1;
+		}
 		switch ( pt->fields[vmp->anchor_field].type ) {
 		case CH_STRING:
 			*anchor = nl_copy_str(&utf8_cm,pt->fields[vmp->anchor_field].d.str);
@@ -837,7 +865,8 @@ FIELD_RGBA_T * rgba;
 			*anchor = 0;
 			break;
 		default:
-			return -1;
+			er = -6;
+			goto err1;
 		}
 	}
 	else if ( vmp->default_anchor ) {
@@ -849,8 +878,10 @@ FIELD_RGBA_T * rgba;
 
 	*align = 0;
 	if ( vp->halign_field >= 0 ) {
-		if ( pt->fields[0].len <= vp->halign_field )
-			return -1;
+		if ( pt->fields[0].len <= vp->halign_field ) {
+			er = -7;
+			goto err2;
+		}
 		switch ( pt->fields[vp->halign_field].type ) {
 		case CH_STRING:
 			if ( strcmp(pt->fields[vp->halign_field].d.str,"left") == 0 )
@@ -859,7 +890,10 @@ FIELD_RGBA_T * rgba;
 				*align |= AG_LR_CENTER;
 			else if ( strcmp(pt->fields[vp->halign_field].d.str,"right") == 0 )
 				*align |= AG_LR_RIGHT;
-			else	return -1;
+			else {
+				er = -8;
+				goto err2;
+			}
 			ofs->x = -1;
 			break;
 		case CH_INT_ADD:
@@ -870,7 +904,8 @@ FIELD_RGBA_T * rgba;
 			*align |= AG_LR_VALUE;
 			break;
 		default:
-			return -1;
+			er = -9;
+			goto err2;
 		}
 	}
 	else {
@@ -878,8 +913,10 @@ FIELD_RGBA_T * rgba;
 		ofs->x = vp->offset.x;
 	}
 	if ( vp->valign_field >= 0 ) {
-		if ( pt->fields[0].len <= vp->valign_field )
-			return -1;
+		if ( pt->fields[0].len <= vp->valign_field ) {
+			er = -10;
+			goto err2;
+		}
 		switch ( pt->fields[vp->valign_field].type ) {
 		case CH_STRING:
 			if ( strcmp(pt->fields[vp->valign_field].d.str,"top") == 0 )
@@ -888,7 +925,10 @@ FIELD_RGBA_T * rgba;
 				*align |= AG_TB_CENTER;
 			else if ( strcmp(pt->fields[vp->halign_field].d.str,"bottom") == 0 )
 				*align |= AG_TB_BOTTOM;
-			else	return -1;
+			else {
+				er = -11;
+				goto err2;
+			}
 			ofs->y = -1;
 			break;
 		case CH_INT_ADD:
@@ -899,7 +939,8 @@ FIELD_RGBA_T * rgba;
 			*align |= AG_TB_VALUE;
 			break;
 		default:
-			return -1;
+			er = -12;
+			goto err2;
 		}
 	}
 	else {
@@ -907,10 +948,14 @@ FIELD_RGBA_T * rgba;
 		ofs->y = vp->offset.y;
 	}
 	if ( vp->t_color_field >= 0 ) {
-		if ( pt->fields[0].len <= vp->t_color_field )
-			return -1;
-		if ( pt->fields[vp->valign_field].type != CH_RGBA )
-			return -1;
+		if ( pt->fields[0].len <= vp->t_color_field ) {
+			er = -13;
+			goto err2;
+		}
+		if ( pt->fields[vp->valign_field].type != CH_RGBA ) {
+			er = -14;
+			goto err2;
+		}
 		rgba = pt->fields[vp->t_color_field].d.rgba;
 		if ( rgba->rgba[3] == 0xff )
 			*t_color = -1;
@@ -920,6 +965,13 @@ FIELD_RGBA_T * rgba;
 		*t_color = vp->t_color;
 	}
 	return 0;
+err2:
+	if ( *anchor )
+		d_f_ree(*anchor);
+err1:
+	d_f_ree(*url);
+err0:
+	return er;
 }
 
 
@@ -987,6 +1039,34 @@ fp,sz);
 //ss_printf("set_dont_print_flag-3 %i\n",len);
 }
 
+
+void
+get_pixel_color(
+	unsigned int * color,unsigned char * alpha,
+	unsigned int backcolor)
+{
+unsigned int col[4];
+unsigned int bcol[4];
+unsigned int result[4];
+int i;
+unsigned int a;
+
+	for ( i = 0 ; i < 3 ; i ++ )
+		bcol[i] = ((backcolor>>(8*(3-i)))&0x0ff)<<(COL_BIT-8);
+	bcol[3] = backcolor&0xff;
+	GET_COL((*color),col[0],col[1],col[2]);
+	if ( (*color)&C_TRANSPARENT )
+		col[3] = 255;
+	else	col[3] = *alpha;
+	
+	result[3] = (a=bcol[3]*col[3])/255;
+	for ( i = 0 ; i < 3 ; i ++ )
+		result[i] = ((255-bcol[3])*col[3]*bcol[i] + (255*255-255*col[3])*col[i])/(255*255-a);
+	*color = COL(result[0],result[1],result[2]);
+	*alpha = result[3];
+}
+
+
 void
 vmt_draw_plot(VIEW_METHOD* vm,GBVIEW_FLAME* gf,RESOURCE * r,DRAW_WORK* dw)
 {
@@ -1046,6 +1126,11 @@ REAL1 style_reso;
 VM_PG_DATA dd;
 int dsize;
 int er_code;
+int logo_er;
+INTEGER64 min_direction;
+INTEGER64 d_avg;
+INTEGER64 level_d,level_i;
+INTEGER64 _logo;
 
 	if ( dw->method == 0 )
 		return; 
@@ -1095,6 +1180,11 @@ int er_code;
 ss_printf("=================== PG VECTOR\n");
 #endif
 
+	d_avg = 0;
+	for ( i = 0 ; i < r->h.mtx->p.dim ; i ++ )
+		d_avg += ((INTEGER64)1)<<r->h.mtx->dim_divide[i];
+	d_avg = d_avg/r->h.mtx->p.dim;
+
 	rp = get_surp_rect_rate(&rp_len,&dw->surp,0.1,0);
 	for ( rr = 0 ; rr < rp_len ; rr ++ )  {
 		if ( wf_active_check_2(gf,dw->wfid) < 0 )
@@ -1164,6 +1254,9 @@ ss_printf("PG PLOT CH %i = %p %p - LEVEL = %i\n",vm->view_channel[0],d,n,lev);
 				goto next;
 			(*n->channel[vm->view_channel[0]].sb->tbl->operation)(PPC_GET,
 				n->channel[vm->view_channel[0]].sb,&ip);
+			level_i = n->dim_code[0] - ix[0];
+			level_d = 1;
+			for ( ; level_i > 0 ; level_i -- , level_d *= d_avg );
 
 #ifdef PGV_DEBUG
 ss_printf("PG PLOT IP = %p\n",ip);
@@ -1185,7 +1278,8 @@ ss_printf("PG PLOT size = %p\n",size);
 #ifdef PGV_DEBUG
 ss_printf("PG PLOT DIST %i\n",(*ip_p)->min_direction);
 #endif
-				if ( (*ip_p)->min_direction < POINT_MIN_DIRECTION_STEP ) {
+				min_direction = (*ip_p)->min_direction * level_d;
+				if ( min_direction < POINT_MIN_DIRECTION_STEP ) {
 				plot_color:
 #ifdef PGV_DEBUG
 ss_printf("PG PLOT COLOR-1\n");
@@ -1218,10 +1312,17 @@ ss_printf("PG PLOT COLOR-2 %i %i - %i %x\n",(*ip_p)->c[0],(*ip_p)->c[1],vmp->col
 #ifdef PGV_DEBUG
 ss_printf("PG PLOT LOGO-1\n");
 #endif
-					logo = (*ip_p)->min_direction / POINT_MIN_DIRECTION_STEP;
-					if ( get_logo_info(vmp,*ip_p,logo,&logo_url,&logo_align,&logo_offset,&logo_t_color,
-							&logo_anchor) < 0 )
+					_logo = min_direction / POINT_MIN_DIRECTION_STEP;
+					if ( _logo > (((INTEGER64)1)<<16) )
+						logo = (((INTEGER64)1)<<16);
+					else	logo = _logo;
+					if ( (logo_er=get_logo_info(vmp,*ip_p,logo,&logo_url,&logo_align,&logo_offset,&logo_t_color,
+							&logo_anchor)) < 0 ) {
+#ifdef PGV_DEBUG
+ss_printf("PG PLOT LOGO-ERR %i\n",logo_er);
+#endif
 						goto plot_color;
+					}
 					
 					data = get_ri(&w,&h,gf,dw->wfid,logo_url);
 					if ( data == 0 )
@@ -1256,9 +1357,15 @@ ss_printf("PG PLOT LOGO-1\n");
 					}
 					dt = d_alloc(w*h*sizeof(int));
 					memcpy(dt,data,w*h*sizeof(int));
-					for ( i = 0 ; i < w*h ; i ++ )
-						if ( dt[i] == logo_t_color )
-							dt[i] = C_TRANSPARENT;
+					{
+					int ix;
+					unsigned int ltc = COL(((logo_t_color>>16)&0xff)<<(COL_BIT-8),
+							((logo_t_color>>8)&0xff)<<(COL_BIT-8),
+							((logo_t_color)&0xff)<<(COL_BIT-8));
+						for ( ix = 0 ; ix < w*h ; ix ++ )
+							if ( dt[ix] == ltc )
+								dt[ix] = C_TRANSPARENT;
+					}
 
 					rect.tl.x = x;
 					rect.tl.y = y;
@@ -1270,7 +1377,7 @@ ss_printf("PG PLOT LOGO-1\n");
 							gf,
 							ISI_INSERT,
 							dw->wfid,
-							dw->resource->h.no,
+							r->h.no,
 							(*ip_p)->id,
 							0,
 							&rect,
@@ -1282,7 +1389,7 @@ ss_printf("PG PLOT LOGO-1\n");
 							gf,
 							ISI_INSERT,
 							dw->wfid,
-							dw->resource->h.no,
+							r->h.no,
 							(*ip_p)->id,
 							0,
 							&rect,
@@ -1350,6 +1457,9 @@ ss_printf("DATA %x %x :: %x\n",fd->d.str[0],fd->d.str[1],data->string.data[0]);
 							default:
 								goto ac_error;
 							}
+#ifdef PGV_DEBUG
+ss_printf("REF %i %i\n",vmp->direct_onmap_ref_field,(*ip_p)->fields[0].len);
+#endif
 							if ( vmp->direct_onmap_ref_field < 0 ||
 								vmp->direct_onmap_ref_field >= 
 									(*ip_p)->fields[0].len ) {
@@ -1363,6 +1473,9 @@ ss_printf("DATA %x %x :: %x\n",fd->d.str[0],fd->d.str[1],data->string.data[0]);
 								goto ref_next;
 							}
 							fd = &(*ip_p)->fields[vmp->direct_onmap_ref_field];
+#ifdef PGV_DEBUG
+ss_printf("REF-2 %i %i\n",fd->type,CH_STRING);
+#endif
 							if ( fd->type == CH_STRING ) {
 								sym = n_get_symbol("A");
 								set_attribute(sym,l_string(std_cm,"HREF"),
@@ -1484,7 +1597,7 @@ ss_printf("\n");
 				rect.br.y = ind_ptr.y + pic.rect.br.y;
 				_width = pic.rect.br.x - pic.rect.tl.x;
 				_height = pic.rect.br.y - pic.rect.tl.y;
-				goto ok;
+//				goto ok;
 				
 				if ( wf_space_check_si(
 						gf,
@@ -1507,12 +1620,15 @@ ss_printf("\n");
 						dw->wfid,r->h.no,((*ip_p)->id&MAIN_CODE)|INFO_SUBCODE,
 							0,&rect,10) == 0 )
 					goto ok;
+
 				free_pic(pic);
 				continue;
 			ok:
 				sub = 0;
 				for ( pe = pic.list ; pe ; pe = pe->next ) {
 				int flags;
+				int ix;
+				int ix_size;
 					rect.tl.x = pe->p.r.tl.x + ind_ptr.x;
 					rect.br.x = pe->p.r.br.x + ind_ptr.x;
 					rect.tl.y = pe->p.r.tl.y + ind_ptr.y;
@@ -1524,6 +1640,11 @@ ss_printf("\n");
 #ifdef PGV_DEBUG
 ss_printf("PG PLOT ONMAP-7 REF=%p %x\n",pe->ref,flags);
 #endif
+					if ( ((vmp->direct_onmap_backcolor&0xff) != 0xff) && pe->alpha ) {
+						ix_size = (rect.br.x - rect.tl.x)*(rect.br.y - rect.tl.y);
+						for ( ix = 0 ; ix < ix_size ; ix ++ )
+							get_pixel_color(&pe->data[ix],&pe->alpha[ix],vmp->direct_onmap_backcolor);
+					}
 					wf_insert_si(
 						gf,
 						ISI_INSERT,
