@@ -401,7 +401,7 @@ void gc_gb_sexp();
 	}
 	sf = get_info_style(is_org,scheme,type,1);
 	if ( sf == 0 ) {
-		ss_printf("dundefined style scheme %ls\n",scheme);
+		ss_printf("undefined style scheme %ls\n",scheme);
 		return org;
 	}
 	if ( sf->style == 0 ) {
