@@ -24,12 +24,10 @@
 #include	"win_flame.h"
 #include	"memory_debug.h"
 #include	"gbgraph.h"
+#include	"radar.h"
 
 #define PRI_OFFSET_RATE		20
 
-void _wakeup_win_manage(void *);
-void wakeup_win_manage(void *);
-
 int
 e1d_move(GBVIEW_FLAME * gf,WIN_FLAME * wf,VPOINT from,VPOINT to,
 	 void * _ix)
@@ -612,6 +610,9 @@ int dx,dy;
 	assert_ls(gf,LSF_MOVE);
 	gf->move_flag = 1;
 	_set_move_timer(gf);
+#ifdef CACHE_TEST_DEBUG
+ss_printf("CACHE-TEST WAKEUP-WIN-MANAGE %lli\n",(INTEGER64)get_xltime());
+#endif
 	_wakeup_win_manage(gf->radar_ptr);
 
 	return _get_env_seq(gf);
