@@ -20,12 +20,11 @@
 #include	"win_flame.h"
 #include	"memory_debug.h"
 #include	"gbgraph.h"
+#include	"radar.h"
 
 #define PRI_OFFSET_RATE		20
 
 void ov_default();
-void _wakeup_win_manage(void *);
-void wakeup_win_manage(void *);
 
 
 int
@@ -1422,6 +1421,9 @@ int dx,dy;
 	assert_ls(gf,LSF_MOVE);
 	gf->move_flag = 1;
 	_set_move_timer(gf);
+#ifdef CACHE_TEST_DEBUG
+ss_printf("CACHE-TEST WAKEUP-WIN-MANAGE %lli\n",(INTEGER64)get_xltime());
+#endif
 	_wakeup_win_manage(gf->radar_ptr);
 
 	return _get_env_seq(gf);
