@@ -42,6 +42,8 @@ GV_RESOURCE_LIST * rl;
 		(wf->small_rct.br.x - wf->small_rct.tl.x);
 	base_measure = gf->win_width * gf->win_height;
 	rl = search_resource_list(gf,wf->draw,0,1);
+	if ( rl == 0 )
+		return;
 	if ( measure > base_measure )
 		rl->weight = weight;
 	else	rl->weight = weight * measure/base_measure;
@@ -180,61 +182,95 @@ int width;
 int yy_index;
 unsigned long * target;
 
+	wf_lock(gf);
+
 	ci_ret = 0;
 	if ( r->tl.x < wf->small_rct.tl.x ) {
-		if ( r->br.x <= wf->small_rct.tl.x )
+		if ( r->br.x <= wf->small_rct.tl.x ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.x = wf->small_rct.tl.x;
 	}
-	if ( r->tl.x >= wf->small_rct.br.x )
+	if ( r->tl.x >= wf->small_rct.br.x ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.x <= wf->small_rct.tl.x )
+	}
+	if ( r->br.x <= wf->small_rct.tl.x ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.x > wf->small_rct.br.x ) {
-		if ( r->tl.x >= wf->small_rct.br.x )
+		if ( r->tl.x >= wf->small_rct.br.x ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.x = wf->small_rct.br.x;
 	}
 	if ( r->tl.y < wf->small_rct.tl.y ) {
-		if ( r->br.y <= wf->small_rct.tl.y )
+		if ( r->br.y <= wf->small_rct.tl.y ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.y = wf->small_rct.tl.y;
 	}
-	if ( r->tl.y >= wf->small_rct.br.y )
+	if ( r->tl.y >= wf->small_rct.br.y ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.y <= wf->small_rct.tl.y )
+	}
+	if ( r->br.y <= wf->small_rct.tl.y ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.y > wf->small_rct.br.y ) {
-		if ( r->tl.y >= wf->small_rct.br.y )
+		if ( r->tl.y >= wf->small_rct.br.y ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.y = wf->small_rct.br.y;
 	}
 	if ( r->tl.x < 0 ) {
-		if ( r->br.x <= 0 )
+		if ( r->br.x <= 0 ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.x = 0;
 	}
-	if ( r->tl.x >= gf->win_width )
+	if ( r->tl.x >= gf->win_width ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.x <= 0 )
+	}
+	if ( r->br.x <= 0 ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.x > gf->win_width ) {
-		if ( r->tl.x >= gf->win_width )
+		if ( r->tl.x >= gf->win_width ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.x = gf->win_width;
 	}
 	if ( r->tl.y < 0 ) {
-		if ( r->br.y <= 0 )
+		if ( r->br.y <= 0 ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.y = 0;
 	}
-	if ( r->tl.y >= gf->win_height )
+	if ( r->tl.y >= gf->win_height ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.y <= 0 )
+	}
+	if ( r->br.y <= 0 ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.y > gf->win_height ) {
-		if ( r->tl.y >= gf->win_height )
+		if ( r->tl.y >= gf->win_height ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.y = gf->win_height;
 	}
 	min_x = r->br.x;
@@ -243,8 +279,6 @@ unsigned long * target;
 	max_y = r->tl.y;
 
 
-	wf_lock(gf);
-
 
 /*
 	if ( _check_exit_flame(gf) ) {
