@@ -21,10 +21,9 @@
 #include	"win_flame.h"
 #include	"memory_debug.h"
 #include	"viewindex.h"
+#include	"radar.h"
 
 void ov_default();
-void _wakeup_win_manage(void *);
-void wakeup_win_manage(void *);
 
 
 typedef struct globe_move_wa_t {
@@ -519,6 +518,9 @@ I_RECT ir;
 	assert_ls(gf,LSF_MOVE);
 	gf->move_flag = 1;
 	_set_move_timer(gf);
+#ifdef CACHE_TEST_DEBUG
+ss_printf("CACHE-TEST WAKEUP-WIN-MANAGE %lli\\n",(INTEGER64)get_xltime());
+#endif
 	_wakeup_win_manage(gf->radar_ptr);
 
 	return _get_env_seq(gf);
