@@ -1402,20 +1402,26 @@ WIN_FLAME * wf;
 			continue;
 		if ( cross_rect_rect(rect,&si->rect) == 0 )
 			continue;
-		x = x_max;
-		xx = rect->br.x - si->rect.tl.x;
-		if ( xx < x )
-			x = xx;
-		xx = si->rect.br.x - rect->tl.x;
-		if ( xx < x )
-			x = xx;
-		y = y_max;
-		yy = rect->br.y - si->rect.tl.y;
-		if ( yy < y )
-			y = yy;
-		yy = si->rect.br.y - rect->tl.y;
-		if ( yy < y )
-			y = yy;
+
+		if ( rect->br.x > si->rect.br.x )
+			x = si->rect.br.x;
+		else	x = rect->br.x;
+		if ( rect->tl.x < si->rect.tl.x )
+			xx = si->rect.tl.x;
+		else	xx = rect->tl.x;
+		x = x - xx;
+		if ( x < 0 )
+			x = 0;
+		if ( rect->br.y > si->rect.br.y )
+			y = si->rect.br.y;
+		else	y = rect->br.y;
+		if ( rect->tl.y < si->rect.tl.y )
+			yy = si->rect.tl.y;
+		else	yy = rect->tl.y;
+		y = y - yy;
+		if ( y < 0 )
+			y = 0;
+
 		if ( x*y*100 >= percent*surf1 )
 			goto end;
 		surf2 = (si->rect.br.x - si->rect.tl.x)*
