@@ -37,6 +37,7 @@ int max_hops;
 XL_SEXP * get_op();
 void acrp_loop_check_1(MP_TASK_ENV * te,MP_TASK_T * t);
 void acrp_loop_check_2(MP_TASK_ENV * te,MP_TASK_T * t);
+extern int loop_check_nos;
 
 void
 test_set_buf(char * str)
@@ -1339,11 +1340,15 @@ INVALID_DATA_SET ds;
 	at = t->arg;
 	gc_push(0,0,"acrp_loop_check");
 	ret = t->sexp;
+
 ss_printf("ALC_2 %ls %s %i\n",at->start_point,s_print_cid(at->target),at->ttl);
+
 	if ( get_type(ret) == XLT_ERROR ) {
+
 ss_printf("ALC_2-1\n");
 print_sexp(s_stdout,ret,0);
 ss_printf("\n");
+
 		er = get_routing_err_code(ret);
 		if ( er == MPE_OVER_TTL || er == MPE_NO_ROUTE ) {
 
@@ -1372,7 +1377,11 @@ ss_printf("*****\n");
 
 	gc_pop(0,0);
 
+	if ( at->access_mode == 1 )
+		loop_check_nos --;
+
 	free_mp_task_t(t);
+	
 }
 
 void
@@ -1381,6 +1390,9 @@ new_loop_check(L_CHAR * start_point,L_CHAR * pri,int hops,int * target,int am)
 ACRP_T * arg;
 MP_TASK_T * tt;
 
+	if ( am == 1 )
+		loop_check_nos ++;
+
 	tt = new_queue_node(sizeof(*tt));
 
 	arg = d_alloc(sizeof(*arg));
