@@ -47,6 +47,7 @@ pid = getpid();
 	init_mp_work();
 	init_lump();
 
+	gc_push(0,0,"main");
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_mp_Exit(gblisp_top_env1);
 	init_server_function(gblisp_top_env0,gblisp_top_env1);
@@ -54,6 +55,7 @@ pid = getpid();
 	init_gv_cpu(gblisp_top_env0);
 
 	init_gbs();
+	gc_pop(0,0);
 
 	memory_watchdog(watchdog_exit);
 
