@@ -106,7 +106,7 @@ INTEGER64 * _dim_code;
 			goto end;
 		}
 		err = 0;
-		n = get_matrix_node(&err,e->c.m,_dim_code,GN_ERROR_NORETRY,0,&ret);
+		n = get_matrix_node(&err,e->c.m,_dim_code,GN_ERROR_NORETRY,0,&ret,0);
 		switch ( err ) {
 		case ME_MATRIX_ERR:
 			ret = get_error(
