@@ -37,10 +37,12 @@ _main(int argc,char ** argv)
 	init_xl(INI_DONTWAITCHI);
 	init_cache();
 
+	gc_push(0,0,"main");
 	init_gbs();
 
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_pdbp_function(gblisp_top_env0,gblisp_top_env1);
+	gc_pop(0,0);
 
 	xl_setup_file(argc,argv);
 	return 0;
