@@ -1976,7 +1976,8 @@ ss_printf("rc.ri.d.retrieve2 = %i\n",ls->rc.ri.d.retrieve2);
 
 	all += ls->wf.draw;
 #ifdef GVHA_LOADING_STATUS
-ss_printf("rc.wf.draw = %i\n",ls->wf.draw);
+ss_printf("rc.wf.draw = %i - Resouce Check %i %i\n",ls->wf.draw,
+	s_check_resource3(),s_check_resource2());
 #endif
 	all += ls->wf.exit;
 #ifdef GVHA_LOADING_STATUS
@@ -2072,8 +2073,11 @@ L_CHAR * site;
 			break;
 */
 	ls = c->sts.current_ls;
-	if ( ls == 0 )
-		er_panic("get_next_target");
+	if ( ls == 0 ) {
+		d_f_ree(base);
+		base = copy_str("http://www.globalbase.org/");
+		return base;
+	}
 	id = get_id_by_crd(g_set,ls->entry_url);
 ss_printf("ENTRY URL %ls == %i\n",ls->entry_url,id);
 	if ( id < 0 ) {
@@ -2734,17 +2738,23 @@ get_gvha_mark_point(GVHA_STATUS * sts,GVHA_FRAME_CACHE * c,GVHA_VCT_SET * vs,I_P
 GB_POINT ret;
 GBVIEW_STATUS wf_sts;
 INDICATE * in;
+XL_SEXP * in_list;
+	in_list = 0;
 	wf_indicate(c->gf,0,display_ptr.x,display_ptr.y,0);
 	locked_wf_status(c->gf,&wf_sts);
 	for ( in = wf_sts.indicate ; in ; in = in ->next ) {
+		in_list = cons(get_string(get_url_str2(&in->url)),in_list);
 		if ( url_cmp_str(&in->url,&vs->vct->h.entry) == 0 )
 			break;
 	}
+	in_list = cons(n_get_symbol("indicate"),in_list);
 	if ( in == 0 ) {
 		sts->status = GVHA_STS_POINT_OUTOF_BOUND;
 		sts->err_message = List(
 				get_integer(display_ptr.x,0),
 				get_integer(display_ptr.y,0),
+				get_string(get_url_str2(&vs->vct->h.entry)),
+				in_list,
 				-1);
 		goto end;
 	}
