@@ -55,7 +55,7 @@ _main(int argc,char ** argv)
 //GBVIEW_STATUS sts;
 extern int exit_mode;
 
-printf("GBVIEW %i\n",get_xltime());
+printf("GBVIEW %i --\n",get_xltime());
 
 	exit_mode = 1;
 
