@@ -42,6 +42,10 @@ FAVT64_ROOT * alloc64_dtree(PDB64 * p,int type);
 U_INTEGER64 search_dtree64(int * errp,int * sizep,FAVT64_ROOT * r,L_CHAR * str,int perfect_flag);
 int dtree64_trace_from_small(int * errp,FAVT64_ROOT * r,int (*func)(),void * work);
 int dtree64_trace_from_large(int * errp,FAVT64_ROOT * r,int (*func)(),void * work);
+int delete_dtree64(int * errp,FAVT64_ROOT * r,L_CHAR * str,U_INTEGER64 old);
+int
+insert_dtree64(int * errp,
+	FAVT64_ROOT * r,L_CHAR * str,U_INTEGER64 old,U_INTEGER64 data);
 
 #endif
 
