@@ -31,6 +31,13 @@ typedef struct ex_matrix {
 #define XI(m,y,x)	((x)+(y)*(m)->h_size)
 #define XD(m,y,x)	((m)->d[XI(m,y,x)])
 
+typedef struct ex_lsm_work {
+	int		from;
+	int		to;
+	EX_MATRIX *	m;
+	EX_MATRIX *	q;
+} EX_LSM_WORK;
+
 EX_MATRIX * new_ex_matrix(int v,int h);
 void free_ex_matrix(EX_MATRIX * m);
 EX_MATRIX * add_ex(EX_MATRIX *,EX_MATRIX *);
@@ -39,5 +46,17 @@ EX_MATRIX * mul_ex(EX_MATRIX *,EX_MATRIX *);
 double inner_ex(int * er,EX_MATRIX *,EX_MATRIX*);
 EX_MATRIX * get_ex_from_sexp(XL_SEXP *);
 XL_SEXP * get_sexp_from_ex(EX_MATRIX *);
+EX_MATRIX * copy_ex(EX_MATRIX * org);
+EX_MATRIX * ex_equation(int * erp,EX_MATRIX * m1,EX_MATRIX * m2,int copy_flag);
+int ex_uppertriangle(EX_MATRIX * m1,EX_MATRIX * m2,int * index);
+EX_MATRIX * ex_get_lsm(int * erp,EX_LSM_WORK * w);
+EX_LSM_WORK* new_ex_lsm(int from,int to);
+int ex_lsm_insert(EX_LSM_WORK * w,EX_MATRIX * p,EX_MATRIX * q);
+int ex_insert_hrect(EX_MATRIX * hrect,EX_MATRIX * p);
+void free_lsm(EX_LSM_WORK * w);
+EX_MATRIX *
+new_ex_matrix_E(int v);
+
+
 
 #endif
