@@ -25,6 +25,7 @@
 /* FAVT Defined */
 
 #define FAVT64_CACHE_SIZE		10000
+#define FAVT64_CACHE_LIFE		120
 
 #ifndef AVT_E_NO_OBJ 
 
@@ -39,7 +40,6 @@
 
 #endif
 
-#define FAVT_CACHE_SIZE	100
 
 typedef struct favt64_header {
 	struct favt64_header *	next;
@@ -50,6 +50,7 @@ typedef struct favt64_header {
 	unsigned short		flags;
 #define FAF_DIRTY	0x0001
 #define FAF_LOCK	0x0002
+	INTEGER64		access_time;
 } FAVT64_HEADER;
 
 typedef struct favt64_ptr {
@@ -95,6 +96,10 @@ BOUND64_LIST *
 favt64_bound_search(
 	int *,
 	FAVT64_ROOT *,FAVT64_NODE *,void *,void *,int,int (*)(),void *);
+BOUND64_LIST *
+favt64_bound_search_reverse(
+	int *,
+	FAVT64_ROOT *,FAVT64_NODE *,void *,void *,int,int (*)(),void *);
 void free64_bound_list(BOUND64_LIST *);
 FAVT64_ROOT * get_root64(int * ,PDB64 *,U_INTEGER64,void (*)());
 void favt64_test(int *,FAVT64_ROOT * p,FAVT64_NODE * a,int (*cmp)());
@@ -162,6 +167,54 @@ l_favt64_bound_search(
 	int	limit,
 	int (*cmp)(),
 	void * cw);
+BOUND64_LIST *
+l_favt64_bound_search_reverse(
+	int * errp,
+	FAVT64_ROOT * p,
+	FAVT64_NODE * a,
+	void *	data_min,
+	void *	data_max,
+	int	limit,
+	int (*cmp)(),
+	void * cw);
 void init_l_favt64();
 
+
+int
+l_write_filespace64(PDB64 * p,void * h);
+int
+l_write_filespace64f(PDB64 * p,U_INTEGER64 fofs,void * h);
+void *
+xx_l_read_filespace64(PDB64 * p,U_INTEGER64 fofs,char *,int);
+#define l_read_filespace64(p,fofs)	xx_l_read_filespace64(p,fofs,__FILE__,__LINE__)
+void *
+xx_l_read_filespace64_header(PDB64 * p,U_INTEGER64 fofs,char *,int);
+#define l_read_filespace64_header xx_l_read_filespace64_header(p,fofs,__FILE__,__LINE__)
+void *
+xx_l_read_filespace64f_header(PDB64 * p,U_INTEGER64 fofs,char *,int);
+#define l_read_filespace64f_header(p,fofs) xx_l_read_filespace64f_header(p,fofs,__FILE__,__LINE__)
+void *
+xx_l_read_filespace64f(PDB64 * p,U_INTEGER64 fofs,char *,int);
+#define l_read_filespace64f(p,fofs) xx_l_read_filespace64f(p,fofs,__FILE__,__LINE__)
+void
+l_free_filespace64(PDB64 * p,U_INTEGER64 fofs);
+INTEGER64
+l_alloc_filespace64(PDB64 * p,PN64_HEADER * h);
+void
+l_truncate_filespace64(PDB64 * p);
+void free_bound_list64(BOUND64_LIST * b);
+#ifndef OPEN_FILESPACE
+PDB64 * l_open_filespace64(char * filename,int oflags,int mode,int flags,...);
+#else
+PDB64* l_open_filespace64(char * filename,int oflags,int mode,
+	int flags,int type,char * encoding);
+#endif
+void *
+l_get_file_record64(U_INTEGER64 * retp,PDB64 * p,short type,
+	INTEGER64 max_size);
+FAVT64_NODE *
+l_favt64_alloc_node(FAVT64_ROOT * rt,
+	void * data,int data_size);
+
+
 #endif
