@@ -19,6 +19,8 @@
 #ifndef ___GEO_H___
 #define ___GEO_H___
 
+#include	"machine/include.h"
+
 typedef struct elipsoid {
 	double		a;
 	double		b;
@@ -41,5 +43,24 @@ utm2bl(double * X_ptr,double * Y_ptr,double lambda,double phi,ELIPSOID * ep);
 
 void
 print_elipsoid(ELIPSOID * ep);
+int load_dted1(short * data,int * org_east,int * org_north,
+		int * line_nos_p,
+	       char *dir_name,char *filename,int cmd);
+
+#define DTED1_BLOCK_SIZE	1201
+#define DTED1_HALF_SIZE		601
+
+/* cmd */
+#define DTED1_CMD_BASE		0x0f
+#define DTED1_CMD_OPT		0xf0
+#define DTED1_CMD_POS		1
+#define DTED1_CMD_DIRECT	2
+#define DTED1_CMD_ROUND		3
+#define DTED1_CMD_INTP		0x10
+
+INTEGER64
+ddmmss_int(INTEGER64 d);
+double
+ddmmss_float(double d);
 
 #endif
