@@ -29,8 +29,9 @@
 
 extern int (*__log_vprintf)(int,int,void *,char*,va_list);
 int
-log_vprintf(int level,int layer,void*,char * fmt,va_list p);
-int log_printf(int level,int layer,void*,char * fmt,...);
+log_vprintf(int level,int layer,void*,const char * fmt,va_list p);
+int log_printf(int level,int layer,void*,const char * fmt,...);
+void sync_log();
 
 /* LOG LEVEL */
 #define LOG_TEST	0
