@@ -23,6 +23,7 @@
 #include	"queue.h"
 #include	"recordlist64.h"
 //#include	"pg_vector.h"
+#include	"ex_matrix.h"
 
 #define NCACHE_SIZE		100
 #define NHASH_SIZE		(4*NCACHE_SIZE+3)
@@ -472,6 +473,17 @@ typedef struct mblk {
 #define MBLK_HASHSIZE		16
 
 
+typedef struct mx_gn {
+	int			gn_tree_node;
+	int			gn_create;
+	int			gn_wait;
+} MX_GN;
+
+typedef struct mx_gn_list {
+	struct mx_gn_list *	next;
+	MX_GN			d;
+} MX_GN_LIST;
+
 typedef struct mx_cache {
 	MATRIX * 		m;
 	MATRIX_NODE *		n;
@@ -485,10 +497,14 @@ typedef struct mx_cache {
 
 	int			mblk_hashsize;
 	int			mblk_logsize;
+	
+	MX_GN			gn;
+	MX_GN_LIST *		gn_stack;
+/*
 	int			gn_tree_node;
 	int			gn_create;
 	int			gn_wait;
-
+*/
 	INTEGER64		miss_hit_cnt;
 	INTEGER64		hit_cnt;
 
@@ -555,6 +571,15 @@ typedef struct mx_cache_param {
 	
 	int			vector_len;
 	unsigned char *		vector_valid;
+
+	/* block vector read write param */
+
+	int *			memory_block_size;
+	int *			memory_block_offset;
+	INTEGER64 *		matrix_max_hrect;
+	unsigned char *		result_valid;
+	unsigned char *		access_valid;
+
 } MX_CACHE_PARAM;
 
 typedef struct mx_dim_code_list {
@@ -902,6 +927,10 @@ int write_mx_cache(MX_CACHE_PARAM * p);
 int read_mx_cache(MX_CACHE_PARAM * p);
 int read_mx_cache_vector(MX_CACHE_PARAM * p);
 int write_mx_cache_vector(MX_CACHE_PARAM * p);
+int
+write_mx_cache_block_vector(MX_CACHE_PARAM * p);
+int
+read_mx_cache_block_vector(MX_CACHE_PARAM * p);
 void mxc_close(MX_CACHE * c);
 
 MX_DIM_CODE_LIST *
@@ -1040,6 +1069,17 @@ INTEGER64
 get_matrix_obj_id(MATRIX * m);
 void
 init_mxObjID(XLISP_ENV * env);
+int
+pop_gn(MX_CACHE * c);
+void
+push_gn(MX_CACHE * c,
+	int gn_tree_node,
+	int gn_create,
+	int gn_wait);
+void *
+convert_ex_matrix_double(EX_MATRIX * ex,MX_CACHE * c);
+int
+mx_hem(MATRIX * m);
 
 
 extern int mx_cache_error;
