@@ -144,7 +144,8 @@ void gc_delete(void * s);
 void gc_delete_nl(void * s);
 void resize_gc_mem_nl(void * old,void *_new);
 
-void lock_mem();
+void d_lock_mem(char *,int);
+#define lock_mem() d_lock_mem(__FILE__,__LINE__)
 void unlock_mem();
 void minit();
 void mfree(void * f);
