@@ -140,6 +140,8 @@ VM_WORK_HEADER *
 get_vm_work_header(RESOURCE * r,VIEW_METHOD_TBL * tbl,int size);
 VM_WORK_HEADER *
 _get_vm_work_header(RESOURCE * r,VIEW_METHOD_TBL * tbl,int size);
+MX_ENTRY * 
+search_mx_entry(MATRIX * m);
 
 
 #endif
