@@ -21,6 +21,7 @@
 
 #include	"gbgraph.h"
 
+#pragma pack(4)
 
 #define NO_PITCH	0x100
 #define DF_BUF	0x2000
@@ -99,6 +100,11 @@ typedef struct acc_pn_header {
 #define PNT_RS_TRIANGLE		((PNT_RS_CACHE_GROUP<<8)|13)
 #define PNT_RS_MAP_POINT_LIST	((PNT_RS_CACHE_GROUP<<8)|14)
 
+#define PNT_SP_GROUP	6
+#define PNT_SP_HEADER		((PNT_SP_GROUP<<8)|0)
+#define PNT_SP_NULL		((PNT_SP_GROUP<<8)|1)
+#define PNT_SP_INFO		((PNT_SP_GROUP<<8)|2)
+#define PNT_SP_REFRESH_QUE	((PNT_SP_GROUP<<8)|128)
 
 /*******************************/
 
@@ -124,6 +130,10 @@ typedef struct pn_file_header {
 } PN_FILE_HEADER;
 #define PN_FILE_HEADER_S	sizeof(PN_FILE_HEADER)
 
+#define PDB_VERSION_2D_DRAW_4	"0.4"
+#define PDB_VERSION_2D_DRAW_5	"0.5"
+#define PDB_VERSION_2D_DRAW_6	"0.6"
+
 typedef struct pn_2d_draw_header {
 	PN_HEADER	h;
 	int		level;
@@ -131,7 +141,7 @@ typedef struct pn_2d_draw_header {
 #define UNIT_SIZE	16
 	char		unit[UNIT_SIZE];
 	unsigned int	fofs;	/* offset to root tree node */
-	GB_RECT		minrect;
+	GB_RECT_F		minrect;
 #define INFO_FILENAME_SIZE	32
 	char		infofile[INFO_FILENAME_SIZE];
 } PN_2D_DRAW_HEADER;
@@ -148,7 +158,7 @@ typedef struct pn_lod_list {
 #define PTR_MAX	16
 typedef struct pn_tree_node {
 	PN_HEADER	h;
-	GB_RECT	r;
+	GB_RECT_F	r;
 	unsigned char	lod_min;
 	unsigned char	lod_max;
 	short	fofs_size;
@@ -193,7 +203,7 @@ typedef struct pn_polygon2d {
 #define PNT_OPEN	2
 	unsigned char	lod_min;
 	unsigned char	lod_max;
-	GB_RECT		minrect;
+	GB_RECT_F		minrect;
 } PN_POLYGON2D;
 #define PN_POLYGON2D_S	sizeof(PN_POLYGON2D)
 
@@ -208,7 +218,7 @@ typedef struct pn_poly_point {
 
 	unsigned char	lod_min;
 	unsigned char	lod_max;
-	GB_POINT	p;
+	GB_POINT_F	p;
 } PN_POLY_POINT;
 #define PN_POLY_POINT_S		sizeof(PN_POLY_POINT)
 
@@ -222,7 +232,7 @@ typedef struct pn_lno_poly_point {
 #define PP_TO_L(x)	(((x)&PP_NO)|((((int)(x))&PP_FLAGS)<<16))
 	unsigned char	lod_min;
 	unsigned char	lod_max;
-	GB_POINT	p;
+	GB_POINT_F	p;
 } PN_LNO_POLY_POINT;
 #define PN_LNO_POLY_POINT_S		sizeof(PN_LNO_POLY_POINT)
 
@@ -283,16 +293,30 @@ typedef struct pn_dtree_data {
 /*******************************/
 
 
-typedef struct floating_index {
+typedef struct _floating_index {
 	unsigned int		fofs;
+/* disable 8 byte alignment 
 	REAL1			d;
+*/
 } FLOATING_INDEX;
 
-typedef struct gb_time_index {
+typedef struct floating_index_buffer {
+	FLOATING_INDEX		fi;
+	char			dummy[sizeof(REAL1)];
+} FLOATING_INDEX_BUFFER;
+
+typedef struct _gb_time_index {
 	unsigned int		fofs;
+/* disable 8 byte alignment 
 	GB_TIME			d;
+*/
 } GB_TIME_INDEX;
 
+typedef struct gb_time_index_buffer {
+	GB_TIME_INDEX		gti;
+	char			dummy[sizeof(GB_TIME)];
+} GB_TIME_INDEX_BUFFER;
+
 typedef struct string_index {
 	unsigned int		fofs;
 	L_CHAR			d[1];
@@ -357,7 +381,7 @@ typedef struct pn_assoc_data {
 typedef struct pn_pmd_header {
 	PN_HEADER	h;
 	char		version[8];
-#define PMD_VERSION	"0.3"
+#define PMD_VERSION	"0.4"
 
 #define PMD_UNIT_LEN	200
 	L_CHAR		unit_path[PMD_UNIT_LEN];
@@ -427,7 +451,7 @@ typedef struct pn_pmd_ofslist {
 
 typedef struct code_index {
 	unsigned int		fofs;
-	GB_RECT			minrect;
+	GB_RECT_F		minrect;
 } CODE_INDEX;
 
 
@@ -832,6 +856,7 @@ typedef struct pn_rs_map_point_list {
 	GB_POINT	dest;
 } PN_RS_MAP_POINT_LIST;
 
+#pragma pack()
 
 /*******************************/
 
