@@ -21,7 +21,7 @@
 
 
 #include	"machine/include.h"
-
+#include	"fa_cache.h"
 
 /* PDB define */
 
@@ -97,6 +97,9 @@ typedef struct pn_header {
 #define PNT_RS_TRIANGLE		((PNT_RS_CACHE_GROUP<<8)|13)
 #define PNT_RS_MAP_POINT_LIST	((PNT_RS_CACHE_GROUP<<8)|14)
 
+
+
+
 #endif
 /* PDB define END */
 
@@ -215,6 +218,7 @@ typedef struct pdb64 {
 #define DT_BOUNDARY	6
 #define DT_POS		0x8000
 #define DT_CMD		0x00ff
+	FAC_INFO	fac;
 } PDB64;
 
 
@@ -237,9 +241,10 @@ typedef struct pn64_file_header {
 
 
 #define FT_MATRIX		31
+#define FT_SPCACHE		32
 
 	char		version[8];
-#define PDB64_VERSION		"64-0.5"
+#define PDB64_VERSION		"64-0.6"
 
 #define ENCODING_SIZE	8
 	char		encoding[ENCODING_SIZE];
@@ -339,6 +344,55 @@ typedef struct pn64_assoc_data {
 
 
 
+/*******************************/
+/*
+	FAVT64 fundamental data structure
+*/
+/*******************************/
+
+
+typedef struct _floating_index64 {
+	U_INTEGER64		fofs;
+	REAL1			d;
+} FLOATING_INDEX64;
+
+typedef struct floating_index64_buffer {
+	FLOATING_INDEX64	fi;
+	char			dummy[sizeof(REAL1)];
+} FLOATING_INDEX64_BUFFER;
+
+typedef struct _gb_time_index64 {
+	U_INTEGER64		fofs;
+	GB_TIME			d;
+} GB_TIME_INDEX64;
+
+typedef struct gb_time_index64_buffer {
+	GB_TIME_INDEX		gti;
+	char			dummy[sizeof(GB_TIME)];
+} GB_TIME_INDEX64_BUFFER;
+
+typedef struct string_index64 {
+	U_INTEGER64		fofs;
+	L_CHAR			d[1];
+} STRING_INDEX64;
+
+#define STRING_IX64_LENGTH(x,y)	((int)&(((STRING_INDEX64*)0)->d[(x)+(y)+2]))
+#define STRING_IX64_LENGTH_1(x)	((int)&(((STRING_INDEX64*)0)->d[(x)+1]))
+
+typedef struct timeout_index64 {
+	U_INTEGER64		fofs;
+	unsigned int		timeout;
+} TIMEOUT_INDEX64;
+
+
+void favt64_string_endian(STRING_INDEX64 * ix,INTEGER64 len);
+void favt64_gb_time_endian(GB_TIME_INDEX64 * ix,INTEGER64 len);
+void favt64_floating_endian(FLOATING_INDEX64 * ix,INTEGER64 len);
+void favt64_timeout_endian(TIMEOUT_INDEX64 * ix,INTEGER64 len);
+
+int favt64_cmp_string_1(STRING_INDEX64 *,STRING_INDEX64 *);
+int favt64_cmp_string_2(STRING_INDEX64 *,STRING_INDEX64 *);
+
 
 #endif
 
