@@ -20,7 +20,6 @@
 
 #ifndef ___PRI_LEVEL_H___
 #define ___PRI_LEVEL_H___
-
 #define PRI_LOG			0
 
 #define PRI_RCACHE		1
@@ -36,6 +35,7 @@
 #define PRI_FETCH_RADAR		3
 
 #define PRI_FETCH_STRONG	4
+#define PRI_FETCH_STRONG_RES_MATRIX	4
 
 
 #define PRI_V_RECONFIG		2
@@ -50,6 +50,8 @@
 #define PRI_TICK		3
 #define PRI_BL			3
 #define PRI_NETWORK		3
+#define PRI_PARSE		5
+#define PRI_GC			5
 
 #define PRI_LOCK		3
 
@@ -61,9 +63,10 @@
 
 #define PRI_FETCH_MOST_STRONG	3
 
+#define PRI_MATRIX_DRAW			3
 #define PRI_DRAW_EXIT		4
 #define PRI_REDRAW		4
-#define PRI_START_DRAW		2
+#define PRI_START_DRAW		4
 #define PRI_DRAW		4
 
 #define PRI_SLEEP_WAIT		5
