@@ -87,7 +87,7 @@ typedef struct sys_queue {
 
 void setup_queue(SYS_QUEUE * q);
 int xx_insert_queue(SYS_QUEUE * q,void * n,int wait_flag,char*,int);
-#define insert_queue(q,n,w)	xx_insert_queue(q,n,w,__FILE__,__LINE__)
+#define insert_queue(q,n,w)	xx_insert_queue(q,n,w,(char*)__FILE__,__LINE__)
 int insert_queue_offset(SYS_QUEUE * q,void * n,int offset,int wait_flag);
 void *
 delete_queue(SYS_QUEUE * q,int (*cond)(),void * work,int wait_flag);
@@ -95,10 +95,10 @@ L_CHAR * touch_qkey(SYS_QUEUE * q);
 void release_qkey(SYS_QUEUE * q,L_CHAR * key);
 int sq_key_cond(SYS_QUEUE *,void *,void *);
 L_CHAR *  xx_get_server_key(URL * u,char * prefix,char *,int);
-#define get_server_key(u,prefix)	xx_get_server_key((u),(prefix),__FILE__,__LINE__)
+#define get_server_key(u,prefix)	xx_get_server_key((u),(prefix),(char*)__FILE__,__LINE__)
 int check_queue(SYS_QUEUE * q,int (*cond)(),void * work);
 void * xx_new_queue_node(int,char*,int);
-#define new_queue_node(s)	xx_new_queue_node((s),__FILE__,__LINE__)
+#define new_queue_node(s)	xx_new_queue_node((s),(char*)__FILE__,__LINE__)
 int get_active_que_thread(SYS_QUEUE*);
 void gc_queue_lock();
 void gc_queue_lock_high();
