@@ -58,6 +58,8 @@
 
 #define DEFAULT_ONMAP_INDICATE_SIZE	60
 
+#define DM_ACCESS_LIFE_TIME	120
+
 /*
 #define MAX_CLIENT_CONNECTION	10
 #define T_MATRIX_SIZE	16
@@ -505,12 +507,14 @@ typedef struct draw_matrix {
 #define DMF_REQUIRED		0x0001
 #define DMF_REQUEST		0x0002
 #define DMF_LOADED		0x0004
+#define DMF_HANDLING		0x0008
+#define DMF_DELETE		0x0010
 	struct draw_matrix *	m[DM_DIM][DM_DIM];
 	union resource *	r;
 	struct draw_matrix *	parent;
 	WF_ID			wfid;
 	int			loop_no;
-	int			access;
+	INTEGER64 		access;
 
 	int			get_handle_time;
 	short			get_level;
