@@ -114,7 +114,6 @@ typedef struct s_header {
 #define WAT_CLOSE	1
 #define WAT_SIGNAL	2
 	int		write_abort_interval;
-#define WAT_DEFAULT_INTERVAL	10
 	INTEGER64	write_in_time;
 	int		write_tid;
 
@@ -300,28 +299,28 @@ STREAM * s_connect_XLoHTTP_2(
 
 void init_stream();
 void xx_s_open(STREAM *,int,int,char*,int);
-#define s_open(s,m,stt)	xx_s_open(s,m,stt,__FILE__,__LINE__)
+#define s_open(s,m,stt)	xx_s_open(s,m,stt,(char*)__FILE__,__LINE__)
 void _xx_s_open(STREAM *,int,int,char*,int);
-#define _s_open(s,m,stt)	_xx_s_open(s,m,stt,__FILE__,__LINE__)
+#define _s_open(s,m,stt)	_xx_s_open(s,m,stt,(char*)__FILE__,__LINE__)
 /*
 int s_close(STREAM *);
 */
 
 int __d_s_close(STREAM *,char *,int);
-#define _s_close(st)	__d_s_close(st,__FILE__,__LINE__)
+#define _s_close(st)	__d_s_close(st,(char*)__FILE__,__LINE__)
 
 int _d_s_close(STREAM *,char *,int);
-#define s_close(st)	_d_s_close(st,__FILE__,__LINE__)
+#define s_close(st)	_d_s_close(st,(char*)__FILE__,__LINE__)
 
 int s_write(STREAM *,void *,int);
 int s_read(STREAM *,void *,int);
-int s_printf(STREAM *,char *,...);
+int s_printf(STREAM *,const char *,...);
 int s_flush(STREAM *);
 int s_push(STREAM *,char);
-int _s_printf(STREAM*,int*,char*,va_list,S_PRINTF_SAT * );
-int ss_printf(char *,...);
-int ss_sprintf(L_CHAR *,char*,...);
-int e_printf(STREAM*,int*,char *,...);
+int _s_printf(STREAM*,int*,const char*,va_list,S_PRINTF_SAT * );
+int ss_printf(const char *,...);
+int ss_sprintf(L_CHAR *,const char*,...);
+int e_printf(STREAM*,int*,const char *,...);
 
 void s_set_cr(STREAM *,int);
 void s_reset_cr(STREAM *);
