@@ -26,7 +26,7 @@
 #include "v/VMenu.h"
 
 typedef struct dialog_io {
-	char*			type;
+	const char*		type;
 #define DIO_MSG_LEN			2
 #define DIO_RMSG_LEN			2
 	L_CHAR *		msg[DIO_MSG_LEN];
@@ -45,7 +45,9 @@ typedef struct dialog_io {
 	void			(*post_func)(struct dialog_io *,XL_SEXP *);
 } DIALOG_IO;
 
+extern "C" {
 extern VWindow * window_list;
+}
 
 class VWindow : public VObject
 {
@@ -90,9 +92,13 @@ class VWindow : public VObject
 	virtual void	win_dialog(DIALOG_IO*io);
 	
 	int				get_category() { return category; }
+/*
 	VCustomizedMenuBar *	get_menu_bar() { 
 		return menu_bar;
 	}
+*/
+	VCustomizedMenuBar *	get_menu_bar();
+
 	void
 	refresh_menu_bar(int c);
 	void
