@@ -238,6 +238,8 @@ typedef	void (*f_wf_insert_action_type)
 typedef struct wf_lock_list {
 	struct wf_lock_list *	next;
 	int			tid;
+	char *			file_name;
+	int			line_no;
 } WF_LOCK_LIST;
 
 typedef struct wf_work_area {
@@ -388,8 +390,10 @@ WIN_FLAME * touch_wf(GBVIEW_FLAME * gf);
 int _check_exit_flame(GBVIEW_FLAME * gf);
 GBVIEW_FLAME * get_gf_from_sf(XL_SYM_FIELD *);
 WIN_FLAME * _get_wf_ptr(GBVIEW_FLAME *,WF_ID);
-int _win_lock(GBVIEW_FLAME * gf,WIN_FLAME * wf);
-int _win_wlock(GBVIEW_FLAME * gf,WIN_FLAME * wf);
+int _xx_win_lock(GBVIEW_FLAME * gf,WIN_FLAME * wf,char *,int);
+#define _win_lock(gf,wf)	_xx_win_lock(gf,wf,__FILE__,__LINE__)
+int _xx_win_wlock(GBVIEW_FLAME * gf,WIN_FLAME * wf,char * ,int);
+#define _win_wlock(gf,wf)	_xx_win_wlock(gf,wf,__FILE__,__LINE__)
 void _win_unlock(GBVIEW_FLAME * gf,WIN_FLAME * wf);
 int win_lock(GBVIEW_FLAME * gf,WIN_FLAME * wf);
 int win_wlock(GBVIEW_FLAME * gf,WIN_FLAME * wf);
