@@ -988,6 +988,9 @@ void init_GetListbaseEnv(XLISP_ENV * env);
 void init_SetListbaseEnv(XLISP_ENV * env);
 void init_DefineEval(XLISP_ENV * env);
 void init_LaunchWWW(XLISP_ENV * env);
+void init_ThreadControl(XLISP_ENV * env);
+void init_ForceGC(XLISP_ENV * env);
+
 
 void kill_thread(XL_SEXP * target);
 
