@@ -363,7 +363,8 @@ invalid_arg:
 		s->h.line,
 		XLE_PROTO_INV_PARAM,
 		l_string(std_cm,"WritingStyle"),
-		n_get_string("invalid stylename argment (Font)"));
+		List(n_get_string("invalid stylename argment (Font)"),
+			_s,-1));
 }
 
 
