@@ -402,9 +402,9 @@ LHM_T * ret;
 		if ( ew->font == ret->font &&
 				ew->size == ret->size  ) {
 			if ( -ew->pic.r.tl.x > ret->assent )
-				ret->desent = -ew->pic.r.tl.x;
+				ret->assent = -ew->pic.r.tl.x;
 			if ( ew->pic.r.br.x > ret->desent )
-				ret->assent = ew->pic.r.br.x;
+				ret->desent = ew->pic.r.br.x;
 			return t;
 		}
 	}
@@ -956,8 +956,11 @@ TR_REFERENCE ref,* _ref;
 AVT_NODE * n;
 int tr_ref_cmp();
 int cc;
-int w,h,i;
+int w,h,i,j;
 int flag;
+I_RECT rr;
+unsigned int * data;
+unsigned char * alpha;
 	ew = el->work;
 	if ( ew == 0 )
 		return;
@@ -972,6 +975,7 @@ int flag;
 			);
 	memcpy(pe->p.pic,ew->pic.pic,len);
 	p = p_addi(p,ew->offset);
+	rr = pe->p.r;
 	pe->p.r.tl = p_addi(p,pe->p.r.tl);
 	pe->p.r.br = p_addi(p,pe->p.r.br);
 	a = _tr_get_attr(ew->attr,TRAT_REFERENCE);
@@ -1012,25 +1016,89 @@ int flag;
 	}
 	if ( pe->flags & PLF_ANCOR ) {
 		if ( (ew->ln_dir & VSD_H) ) {
-			for ( i = 0 ; i < w ; i ++ )
-				pe->data[i + w*(h-1)] = cc;
-			if ( pe->alpha )
+			switch ( rr.br.y ) {
+			case 0:
+				pe->data = d_re_alloc(pe->data,(h+2)*w*sizeof(int));
+				h += 2;
+				pe->p.r.br.y += 2;
+				for ( i = 0 ; i < w ; i ++ ) {
+					pe->data[i + w*(h-2)] = C_TRANSPARENT;
+					pe->data[i + w*(h-1)] = cc;
+				}
+				if ( pe->alpha ) {
+					pe->alpha = d_re_alloc(pe->alpha,(h+2)*w);
+					for ( i = 0 ; i < w ; i ++ ) {
+						pe->alpha[i + w*(h-2)] = 255;
+						pe->alpha[i + w*(h-1)] = 0;
+					}
+				}
+				break;
+			case 1:
+				pe->data = d_re_alloc(pe->data,(h+1)*w*sizeof(int));
+				h += 1;
+				pe->p.r.br.y += 1;
 				for ( i = 0 ; i < w ; i ++ )
-					pe->alpha[i + w*(h-1)] = 0;
+					pe->data[i + w*(h-1)] = cc;
+				if ( pe->alpha ) {
+					pe->alpha = d_re_alloc(pe->alpha,(h+1)*w);
+					for ( i = 0 ; i < w ; i ++ )
+						pe->alpha[i + w*(h-1)] = 0;
+				}
+				break;
+			default:
+				for ( i = 0 ; i < w ; i ++ )
+					pe->data[i + w*(h-1)] = cc;
+				if ( pe->alpha )
+					for ( i = 0 ; i < w ; i ++ )
+						pe->alpha[i + w*(h-1)] = 0;
+				break;
+			}
 		}
 		else if ( (ew->ll_dir & VSD_H) ) {
-			for ( i = 0 ; i < h ; i ++ )
-				pe->data[i*w] = cc;
-			if ( pe->alpha )
-				for ( i = 0 ; i < h ; i ++ )
-					pe->alpha[i*w] = 0;
+			data = d_alloc((w+2)*h*sizeof(int));
+			for ( i = 0 ; i < h ; i ++ ) {
+				for ( j = 0 ; j < w ; j ++ )
+					data[i*(w+2)+j+2] = pe->data[i*w+j];
+				data[i*(w+2)] = cc;
+				data[i*(w+2)+1] = C_TRANSPARENT;
+			}
+			d_f_ree(pe->data);
+			pe->data = data;
+			if ( pe->alpha ) {
+				alpha = d_alloc((w+2)*h);
+				for ( i = 0 ; i < h ; i ++ ) {
+					for ( j = 0 ; j < w ; j ++ )
+						alpha[i*(w+2)+j+2] = pe->alpha[i*w+j];
+					alpha[i*(w+2)] = 0;
+					alpha[i*(w+2)+1] = 255;
+				}
+				d_f_ree(pe->alpha);
+				pe->alpha = alpha;
+			}
+			pe->p.r.tl.x -= 2;
 		}
 		else {
-			for ( i = 0 ; i < h ; i ++ )
-				pe->data[i*w + w-1] = cc;
-			if ( pe->alpha )
-				for ( i = 0 ; i < h ; i ++ )
-					pe->alpha[i*w + w-1] = 0;
+			data = d_alloc((w+2)*h*sizeof(int));
+			for ( i = 0 ; i < h ; i ++ ) {
+				for ( j = 0 ; j < w ; j ++ )
+					data[i*(w+2)+j] = pe->data[i*w+j];
+				data[i*(w+2) + w-2] = C_TRANSPARENT;
+				data[i*(w+2) + w-1] = cc;
+			}
+			d_f_ree(pe->data);
+			pe->data = data;
+			if ( pe->alpha ) {
+				alpha = d_alloc((w+2)*h);
+				for ( i = 0 ; i < h ; i ++ ) {
+					for ( j = 0 ; j < w ; j ++ )
+						alpha[i*(w+2)+j] = pe->alpha[i*w+j];
+					alpha[i*(w+2) + w-2] = 255;
+					alpha[i*(w+2) + w-1] = 0;
+				}
+				d_f_ree(pe->alpha);
+				pe->alpha = alpha;
+			}
+			pe->p.r.br.x += 2;
 		}
 	}
 	d_f_ree(pe->p.pic);
