@@ -314,6 +314,7 @@ void * ret;
 MEM_HEADER * mh;
 MEM_LIST *ml;
 int old_size;
+char * d;
 	LOCK;
 	if ( ptr == 0 ) {
 		UNLOCK;
@@ -330,6 +331,10 @@ int old_size;
 		er_panic_x("d_re_alloc");
 	mh = realloc(mh,size + sizeof(*mh));
 	if ( mh ) {
+		if ( old_size < size ) {
+			d = (char*)mh;
+			memset(d+old_size+sizeof(*mh),0,size-old_size);
+		}
 		ml->size = ml->size - old_size + size;
 		mh->size = size;
 		ret = mh + 1;
