@@ -17,6 +17,8 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <wchar.h>
+#include "utils.h"
 #include "addrdb.h"
 #include "associate.h"
 #include "memory_debug.h"
@@ -81,7 +83,7 @@ static BOOL is_kanji_number_sjis(const char*code){
 	};
 	
 	for(i=0; i<11; ++i){
-		if(strncmp(code, kanji_number[i], 2)==0){
+		if(strncmp(code, (char*)kanji_number[i], 2)==0){
 			return TRUE;
 		}
 	}
@@ -147,8 +149,8 @@ static int addrdb_init_jp(ADDRDB_LOCALE* locale, ADDRDB *db){
 		Katakana -> Hiragana
 		A- -> - 
 	*/
-	const unsigned short hiragana_sjis = 0x829f; /* '' */
-	const unsigned short katakana_sjis = 0x8340; /* '@' */
+//	const unsigned short hiragana_sjis = 0x829f; /* '' */
+//	const unsigned short katakana_sjis = 0x8340; /* '@' */
 	const unsigned short hiragana_uni = 0x3041; /* '' */
 	const unsigned short katakana_uni = 0x30a1; /* '@' */
 	
@@ -502,6 +504,7 @@ error_exit:
 	return -1;
 }
 
+#ifdef NOTUSED_FUNC
 static void print_code_table(wchar_t *data[][2], int size){
 	size_t i,j;
 	for(i=0; i<(size_t)size; ++i){
@@ -524,6 +527,7 @@ static void print_code_table(wchar_t *data[][2], int size){
 		printf("},\n");
 	}
 }
+#endif
 
 
 ADDRDB_LOCALE *addrdb_kokudo_get_locale(){
@@ -660,6 +664,7 @@ ADDRDB_LOCALE *addrdb_kokudo_get_locale(){
 }
 
 #include <math.h>
+#ifdef NOTUSED_FUNC
 static BOOL float_eq(double lhs, double rhs){
 	if(fabs(lhs-rhs) < 0.001){
 		return TRUE;
@@ -667,7 +672,6 @@ static BOOL float_eq(double lhs, double rhs){
 	return FALSE;
 }
 
-
 static double get_longtude(XL_SEXP *s){
 	return ((XL_FLOAT*)car(cdr(cdr(cdr(cdr(s))))))->data;
 }
@@ -675,7 +679,7 @@ static double get_longtude(XL_SEXP *s){
 static double get_latitude(XL_SEXP *s){
 	return ((XL_FLOAT*)car(cdr(cdr(cdr(s)))))->data;
 }
-
+#endif
 
 typedef struct kokudo_marge_info
 {
@@ -786,7 +790,7 @@ int i;
 	if(!(dir = opendir(directory))){
 		return 0;
 	}
-	while ( de = readdir(dir) ) {
+	while ( (de = readdir(dir)) != 0 ) {
 		if(filter && (!filter(de->d_name))){
 			continue;
 		}
@@ -1076,42 +1080,42 @@ KOKUDO_RECORD rec;
 	
 	/* s{ */
 	cell=record->head;
-	rec.todofuken = cell->value;
+	rec.todofuken = (char*)cell->value;
 
 	/* s撬 */
 	cell = cell->next;
-	rec.shikucyoson = cell->value;
+	rec.shikucyoson = (char*)cell->value;
 	
 	/* 厚E */
 	cell = cell->next;
-	ohaza = cell->value;
+	ohaza = (char*)cell->value;
 	
 	/* X敄En */
 	cell = cell->next;
-	rec.chiban = cell->value;
+	rec.chiban = (char*)cell->value;
 	
 	/* Wnԍ */
 	cell = cell->next;
-	rec.coordinate_system = atoi(cell->value);
+	rec.coordinate_system = atoi((char*)cell->value);
 	
 	/* wW */
 	cell = cell->next;
-	rec.x = atof(cell->value);
+	rec.x = atof((char*)cell->value);
 
 	/* xW */
 	cell = cell->next;
-	rec.y = atof(cell->value);
+	rec.y = atof((char*)cell->value);
 	
 	/* ܓx */
 	cell = cell->next;
-	rec.latitude = atof(cell->value);
+	rec.latitude = atof((char*)cell->value);
 	
 	/* ox */
 	cell = cell->next;
-	rec.longitude = atof(cell->value);
+	rec.longitude = atof((char*)cell->value);
 	
 	/* ڂƑ厚𕪉 */
-	if(strlen(ohaza)>5 && strcmp(ohaza + (strlen(ohaza)-4), cyome_static) == 0){
+	if(strlen(ohaza)>5 && strcmp(ohaza + (strlen(ohaza)-4), (char*)cyome_static) == 0){
 		int i;
 		for(i=strlen(ohaza)-6; i>0; i-=2){
 			if(!is_kanji_number_sjis(&ohaza[i])){
@@ -1164,6 +1168,7 @@ CSV_RECORD *record;
 }
 
 
+#ifdef TEST_ENABLE
 void addrdb_test()
 {
 	ADDRDB *db;
@@ -1247,4 +1252,5 @@ void addrdb_test()
 	addrdb_convert_csv_batch(db, "addrdb_test/source_csv", "addrdb_test/dest_csv", "Shift_JIS", 0);
 	
 	addrdb_close(db);
-}
\ No newline at end of file
+}
+#endif
