@@ -16,6 +16,8 @@
 **********************************************************************/
 
 
+#define OPEN_FILESPACE
+
 #include	"favt64.h"
 #include	"task.h"
 #include	"filespace64.h"
@@ -32,6 +34,28 @@ init_l_favt64()
 	l_favt64_lock = new_lock(LL_FAVT64);
 }
 
+void *
+l_get_file_record64(U_INTEGER64 * retp,PDB64 * p,short type,
+	INTEGER64 max_size)
+{
+void * ret;
+	lock_task(l_favt64_lock);
+	ret = get_file_record64(retp, p, type, max_size);
+	unlock_task(l_favt64_lock,"");
+	return ret;
+}
+
+PDB64*
+l_open_filespace64(char * filename,int oflags,int mode,
+	int flags,int type,char * encoding)
+{
+PDB64 * ret;
+	lock_task(l_favt64_lock);
+	ret = open_filespace64(filename,oflags,mode,flags,type,encoding);
+	unlock_task(l_favt64_lock,"");
+	return ret;
+}
+
 
 FAVT64_NODE *
 l_favt64_alloc_node(FAVT64_ROOT * rt,
@@ -180,6 +204,84 @@ l_close_filespace64(PDB64 * p)
 	unlock_task(l_favt64_lock,"unlock");
 }
 
+int
+l_write_filespace64(PDB64 * p,void * h)
+{
+int ret;
+	lock_task(l_favt64_lock);
+	ret = write_filespace64(p,h);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+int
+l_write_filespace64f(PDB64 * p,U_INTEGER64 fofs,void * h)
+{
+int ret;
+	lock_task(l_favt64_lock);
+	ret = write_filespace64f(p,fofs,h);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+void *
+xx_l_read_filespace64(PDB64 * p,U_INTEGER64 fofs,char * file,int line)
+{
+void * ret;
+	lock_task(l_favt64_lock);
+	ret = xx_read_filespace64(p,fofs,file,line);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+void *
+xx_l_read_filespace64_header
+	(PDB64 * p,U_INTEGER64 fofs,char * file,int line)
+{
+void * ret;
+	lock_task(l_favt64_lock);
+	ret = xx_read_filespace64_header(p,fofs,file,line);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+void *
+xx_l_read_filespace64f_header
+	(PDB64 * p,U_INTEGER64 fofs,char * file,int line)
+{
+void * ret;
+	lock_task(l_favt64_lock);
+	ret = xx_read_filespace64f_header(p,fofs,file,line);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+void *
+xx_l_read_filespace64f(PDB64 * p,U_INTEGER64 fofs,char * file,int line)
+{
+void * ret;
+	lock_task(l_favt64_lock);
+	ret = xx_read_filespace64f(p,fofs,file,line);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+void
+l_free_filespace64(PDB64 * p,U_INTEGER64 fofs)
+{
+	lock_task(l_favt64_lock);
+	free_filespace64(p,fofs);
+	unlock_task(l_favt64_lock,"unlock");
+}
+INTEGER64
+l_alloc_filespace64(PDB64 * p,PN64_HEADER * h)
+{
+INTEGER64 ret;
+	lock_task(l_favt64_lock);
+	ret = alloc_filespace64(p,h);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
 
 BOUND64_LIST *
 l_favt64_bound_search(
@@ -207,6 +309,33 @@ BOUND64_LIST * ret;
 	return ret;
 }
 
+BOUND64_LIST *
+l_favt64_bound_search_reverse(
+	int * errp,
+	FAVT64_ROOT * p,
+	FAVT64_NODE * a,
+	void *	data_min,
+	void *	data_max,
+	int	limit,
+	int (*cmp)(),
+	void * cw)
+{
+BOUND64_LIST * ret;
+	lock_task(l_favt64_lock);
+	ret = favt64_bound_search_reverse(
+		errp,
+		p,
+		a,
+		data_min,
+		data_max,
+		limit,
+		cmp,
+		cw);
+	unlock_task(l_favt64_lock,"unlock");
+	return ret;
+}
+
+
 
 
 int
@@ -304,6 +433,13 @@ int ret;
 }
 
 
+void
+l_truncate_filespace64(PDB64 * p)
+{
+	lock_task(l_favt64_lock);
+	truncate_filespace64(p);
+	unlock_task(l_favt64_lock,"unlock");
+}
 
 
 
