@@ -208,7 +208,7 @@ int tid;
 ss_printf("_start_file_access %ls %p\n",m->filename,m);
 
 	encoding = l_string(std_cm,"utf8");
-	w->pdb_fd = open_filespace64(
+	w->pdb_fd = l_open_filespace64(
 		n_string(std_cm,m->filename),
 		w->oflags,0644,
 		PF_USEFREELIST,FT_MATRIX,encoding);
@@ -708,7 +708,7 @@ ss_printf("load_matrix_header-1 %i %p %p\n",err,m->file_work,m);
 	w = m->file_work;
 
 	ofs = 0;
-	h = get_file_record64((U_INTEGER64*)&ofs,
+	h = l_get_file_record64((U_INTEGER64*)&ofs,
 		w->pdb_fd,PNT_MX_HEADER,0);
 
 	if ( h )
@@ -749,7 +749,7 @@ ss_printf("load_matrix_header-1 %i\n",err);
 		return err;
 	}
 
-	h = get_file_record64((U_INTEGER64*)&w->header_fofs,
+	h = l_get_file_record64((U_INTEGER64*)&w->header_fofs,
 		w->pdb_fd,PNT_MX_HEADER,0);
 	if ( h == 0 ) {
 		l_close_filespace64(w->pdb_fd);
@@ -848,6 +848,17 @@ er_panic("load");
 		else	info.default_data = 0;
 		info.default_data_fofs = ch.default_data_fofs;
 		set_matrix_channel_info(m,i,&info);
+		
+		if ( info.default_data ) {
+			if ( info.data_type->parent )
+				(*info.data_type->parent->free_data)
+					(info.data_type->parent,
+					info.default_data);
+			else
+				(*info.data_type->free_data)
+					(info.data_type,
+					info.default_data);
+		}
 	}
 
 
@@ -907,8 +918,10 @@ MX_FILE_WORK * w;
 			size = h2->size;
 			if ( h->size != size ) {
 				l_free_filespace64(w->pdb_fd,fofs);
+				d_f_ree(h);
 				goto alloc;
 			}
+			d_f_ree(h);
 		}
 	}
 	change_endian_header64(rl->data);
@@ -969,9 +982,11 @@ PN64_MX_DATA_2 * mx;
 			h2 = (PN64_HEADER*)rl->data;
 			size = h2->size;
 			if ( h->size != size ) {
+				d_f_ree(h);
 				l_free_filespace64(w->pdb_fd,fofs);
 				goto alloc;
 			}
+			d_f_ree(h);
 		}
 	}
 	change_endian_header64(&mx->h);
@@ -1070,6 +1085,7 @@ ss_printf("load_raw_matrix_node1\n");
 	if ( n->h.type != PNT_MX_NODE ) {
 		finish_file_access(m,0);
 ss_printf("load_raw_matrix_node2 = %i\n",n->h.type);
+		d_f_ree(n);
 		return -2;
 	}
 	*ret = *n;
@@ -1659,6 +1675,7 @@ debug = 1;
 			dc,ptr - (unsigned char*)dc);
 		if ( fn == 0 ) {
 			w->favt64_err = -1;
+			free_recordlist64(rl);
 			finish_file_access(m,0);
 			return -1;
 		}
@@ -1678,6 +1695,8 @@ debug = 1;
 	l_write_filespace64f(w->pdb_fd,n->fofs,rl->data);
 	wakeup_task((int)n);
 
+	free_recordlist64(rl);
+
 	finish_file_access(m,0);
 	return 0;
 }
@@ -1694,7 +1713,7 @@ MX_FILE_WORK * w;
 	w = m->file_work;
 	w->subheader.flags &= ~MXF_WRITE;
 	save_subheader(m,1);
-ss_printf("CLOSE DETECT FLAG %x\n",m->flags);
+//ss_printf("CLOSE DETECT FLAG %x\n",m->flags);
 	if ( m->flags & MXF_ERR_DETECTED ) {
 		l_truncate_filespace64(w->pdb_fd);
 	}
@@ -1951,6 +1970,7 @@ STREAM * st;
 				l_string(std_cm,"sexp_commands"));
 			for ( s = ret ; get_type(s) == XLT_PAIR ; s = cdr(s) );
 			cals[i] = ret;
+			d_f_ree(c);
 		}
 	}
 	finish_file_access(m,0);
