@@ -2084,4 +2084,35 @@ end:
 	return ret;
 }
 
+void *
+convert_ex_matrix_double(EX_MATRIX * ex,MX_CACHE * c)
+{
+int ix[2];
+int i,j;
+MATRIX_DH_SET ds;
+MATRIX_ALLOC_VECTOR_PARAM vp;
+double zero;
+void * ret;
+double * ret_ptr;
+	ix[0] = ex->h_size;
+	ix[1] = ex->v_size;
+	zero = 0;
+	vp.dim = 2;
+	vp.ix_size = ix;
+	vp.default_data = &zero;
+	vp.mxc = c;
+	ret = mxt_alloc_vector(
+			&mx_type_double_v,
+			MD_CALLOC,
+			&vp,0);
+	get_matrix_dh_set(&ds,ret);
+	ret_ptr = ds.offset;
+			
+	for ( i = 0 ; i < ex->v_size ; i ++ )
+		for ( j = 0 ; j < ex->h_size ; j ++ ) {
+			ret_ptr[j + i * ex->h_size] = XD(ex,i,j);
+		}
+	return ret;
+}
+
 
