@@ -284,18 +284,21 @@ int _p;
 		src_inc[i] = 1<<(m->dim_divide[i]*parent);
 		n_size *= src_inc[i];
 		dest_inc[i] = 1;
-		dest_ix[i] = ofs[i];
 	}
 	for ( ; ; ) {
 		memcpy(avg_ix,src_ix,sizeof(int)*dim);
 		avg = 0;
 		for ( i = 0 ; i < dim ; i ++ ) {
 			avg_size[i] = src_ix[i] + src_inc[i];
-			dest_ix[i] = src_ix[i]>>(m->dim_divide[i]*parent);
+			if ( avg_size[i] >= h_src.ix[i] )
+				avg_size[i] = h_src.ix[i];
+			dest_ix[i] = ofs[i] + (src_ix[i]>>(m->dim_divide[i]*parent));
 		}
+		n_size = 0;
 		for ( ; ; ) {
 			p1 = &((BASE_TYPE*)h_src.offset)[get_seq_from_ix(avg_ix,h_src.ix,dim)];
 			avg += *p1;
+			n_size ++;
 			if ( inc_ix(avg_ix,src_ix,dest_inc,avg_size,dim) )
 				break;
 		}
