@@ -311,8 +311,6 @@ int _p;
 	if ( h_dest.hd->dim != m->p.dim )
 		return -1;
 	lev = dim_code[0];
-	if ( lev <= 0 )
-		return -1;
 	ofs = d_alloc(sizeof(int)*m->p.dim);
 	for ( i = 0 ; i < m->p.dim ; i ++ ) {
 		_p = m->dim_divide[i]*parent;
@@ -336,18 +334,21 @@ int _p;
 		src_inc[i] = 1<<(m->dim_divide[i]*parent);
 		n_size *= src_inc[i];
 		dest_inc[i] = 1;
-		dest_ix[i] = ofs[i];
 	}
 	for ( ; ; ) {
 		memcpy(avg_ix,src_ix,sizeof(int)*dim);
 		avg = 0;
 		for ( i = 0 ; i < dim ; i ++ ) {
 			avg_size[i] = src_ix[i] + src_inc[i];
-			dest_ix[i] = src_ix[i]>>(m->dim_divide[i]*parent);
+			if ( avg_size[i] >= h_src.ix[i] )
+				avg_size[i] = h_src.ix[i];
+			dest_ix[i] = ofs[i] + (src_ix[i]>>(m->dim_divide[i]*parent));
 		}
+		n_size = 0;
 		for ( ; ; ) {
 			p1 = &((BASE_TYPE*)h_src.offset)[get_seq_from_ix(avg_ix,h_src.ix,dim)];
 			avg += *p1;
+			n_size ++;
 			if ( inc_ix(avg_ix,src_ix,dest_inc,avg_size,dim) )
 				break;
 		}
