@@ -3136,32 +3136,32 @@ double zero = 0;
 	ss_printf("PHASE 1(4);;\n");
 
 	write_c.m = read_c.m = mtx;
-	write_c.gn_tree_node = GN_TREE;
-	write_c.gn_create = GN_LIST_CREATE;
-	write_c.gn_wait = GN_LIST_CREATE;
+	write_c.gn.gn_tree_node = GN_TREE;
+	write_c.gn.gn_create = GN_LIST_CREATE;
+	write_c.gn.gn_wait = GN_LIST_CREATE;
 	write_c.access_ch = &access_ch[0];
 	write_c.ds_len = dest_dim + 1;
 	mxc_setup(&write_c);
 
 	write_delta_c.m = read_c.m = mtx;
-	write_delta_c.gn_tree_node = GN_NODE;
-	write_delta_c.gn_create = GN_ERROR_NORETRY;
-	write_delta_c.gn_wait = GN_ERROR_NORETRY;
+	write_delta_c.gn.gn_tree_node = GN_NODE;
+	write_delta_c.gn.gn_create = GN_ERROR_NORETRY;
+	write_delta_c.gn.gn_wait = GN_ERROR_NORETRY;
 	write_delta_c.access_ch = &access_delta_ch[0];
 	write_delta_c.ds_len = mtx->total_levels + 1;
 	mxc_setup(&write_delta_c);
 
 	write_rr_c.m = read_c.m = mtx;
-	write_rr_c.gn_tree_node = GN_NODE;
-	write_rr_c.gn_create = GN_ERROR_NORETRY;
-	write_rr_c.gn_wait = GN_ERROR_NORETRY;
+	write_rr_c.gn.gn_tree_node = GN_NODE;
+	write_rr_c.gn.gn_create = GN_ERROR_NORETRY;
+	write_rr_c.gn.gn_wait = GN_ERROR_NORETRY;
 	write_rr_c.access_ch = &rr_ch;
 	write_rr_c.ds_len = 1;
 	mxc_setup(&write_rr_c);
 
-	read_c.gn_tree_node = GN_NODE;
-	read_c.gn_create = GN_ERROR_NORETRY;
-	read_c.gn_wait = GN_ERROR_NORETRY;
+	read_c.gn.gn_tree_node = GN_NODE;
+	read_c.gn.gn_create = GN_ERROR_NORETRY;
+	read_c.gn.gn_wait = GN_ERROR_NORETRY;
 	read_c.access_ch = &access_ch[0];
 	read_c.ds_len = dest_dim + 1;
 	read_c2 = read_c;
@@ -3170,9 +3170,9 @@ double zero = 0;
 
 
 	write_hem_c.m = read_c.m = mtx;
-	write_hem_c.gn_tree_node = GN_NODE;
-	write_hem_c.gn_create = GN_ERROR_NORETRY;
-	write_hem_c.gn_wait = GN_ERROR_NORETRY;
+	write_hem_c.gn.gn_tree_node = GN_NODE;
+	write_hem_c.gn.gn_create = GN_ERROR_NORETRY;
+	write_hem_c.gn.gn_wait = GN_ERROR_NORETRY;
 	write_hem_c.access_ch = &access_ch[0];
 	write_hem_c.ds_len = dest_dim + 1;
 	mxc_setup(&write_hem_c);
