@@ -46,13 +46,15 @@ typedef struct gm_ptr {
 typedef struct gm_line {
 	struct gm_line *	next;
 	GM_PTR *		point[2];
+	struct gm_triangle *	tri[2];
 } GM_LINE;
 
 
 typedef struct gm_triangle {
 	struct gm_triangle *	next;
 	GM_PTR *		point[3];
-	float			round;
+	double			round;
+	GM_LINE *		line[3];
 } GM_TRIANGLE;
 
 
@@ -323,24 +325,33 @@ int retry_flag;
 		retry_flag = 0;
 	retry:
 		for (  ; p2 ; p2 = p2->next , tt2 ++ ) {
-ss_printf("LOOP (%i) %i %i  \r",total,tt1,tt2);
+/*
+ss_printf("LOOP (%i) %i %i  \n",total,tt1,tt2);
+*/
 			if ( p2 == p1 )
 				continue;
 			if ( retry_flag == 0 &&
 					check_amount(p1,p2,0,w) )
 				continue;
 			for ( p3 = p2->next ; p3 ; p3 = p3->next ) {
+//ss_printf("FIT_name 1 = %p %p %p\n",p1,p2,p3);
 				if ( p3 == p1 )
 					continue;
+//ss_printf("FIT-1 = %p %p %p\n",p1,p2,p3);
 				if ( retry_flag == 0 &&
 						check_amount(p1,p2,p3,w) )
 					continue;
+/*
 if ( fit_pattern == 2 || fit_cnt )
-ss_printf("\t\t\t\t\t\t\t%i \r",++fit_cnt );
+ss_printf("\t\t\t\t\t\t\t%i \n",++fit_cnt );
+*/
+//ss_printf("FIT-2 = %p %p %p\n",p1,p2,p3);
 				if ( check_direction(p1,p2,p3) < 0 )
 					continue;
+//ss_printf("FIT-3 = %p %p %p\n",p1,p2,p3);
 				if ( check_inpoint(p1,p2,p3,ptr) < 0 )
 					continue;
+//ss_printf("FIT-4 = %p %p %p\n",p1,p2,p3);
 				fit_pattern = 1;
 				t1 = d_alloc(sizeof(*t1));
 				t1->point[0] = p1;
@@ -609,6 +620,9 @@ int
 triangle_conflict(SELECT_SET * ss,GM_TRIANGLE * t)
 {
 GM_LINE * ll;
+GM_TRIANGLE * t1;
+int index[3];
+int i,j;
 	for ( ll = ss->line ; ll ; ll = ll->next ) {
 		switch ( line_conflict(
 			ll->point[0],
@@ -616,6 +630,10 @@ GM_LINE * ll;
 			t->point[0],
 			t->point[1]) ) {
 		case -1:
+/*
+ss_printf("CONFLICT-1 %p %p %p\n",t->point[0],t->point[1],t->point[2]);
+ss_printf("CONFLICT-LINE %p %p %p\n",ll->point[0],ll->point[1]);
+*/
 			return -1;
 		case 0:
 		case 1:
@@ -627,6 +645,10 @@ GM_LINE * ll;
 			t->point[1],
 			t->point[2]) ) {
 		case -1:
+/*
+ss_printf("CONFLICT-2 %p %p %p\n",t->point[0],t->point[1],t->point[2]);
+ss_printf("CONFLICT-LINE %p %p %p\n",ll->point[0],ll->point[1]);
+*/
 			return -1;
 		case 0:
 		case 1:
@@ -638,38 +660,67 @@ GM_LINE * ll;
 			t->point[0],
 			t->point[2]) ) {
 		case -1:
+/*
+ss_printf("CONFLICT-3 %p %p %p\n",t->point[0],t->point[1],t->point[2]);
+ss_printf("CONFLICT-LINE %p %p %p\n",ll->point[0],ll->point[1]);
+*/
 			return -1;
 		case 0:
 		case 1:
 			break;
 		}
 	}
+	for ( t1 = ss->tri ; t1 ; t1 = t1->next ) {
+		index[0] = index[1] = index[2] = -1;
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			for ( j = 0 ; j < 3 ; j ++ ) {
+				if ( t1->point[i] == t->point[j] )
+					index[i] = j;
+			}
+		}
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			if ( index[i] < 0 )
+				goto  ok;
+		}
+/*
+ss_printf("CONFLICT-4 %p %p %p\n",t->point[0],t->point[1],t->point[2]);
+*/
+		return -1;
+	}
+ok:
 	return 0;
 }
 
-void
-set_ssline(SELECT_SET * ss,GM_PTR * p1,GM_PTR * p2)
+GM_LINE *
+set_ssline(SELECT_SET * ss,GM_PTR * p1,GM_PTR * p2,GM_TRIANGLE * t)
 {
 GM_LINE * ll;
 	for ( ll = ss->line ; ll ; ll = ll->next ) {
 		if ( ll->point[0] == p1 &&
-				ll->point[1] == p2 )
-			return;
+				ll->point[1] == p2 ) {
+			return ll;
+		}
 		if ( ll->point[1] == p1 &&
-				ll->point[0] == p2 )
-			return;
+				ll->point[0] == p2 ) {
+			return ll;
+		}
 	}
 	ll = d_alloc(sizeof(*ll));
 	ll->point[0] = p1;
 	ll->point[1] = p2;
+	ll->tri[0] = 0;
+	ll->tri[1] = 0;
 	ll->next = ss->line;
 	ss->line = ll;
+	
+	return ll;
 }
 
 void
 check_conflict(SELECT_SET * ss,GM_TRIANGLE * t)
 {
 GM_TRIANGLE * t1;
+int i,j;
 	for ( ; t ; ) {
 		t1 = t;
 		t = t->next;
@@ -680,13 +731,260 @@ GM_TRIANGLE * t1;
 		else {
 			t1->next = ss->tri;
 			ss->tri = t1;
-			set_ssline(ss,t1->point[0],t1->point[1]);
-			set_ssline(ss,t1->point[2],t1->point[1]);
-			set_ssline(ss,t1->point[0],t1->point[2]);
+			t1->line[0] = set_ssline(ss,t1->point[0],t1->point[1],t1);
+			t1->line[1] = set_ssline(ss,t1->point[2],t1->point[1],t1);
+			t1->line[2] = set_ssline(ss,t1->point[0],t1->point[2],t1);
+		}
+	}
+	for ( t = ss->tri ; t ; t = t->next ) {
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			for ( j = 0 ; j < 2 ; j ++ ) {
+				if ( t->line[i]->tri[j] )
+					continue;
+				t->line[i]->tri[j] = t;
+				goto ok;
+			}
+			er_panic("check_conflict");
+		ok:	;
 		}
 	}
 }
 
+
+double
+calc_tri_distance(GM_LINE * ll,int *il_t1,int *il_t2)
+{
+GM_TRIANGLE * t1,*t2;
+AFFEN2D a1,a2;
+int er;
+int i,j;
+double ret,s;
+	if ( il_t1 )
+		*il_t1 = 0;
+	if ( il_t2 )
+		*il_t2 = 0;
+	t1 = ll->tri[0];
+	t2 = ll->tri[1];
+	if ( t1 == 0 || t2 == 0 )
+		return 0;
+	er = get_matrix(&a1,
+		t1->point[0]->src_ptr,	t1->point[0]->dest_ptr,
+		t1->point[1]->src_ptr,	t1->point[1]->dest_ptr,
+		t1->point[2]->src_ptr,	t1->point[2]->dest_ptr
+		);
+	if (er < 0 ) {
+		if ( il_t1 )
+			*il_t1 = -1;
+		return -1;
+	}
+	if ( il_t1 )
+		*il_t1 = 1;
+	er = get_matrix(&a2,
+		t2->point[0]->src_ptr,	t2->point[0]->dest_ptr,
+		t2->point[1]->src_ptr,	t2->point[1]->dest_ptr,
+		t2->point[2]->src_ptr,	t2->point[2]->dest_ptr
+		);
+	if (er < 0 ) {
+		if ( il_t2 )
+			*il_t2 = -1;
+		return -1;
+	}
+	if ( il_t2 )
+		*il_t2 = 1;
+	ret = 0;
+	for ( i = 0 ; i < 2 ; i ++ ) {
+		for ( j = 0 ; j < 2 ; j ++ ) {
+			s = a1.matrix[i][j] - a2.matrix[i][j];
+			ret += s*s;
+		}
+	}
+	return ret;
+}
+
+double
+tri_distance_delta(GM_LINE * ll,int *il_t1,int *il_t2)
+{
+GM_LINE *ll1[2],*ll2[2];
+GM_TRIANGLE * t1,*t2;
+int i,j;
+double ret,s;
+	t1 = ll->tri[0];
+	t2 = ll->tri[1];
+	if ( t1 == 0 || t2 == 0 )
+		return -1;
+	j = 0;
+	ll1[0] = ll1[1] = 0;
+	ll2[0] = ll2[1] = 0;
+	for ( i = 0 ; i < 3 ; i ++ ) {
+		if ( (t1->line[i]->point[0] == ll->point[0] &&
+				t1->line[i]->point[1] == ll->point[1]) ||
+				(t1->line[i]->point[0] == ll->point[1] &&
+				t1->line[i]->point[1] == ll->point[0])
+					)
+			continue;
+		ll1[j] = t1->line[i];
+		j ++;
+	}
+	j = 0;
+	for ( i = 0 ; i < 3 ; i ++ ) {
+		if ( (t2->line[i]->point[0] == ll->point[0] &&
+				t2->line[i]->point[1] == ll->point[1]) ||
+				(t2->line[i]->point[0] == ll->point[1] &&
+				t2->line[i]->point[1] == ll->point[0])
+					)
+			continue;
+		ll2[j] = t2->line[i];
+		j ++;
+	}
+	ret = calc_tri_distance(ll,il_t1,il_t2);
+	for ( i = 0 ; i < 2 ; i ++ ) {
+		s =  calc_tri_distance(ll1[i],0,0);
+		if ( s < 0 )
+			return -1;
+		ret += s;
+		s = calc_tri_distance(ll2[i],0,0);
+		if ( s < 0 )
+			return -1;
+		ret += s;
+	}
+	return ret;
+}
+
+
+void
+fitting_tri_distance(SELECT_SET * ss)
+{
+
+GM_LINE * ll,llt;
+double old_td,new_td;
+GM_TRIANGLE * t1,*t2;
+GM_TRIANGLE nt1,nt2;
+int i,j;
+int fitting_flag;
+int il_t1,il_t2;
+	
+ss_printf("fitting-------\n");
+	
+	for ( ll = ss->line ; ll ; ll = ll->next );
+	
+retry:
+	fitting_flag = 0;
+
+
+	for ( ll = ss->line ; ll ; ll= ll->next ){
+
+		old_td = tri_distance_delta(ll,&il_t1,&il_t2);
+		if ( old_td < 0 )
+			continue;
+		t1 = ll->tri[0];
+		t2 = ll->tri[1];
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			if ( t1->point[i] == ll->point[0] )
+				continue;
+			if ( t1->point[i] == ll->point[1] )
+				continue;
+			break;
+		}
+		llt.point[0] = t1->point[i];
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			if ( t2->point[i] == ll->point[0] )
+				continue;
+			if ( t2->point[i] == ll->point[1] )
+				continue;
+			break;
+		}
+		llt.point[1] = t2->point[i];
+		if ( line_conflict(
+				llt.point[0],llt.point[1],
+				ll->point[0],ll->point[1]) >= 0 )
+			continue;
+		nt1.point[0] = llt.point[0];
+		nt1.point[1] = llt.point[1];
+		nt1.point[2] = ll->point[0];
+		
+		nt1.line[2] = &llt;
+		
+		nt2.point[0] = llt.point[0];
+		nt2.point[1] = llt.point[1];
+		nt2.point[2] = ll->point[1];
+
+		nt2.line[2] = &llt;
+
+		llt.tri[0] = &nt1;
+		llt.tri[1] = &nt2;
+
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			if ( t1->line[i] != ll ) {
+				if ( t1->line[i]->point[0] == ll->point[0] ||
+						t1->line[i]->point[1] == ll->point[0] ) {
+					nt1.line[0] = t1->line[i];
+				}
+				if ( t1->line[i]->point[0] == ll->point[1] ||
+						t1->line[i]->point[1] == ll->point[1] ) {
+					nt2.line[0] = t1->line[i];
+				}
+			}
+			if ( t2->line[i] != ll ) {
+				if ( t2->line[i]->point[0] == ll->point[0] ||
+						t2->line[i]->point[1] == ll->point[0] ) {
+					nt1.line[1] = t2->line[i];
+				}
+				if ( t2->line[i]->point[0] == ll->point[1] ||
+						t2->line[i]->point[1] == ll->point[1] ) {
+					nt2.line[1] = t2->line[i];
+				}
+			}
+		}
+		
+		if ( il_t1 >= 0 && il_t2 >= 0 ) {
+			new_td = tri_distance_delta(&llt,&il_t1,&il_t2);
+			
+			if ( il_t1 < 0 || il_t2 < 0 )
+				continue;
+			if ( new_td > old_td )
+				continue;
+		}
+		for ( i = 0 ; i < 3 ; i ++ ) {
+			t1->point[i] = nt1.point[i];
+			if ( nt1.line[i] == &llt )
+				t1->line[i] = ll;
+			else {
+				t1->line[i] = nt1.line[i];
+				for ( j = 0 ; j < 2 ; j ++ ) {
+					if ( t1->line[i]->tri[j] == t1 )
+						break;
+					if ( t1->line[i]->tri[j] == t2 )
+						break;
+				}
+				t1->line[i]->tri[j] = t1;
+			}
+			
+			t2->point[i] = nt2.point[i];
+			if ( nt2.line[i] == &llt )
+				t2->line[i] = ll;
+			else {
+				t2->line[i] = nt2.line[i];
+				for ( j = 0 ; j < 2 ; j ++ ) {
+					if ( t2->line[i]->tri[j] == t1 )
+						break;
+					if ( t2->line[i]->tri[j] == t2 )
+						break;
+				}
+				t2->line[i]->tri[j] = t2;
+			}
+		}
+		
+		for ( i = 0 ; i < 2 ; i ++ ) {
+			ll->point[i] = llt.point[i];
+		}
+		fitting_flag = 1;
+ss_printf("fitting optimize %lf\n",new_td - old_td);
+	}
+	if ( fitting_flag )
+		goto retry;
+}
+
+
 XL_SEXP *
 get_lisp_list(GM_TRIANGLE * tri)
 {
@@ -704,6 +1002,7 @@ char buf[3][10];
 				continue;
 			p1 = tri->point[i];
 			p1->name = name++;
+//ss_printf("NAME %p %i\n",p1,p1->name);
 			sprintf(buf[0],"%i",p1->name);
 			r1 = list(
 				n_get_symbol("point-map"),
@@ -746,6 +1045,7 @@ XL_SEXP * ret;
 	ss.tri = 0;
 	ss.line = 0;
 	check_conflict(&ss,tri);
+	fitting_tri_distance(&ss);
 	ret = get_lisp_list(ss.tri);
 	free_gm_triangle(ss.tri);
 	free_gm_line(ss.line);
