@@ -1348,10 +1348,11 @@ ss_printf("OPT START\n");
 	w->center.y *= 0.5;
 	len  = 0;
 	pitch = ((r.br.x - r.tl.x) + (r.br.y - r.tl.y))/2;
-	w->radius = pitch*20;
+	w->radius = pitch*w->_radius;
 	w->max_dist = pitch*2;
 	w->dist = 0;
 	w->dist_cnt = 0;
+ss_printf("RADIUS = %f\n",w->radius);
 
 	fd = fopen("points.txt","r+");
 	if ( fd == 0 ) {
@@ -1631,12 +1632,18 @@ XL_SEXP * el;
 XL_SEXP * d;
 L_CHAR fh;
 int tin_mode;
+L_CHAR * radius;
 
 	ret = 0;
 	memset(&w,0,sizeof(w));
 
 	w.target_pitch = DEFAULT_TARGET_PITCH;
 
+	radius = get_sf_attribute(sf,l_string(std_cm,"radius"));
+	if ( radius == 0 )
+		w._radius = 20;
+	else	w._radius = atoi(n_string(std_cm,radius));
+
 	src = get_sf_attribute(sf,l_string(std_cm,"src"));
 	if ( src == 0 ) {
 		ret = n_get_string("src attribute is required");
