@@ -24,6 +24,7 @@
 #include	"xl_zlib.h"
 #include	"memory_routine.h"
 #include	"simple_alloc.h"
+#include	"geo.h"
 
 void
 check_mem_list(char*);
@@ -572,42 +573,6 @@ int ret;
 
 /* TYPE INTEGER64 */
 
-INTEGER64
-ddmmss_int(INTEGER64 d)
-{
-INTEGER64 ret;
-int sign;
-	if ( d >= 0 )
-		sign = 1;
-	else {
-		d = -d;
-		sign = -1;
-	}
-	ret = d % 60;
-	d = d/60;
-	ret += (d % 60)*60;
-	d = d/60;
-	ret += d * 3600;
-	return ret*sign;
-}
-
-double
-ddmmss_float(double d)
-{
-double _d;
-int sign;
-INTEGER64 _i;
-	if ( d >= 0 )
-		sign = 1;
-	else {
-		sign = -1;
-		d = -d;
-	}
-	_i = d;
-	_d = d - _i;
-	return (ddmmss_int(_i) + _d)*sign;
-}
-
 int
 fd_initial_int(IP_FIELD * target,void * _d,void * w,int flag)
 {
@@ -2260,6 +2225,8 @@ int md;
 	for ( p = b->plot ; p ; p = p->next ) {
 		for ( q = p->next ; q ; q = q->next ) {
 			md = get_distance(m,p,q);
+			if ( md == 0 )
+				continue;
 			if ( p->min_direction < 0 || p->min_direction > md )
 				p->min_direction = md;
 			if ( q->min_direction < 0 || q->min_direction > md )
@@ -2286,6 +2253,8 @@ int md,d;
 		q = p->prev;
 		for ( ; q ; q = q->prev ) {
 			md = get_distance(m,p,q);
+			if ( md == 0 )
+				continue;
 			if ( p->min_direction < 0 || p->min_direction > md )
 				p->min_direction = md;
 			if ( q->min_direction < 0 || q->min_direction > md )
@@ -2299,6 +2268,8 @@ int md,d;
 		q = p->next;
 		for ( ; q ; q = q->next ) {
 			md = get_distance(m,p,q);
+			if ( md == 0 )
+				continue;
 			if ( p->min_direction < 0 || p->min_direction > md )
 				p->min_direction = md;
 			if ( q->min_direction < 0 || q->min_direction > md )
