@@ -16,13 +16,24 @@
 
 **********************************************************************/
 
-
+#include <strings.h>
 #include "svg-main.h"
 #include "shape.h"
 #include "dbase.h"
 #include "svg.h"
 #include "change_endian.h"
 
+
+/*
+	stricmp
+*/
+
+int
+i_stricmp(char * a,char * b)
+{
+	return strcmp(a,b);
+}
+
 /*
 //======================================//
 //		global variables
@@ -413,7 +424,7 @@ int printPointM(FILE *fin , FILE *fout , int iID){
 */
 	struct Point pt;
 	struct Rect rc;
-	DOUBLE M;/*Not Used Now*/
+//	DOUBLE M;/*Not Used Now*/
 	
 	fread(&pt , SIZEOF_POINT , 1 , fin);
 	pt.X=convertLittleEndianDouble(pt.X);
@@ -452,9 +463,9 @@ int printPolyLineM(FILE *fin , FILE *fout , int iID){
 	INT iNumParts;
 	INT iNumPoints;
 	INT *pParts;
-	DOUBLE Mmin; /* Not Used Now */
-	DOUBLE Mmax;/* Not Used Now */
-	DOUBLE *Marray;/* Not Used Now */
+//	DOUBLE Mmin; /* Not Used Now */
+//	DOUBLE Mmax;/* Not Used Now */
+//	DOUBLE *Marray;/* Not Used Now */
 	struct Point* pPoints;
 	
 	int i;
@@ -540,9 +551,9 @@ int printPolygonM(FILE *fin , FILE *fout , int iID){
 	INT iNumParts;
 	INT iNumPoints;
 	INT *pParts;
-	DOUBLE Mmin;/* Not Used Now */
-	DOUBLE Mmax;/* Not Used Now */
-	DOUBLE *Marray;/* Not Used Now */
+//	DOUBLE Mmin;/* Not Used Now */
+//	DOUBLE Mmax;/* Not Used Now */
+//	DOUBLE *Marray;/* Not Used Now */
 	struct Point* pPoints;
 	int i;
 	int j;
@@ -624,9 +635,9 @@ int printMultiPointM(FILE *fin , FILE *fout , int iID){
 //////
 */
 	INT iNumPoints;
-	DOUBLE Mmin;/* Not Used Now */
-	DOUBLE Mmax;/* Not Used Now */
-	DOUBLE *Marray;/* Not Used Now */
+//	DOUBLE Mmin;/* Not Used Now */
+//	DOUBLE Mmax;/* Not Used Now */
+//	DOUBLE *Marray;/* Not Used Now */
 	
 	struct Point pt;
 	struct Rect rc;
@@ -1052,7 +1063,7 @@ int parseIndex(const char *filename){
 	
 	g_pIndexRecords=(struct IndexRecord*)(malloc(sizeof(struct IndexRecord)*g_iRecordNum));
 	if(!g_pIndexRecords){
-		fprintf(stderr , "malloc fault.\n" , indexfile);
+		fprintf(stderr , "malloc fault. %s\n" , indexfile);
 		fclose(fp);
 		return 0;
 	}
@@ -1195,7 +1206,7 @@ int main(int argc, char* argv[]) {
 
 			/* remove "shp" extension name */
 			ext = strrchr(shape_filename, '.');
-			if(ext && (stricmp(ext, ".shp") == 0)){
+			if(ext && (i_stricmp(ext, ".shp") == 0)){
 				shape_filename[strlen(shape_filename)-4] = '\0';
 			}
 		}
