@@ -314,6 +314,8 @@ free_HTTP_info(HTTP_INFO * info)
 {
 	if ( info->dir )
 		d_f_ree(info->dir);
+	if ( info->dir_org )
+		d_f_ree(info->dir_org);
 	if ( info->method )
 		d_f_ree(info->method);
 }
@@ -378,9 +380,11 @@ scan_HTTP(HTTP_INFO * info,STREAM * con,int flag)
 {
 GET_BUF * ret;
 char * v, * r;
+char * pp;
 	info->http_ver = info->http_rev = 0;
 	info->method = 0;
 	info->dir = 0;
+	info->dir_org = 0;
 	info->content_length = -1;
 	info->err = 200;
 	info->flags = 0;
@@ -403,7 +407,26 @@ char * v, * r;
 		info->http_rev = 9;
 		return 0;
 	}
-	info->dir = ret->str;
+	info->dir_org = ret->str;
+	for ( pp = ret->str ; *pp ; pp ++ )
+		if ( *pp == '/' ) {
+			if ( pp[1] == '/' )
+				goto complete_url;
+		}
+	info->dir = copy_str(ret->str);
+	goto next1;
+complete_url:
+	pp += 2;
+	for ( ; *pp ; pp ++ )
+		if ( *pp == '/' )
+			break;
+	if ( *pp == 0 ) {
+		info->dir = copy_str("/");
+	}
+	else {
+		info->dir = copy_str(pp);
+	}
+next1:
 	ret->str = 0;
 	ret = step_GET_BUF(ret);
 	if ( ret == 0 ) {
