@@ -225,9 +225,12 @@ printf("CLOSE ZOMBIE ACCESS %i %i / %x\n",s->h.close_time,s->h.zonbie_access,s);
 				s->h.write_tid = get_tid();
 				s->h.write_in_time = get_xltime();
 			}
-			unlock_task(stream_lock,"s_close");
-			_ret = (*tbl->write)(s,buf,rbyte);
-			lock_task(stream_lock);
+			_ret = 0;
+			if ( rbyte ) {
+				unlock_task(stream_lock,"s_close");
+				_ret = (*tbl->write)(s,buf,rbyte);
+				lock_task(stream_lock);
+			}
 			s->h.write_tid = 0;
 			s->h.write_in_time = 0;
 			calc_checksum(s,buf,_ret,0);
