@@ -252,12 +252,15 @@ void
 s_set_write_abort(STREAM * s,int type,int interval)
 {
 	lock_task(stream_lock);
+	if ( interval < 0 )
+		goto end;
 	s->h.write_abort_type = type;
 	s->h.write_abort_interval = interval;
 	if ( s_write_abort_task_flag == 0 ) {
 		s_write_abort_task_flag = 1;
 		create_task((void(*)(TKEY))s_write_abort_task,0,PRI_WRITE_BUF);
 	}
+end:
 	unlock_task(stream_lock,"s_set_write_abort");
 }
 
