@@ -37,10 +37,10 @@ int i;
 			break;
 		if ( d->d_name[0] == '.' )
 			continue;
-		closedir(dd);
+		secure_closedir(dd);
 		return;
 	}
-	closedir(dd);
+	secure_closedir(dd);
 	u_unlink(n_string(std_cm,dir));
 	dir_path = ll_copy_str(dir);
 	for ( i = l_strlen(dir)-1 ; i >= 0 && dir_path[i] != '/' ; i -- );
