@@ -19,6 +19,7 @@
 #define SEQUENCE_RESOLVE	1
 /*
 #define RESOLVE_DEBUG
+#define RESOLVE_DEBUG_2
 */
 
 #include	<stdio.h>
@@ -147,6 +148,21 @@ RESOLVE_QUEUE_HEADER * h;
 	return 0;
 }
 
+int
+_aboart_check_queue()
+{
+RESOLVE_QUEUE * q;
+int pri;
+RESOLVE_QUEUE_HEADER * h;
+	for ( pri = 0 ; pri < 2 ; pri ++ ) {
+		h = &resolve_que_header[pri];
+		for ( q = h->head ; q ; q = q->next )
+			if ( q->abort_flag )
+				return 0;
+	}
+	return -1;
+}
+
 
 void
 aboat_resolve_request()
@@ -160,6 +176,10 @@ void * tid;
 		if ( func )
 			(*func)(tid);
 	}
+	else {
+		if ( _aboart_check_queue() < 0 )
+			aboat_resolve_flag = 0;
+	}
 }
 
 void
@@ -252,6 +272,7 @@ ss_printf("entry-rs RQ_IDLE-4 %i -- %p\n",get_tid(),rq);
 	_insert_resolve_queue(rq);
 	_wakeup_resolve_thread();
 	for ( ; rq->status != RQ_RUN ; ) {
+		rq->abort_flag = 0;
 		_wakeup_resolve_thread();
 		sleep_task((int)rq,resolve_lock2);
 		lock_task(resolve_lock2);
@@ -335,9 +356,18 @@ int i;
 	for ( ret = resolv_cache ; ret ;
 			prev_cache = &ret->next,
 			ret = ret->next ) {
+#ifdef RESOLVE_DEBUG_2
+ss_printf("_search_host_entry_byaddr %p\n",ret);
+#endif
 		for ( i = 0 ; i < ret->ips_length ; i ++ ) {
+#ifdef RESOLVE_DEBUG_2
+ss_printf("_search_host_entry_byaddr %i %i\n",ret->ips[i].size,ip.size);
+#endif
 			if ( ret->ips[i].size != ip.size )
 				continue;
+#ifdef RESOLVE_DEBUG_2
+ss_printf("_search_host_entry_byaddr %x %x\n",(int)ret->ips[i].d.v4,(int)ip.d.v4);
+#endif
 			if ( memcmp(&ret->ips[i].d,&ip.d,ip.size) )
 				continue;
 			return ret;
@@ -399,6 +429,9 @@ del:
 void
 _insert_host_entry(HOST_ENTRY * he)
 {
+#ifdef RESOLVE_DEBUG_2
+ss_printf("_isnert_host_entry %p\n",he);
+#endif
 	he->next = resolv_cache;
 	resolv_cache = he;
 	prev_cache = 0;
@@ -690,14 +723,28 @@ HOST_ENTRY * ret, *new_ret;
 unsigned int t;
 RESOLVE_QUEUE rq;
 
-#ifdef RESOLVE_DEBUG
-ss_printf("r_get_hostbyaddr :: %x\n",a.d.v4);
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr :: %x %i\n",a.d.v4,a.size);
 #endif
 
+	switch ( a.type ) {
+	case HAT_V4:
+		break;
+	case HAT_XLPROX_V4:
+		a.d.v4 = a.d.xp_v4.v4;
+		a.type = HAT_V4;
+		a.size = sizeof(a.d.v4);
+		break;
+	default:
+		er_panic("r_gethostbyaddr(1)");
+	}
 
 	lock_task(resolve_lock2);
 retry2:
 	ret = _search_host_entry_byaddr(a);
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-0 %p\n",ret);
+#endif
 	switch ( _return_host_entry(ret,0,&a) ) {
 	case RHE_OK:
 		t = get_xltime();
@@ -713,9 +760,15 @@ retry2:
 retry:
 	unlock_task(resolve_lock2,"r_get_hostbyaddr");
 
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-1\n");
+#endif
 	if ( SEQUENCE_RESOLVE )
 		ret = resolve_request(&a,0);
 	else	ret = intr_gethostbyaddr_rr(a);
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-2 %p\n",ret);
+#endif
 
 	lock_task(resolve_lock2);
 	if ( _exit_resolve_call(&rq) < 0 )
@@ -725,6 +778,9 @@ retry:
 
 	t = get_xltime();
 	if ( ret ) {
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-3 %p\n",ret);
+#endif
 		_host_entry_regulation(ret);
 		new_ret = _replace_host_entry(ret);
 		if ( new_ret != ret ) {
@@ -734,6 +790,9 @@ retry:
 		ret->timer = 0;
 	}
 	else {
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-4\n");
+#endif
 		ret = _err_host_entry(0,&a);
 		new_ret = _replace_host_entry(ret);
 		if ( new_ret != ret ) {
@@ -760,6 +819,9 @@ ok:
 		else	ret->access = t;
 	}
 	unlock_task(resolve_lock2,"r_gethostbyaddr");
+#ifdef RESOLVE_DEBUG_2
+ss_printf("r_get_hostbyaddr-4\5\n");
+#endif
 	return ret;
 }
 
