@@ -54,7 +54,7 @@ int t;
 void
 exit_tick()
 {
-	create_task(timeout_exit_task,0,0);
+	create_task((void(*)(TKEY))timeout_exit_task,0,0);
 }
 
 void
