@@ -1,4 +1,4 @@
-/* ver.B.b17.10(BLAZE) */
+/* ver.B.b17.12(BLAZE) */
 
 
 #include "version.h"
@@ -6,10 +6,10 @@
 
 VERSION ap_version = {
 	"AP.code",
-	"kiban2matrix",
+	"addrdb",
 	"(C) 2000-2008 Hirohisa Mori and GLOBALBASE Project",
-	"ver.B.b17.10(BLAZE)",
-	2008,10,25,
+	"ver.B.b17.12(BLAZE)",
+	2009,7,30,
 	0,
 	"convert from Kiban to Matrix ",
 };
