@@ -1,4 +1,4 @@
-/* ver.B.b17(BLAZE) */
+/* ver.B.b17.03(BLAZE) */
 
 
 #include "version.h"
@@ -7,9 +7,9 @@
 VERSION ap_version = {
 	"AP.code",
 	"nig2svg",
-	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
-	"ver.B.b17(BLAZE)",
-	2008,1,11,
+	"(C) 2000-2008 Hirohisa Mori and GLOBALBASE Project",
+	"ver.B.b17.03(BLAZE)",
+	2008,7,17,
 	0,
 	"nigmas to svg format converter ",
 };
