@@ -62,6 +62,8 @@ XL_SEXP *
 vobj_load_warp_point_menu(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
 XL_SEXP *
 gb_trackback(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
+XL_SEXP *
+gb_frame_goto_point(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf);
 
 void
 init_vobj_VgbFlameStandard(XLISP_ENV *env)
@@ -72,6 +74,8 @@ init_vobj_VgbFlameStandard(XLISP_ENV *env)
 		get_func_prim((XL_SEXP*(*)())vobj_load_warp_point_menu,FO_APPLICATIVE,0,1,2));
 	set_env(gblisp_top_env0,l_string(std_cm,"trackback"),
 		get_func_prim((XL_SEXP*(*)())gb_trackback,FO_NORMAL,0,2,2));
+	set_env(gblisp_top_env0,l_string(std_cm,"frame-goto-point"),
+		get_func_prim((XL_SEXP*(*)())gb_frame_goto_point,FO_APPLICATIVE,0,5,5));
 
 
 
@@ -224,7 +228,7 @@ L_CHAR * d;
 		else if ( l_strcmp(d,l_string(std_cm,"Remote")) == 0 )
 			sts->mode = SW_MODE_REMOTE;
 		else {
-			ret = "flame.switch.Mode";
+			ret = (char*)"flame.switch.Mode";
 			goto err;
 		}
 		(*flags) |= VSF_FLAME_S_MODE;
@@ -250,7 +254,7 @@ VgbFlame_get_flame_from_sf(
 	XL_SEXP * arg,
 	VObject::FreeList **free_list)
 {
-char * ret;
+const char * ret;
 XL_SEXP * _ret;
 L_CHAR * d;
 	*flags = 0;
@@ -549,7 +553,7 @@ L_CHAR * d;
 
 	return 0;
 err:
-	return ret;
+	return (char*)ret;
 }
 
 char *
@@ -560,7 +564,7 @@ VgbFlame_get_flame_radar_from_sf(
 	XL_SYM_FIELD * sf)
 {
 L_CHAR * d;
-char * ret;
+const char * ret;
 XL_SEXP * _q;
 	*flags = 0;
 	ret = 0;
@@ -608,7 +612,7 @@ XL_SEXP * _q;
 	}
 	return 0;
 err:
-	return ret;
+	return (char*)ret;
 }
 
 void
@@ -943,13 +947,44 @@ XL_SEXP * inp,*sym;
 XL_SEXP * ret;
 RADAR_CACHE * rc_ptr;
 WARP_POINT * wp;
-char * err;
+const char * err;
+L_CHAR * polling;
+int _ret;
+int mode;
+I_POINT ptr;
+INTEGER64 tim;
 
 ss_printf("TRACKBACK\n");
 	inp = get_el(s,1);
+	polling = get_sf_attribute(sf,l_string(std_cm,"polling"));
+	if ( polling && l_strcmp(polling,l_string(std_cm,"on")) == 0 ) {
+ss_printf("TRACKBACK ==== POLLING\n");
+		rc_ptr = get_sf_rc_ptr(env,sf);
+		err = "polling mode flags";
+		if ( get_type(inp) != XLT_INTEGER )
+			goto type_missmatch;
+		_ret = rc_get_mouse_mode(rc_ptr,&mode,&ptr,&tim,inp->integer.data,1);
+		if ( _ret < 0 ) {
+			return get_error(
+				s->h.file,
+				s->h.line,
+				XLE_PROTO_CLOSED,
+				l_string(std_cm,"trackback"),
+				n_get_string("polling closed"));
+		}
+		return List(
+			n_get_symbol("status"),
+			get_integer(mode,0),
+			List(	n_get_symbol("point"),
+				get_integer(ptr.x,0),
+				get_integer(ptr.y,0),
+				-1),
+			get_integer(tim,l_string(std_cm,"sec")),
+			-1);
+	}
 	switch ( get_type(inp) ) {
 	case XLT_STRING:
-		rc_ptr = get_sf_rc_ptr(sf);
+		rc_ptr = get_sf_rc_ptr(env,sf);
 		if ( rc_trackback(&ret,rc_ptr,inp->string.data) < 0 ) {
 			if ( get_type(ret) == XLT_ERROR )
 				return ret;
@@ -972,7 +1007,7 @@ ss_printf("TRACKBACK\n");
 				err = "trackback warp-point type missmatch";
 				goto type_missmatch;
 			}
-			rc_ptr = get_sf_rc_ptr(sf);
+			rc_ptr = get_sf_rc_ptr(env,sf);
 			if ( rc_ptr == 0 ) {
 				return get_error(
 					s->h.file,
@@ -1005,6 +1040,119 @@ type_missmatch:
 }
 
 
+XL_SEXP *
+gb_frame_goto_point(XLISP_ENV * env,XL_SEXP * s,XLISP_ENV * a,XL_SYM_FIELD * sf)
+{
+RADAR_CACHE * rc_ptr;
+XL_SEXP * url;
+XL_SEXP * _ptr;
+XL_SEXP * _ptr_x,*_ptr_y;
+XL_SEXP * _rotate;
+XL_SEXP * _reso;
+const char * err;
+int ret;
+
+GB_POINT ptr;
+double rotate;
+double reso;
+int flags = 0;
+	url = get_el(s,1);
+	_ptr = get_el(s,2);
+	_rotate = get_el(s,3);
+	_reso = get_el(s,4);
+//ss_printf("frame-goto-point\n");
+	err = "url";
+	if ( get_type(url) != XLT_STRING )
+		goto type_missmatch;
+	err = "point";
+	switch ( get_type(_ptr) ) {
+	case XLT_NULL:
+		flags |= GP_IGN_PTR;
+		ptr.x = ptr.y = 0;
+		goto next1;
+	case XLT_PAIR:
+		break;
+	default:
+		goto type_missmatch;
+	}
+	if ( list_length(_ptr) != 2 )
+		goto type_missmatch;
+	_ptr_x = get_el(_ptr,0);
+	_ptr_y = get_el(_ptr,1);
+	switch ( get_type(_ptr_x) ) {
+	case XLT_NULL:
+		flags |= GP_IGN_PTR;
+		ptr.x = 0;
+		break;
+	case XLT_INTEGER:
+		ptr.x = _ptr_x->integer.data;
+		break;
+	case XLT_FLOAT:
+		ptr.x = _ptr_x->floating.data;
+		break;
+	default:
+		err = "point-x";
+		goto type_missmatch;
+	}
+	switch ( get_type(_ptr_y) ) {
+	case XLT_NULL:
+		flags |= GP_IGN_PTR;
+		ptr.y = 0;
+		break;
+	case XLT_INTEGER:
+		ptr.y = _ptr_y->integer.data;
+		break;
+	case XLT_FLOAT:
+		ptr.y = _ptr_y->floating.data;
+		break;
+	default:
+		err = "point-y";
+		goto type_missmatch;
+	}
+next1:
+	err = "rotate";
+	switch ( get_type(_rotate) ) {
+	case XLT_NULL:
+		flags |= GP_IGN_ROTATE;
+		rotate = 0;
+		break;
+	case XLT_INTEGER:
+		rotate = _rotate->integer.data;
+		break;
+	case XLT_FLOAT:
+		rotate = _rotate->floating.data;
+		break;
+	default:
+		goto type_missmatch;
+	}
+	err = "reso";
+	switch ( get_type(_reso) ) {
+	case XLT_NULL:
+		flags |= GP_IGN_RESO;
+		reso = 0;
+		break;
+	case XLT_INTEGER:
+		reso = _reso->integer.data;
+		break;
+	case XLT_FLOAT:
+		reso = _reso->floating.data;
+		break;
+	default:
+		goto type_missmatch;
+	}
+	
+	rc_ptr = get_sf_rc_ptr(env,sf);
+	ret = wf_goto_point(rc_ptr->gf,url->string.data,ptr,rotate,reso,flags);
+	return get_integer(ret,0);
+type_missmatch:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_SEMANTICS_TYPE_MISSMATCH,
+		l_string(std_cm,"trackback"),
+		n_get_string(err));
+}
+
 } // extern "C"
 
 
