@@ -40,10 +40,9 @@ VEditable::focus_event(bool in)
 		focused_object = this;
 	else
 		focused_object = 0;
-ss_printf("focus_event\n");
 	if ( focused_event_handler )
-		vq_insert_callback(dynamic_cast<VObject*>(this),
-			focused_event_handler, focused_eh_arg, &in, sizeof(in),"focus");
+		vq_insert_callback_machine(dynamic_cast<VObject*>(this),
+			focused_event_handler, focused_eh_arg, &in, sizeof(in),"focus",0);
 }
 
 void
