@@ -81,8 +81,8 @@ VTreeView::select_event(VTreeView *view, Selection* sel)
 	delete view->selection;
 	view->selection = sel;
 	if ( view->select_event_handler )
-		vq_insert_callback(view, view->select_event_handler,
-			view->user_arg_select, 0, 0,0);
+		vq_insert_callback_machine(view, view->select_event_handler,
+			view->user_arg_select, 0, 0,0,0);
 }
 
 void
@@ -100,8 +100,8 @@ VTreeView::row_edit_event(VTreeView *view, RowEdit *re)
 				(L_CHAR*)re->data,(char*)re->m_data,re->m_data_len);
 	view->row_edit_event_done(re);
 	if ( view->row_edit_event_handler )
-		vq_insert_callback(view, view->row_edit_event_handler,
-				view->user_arg_row_edit, re, sizeof(RowEdit),0);
+		vq_insert_callback_machine(view, view->row_edit_event_handler,
+				view->user_arg_row_edit, re, sizeof(RowEdit),0,0);
 }
 
 void
