@@ -59,11 +59,11 @@ default_VxlEditLineStatus(VxlEditLineStatus * s)
 	s->writing_direction = VSD_V_L2R;
 	s->file_convert = VEL_FC_NONE;
 	s->data = 0;
-	s->add_descriptor = nl_copy_str(std_cm,"Add");
-	s->del_descriptor = nl_copy_str(std_cm,"Delete");
-	s->bro_descriptor = nl_copy_str(std_cm,"Browse");
-	s->ok_descriptor = nl_copy_str(std_cm,"OK");
-	s->tree_view_title = nl_copy_str(std_cm,"Data");
+	s->add_descriptor = nl_copy_str(std_cm,(char*)"Add");
+	s->del_descriptor = nl_copy_str(std_cm,(char*)"Delete");
+	s->bro_descriptor = nl_copy_str(std_cm,(char*)"Browse");
+	s->ok_descriptor = nl_copy_str(std_cm,(char*)"OK");
+	s->tree_view_title = nl_copy_str(std_cm,(char*)"Data");
 	s->max_len = 300;
 	s->min_len = 20;
 	s->col_len = 300;
@@ -209,7 +209,7 @@ VTreeView * tv;
 VExError err;
 VObjectStatus ss;
 VTreeNode node(1);
-	if ( lock_d(__FILE__,__LINE__) )
+	if ( lock_d((char*)__FILE__,__LINE__) )
 		return;
 	if ( (et = _obj_arg.edit_text) == 0 )
 		goto end;
@@ -238,7 +238,7 @@ void
 VxlEditLine::_push_del_btn()
 {
 VTreeView * tv;
-	if ( lock_d(__FILE__,__LINE__) )
+	if ( lock_d((char*)__FILE__,__LINE__) )
 		return;
 	tv = _obj_arg.tree_view;
 	VTreeView::Selection *sel = tv->get_selection();
