@@ -153,7 +153,7 @@ VxlText::_s_write(STREAM * s,void * data,int len)
 {
 int _len;
 	_len = len/sizeof(L_CHAR);
-	if ( lock_d(__FILE__,__LINE__) )
+	if ( lock_d((char*)__FILE__,__LINE__) )
 		return -1;
 	tx_curret = tr_insert_string(
 		tx_sq,
@@ -172,7 +172,7 @@ int
 VxlText::_s_read(STREAM * s,void * data,int len)
 {
 int _len;
-	if ( lock_d(__FILE__,__LINE__) )
+	if ( lock_d((char*)__FILE__,__LINE__) )
 		return -1;
 	_len = len/sizeof(L_CHAR);
 	_len = tr_copyout(tx_sq,tx_curret,(L_CHAR*)data,_len);
@@ -618,7 +618,7 @@ VImage * img;
 int h,w;
 PIC_ELEMENT * pe;
 VObjectStatus s;
-	if ( lock_d(__FILE__,__LINE__) )
+	if ( lock_d((char*)__FILE__,__LINE__) )
 		return;
 	sp_get_sequence_pic(&pi,tx_sq);
 
@@ -677,7 +677,7 @@ VxlText_get_xltext_from_sf(
 	XL_SYM_FIELD * sf)
 {
 L_CHAR * d;
-char * ret;
+const char * ret;
 	*flags = 0;
 	ret = 0;
 	xsts->battr.max_line_pixels = -1;
@@ -691,7 +691,7 @@ char * ret;
 			xsts->algorism = VXLT_A_TEXT;
 		else {
 			ret = "algorism";
-			return ret;
+			return (char*)ret;
 		}
 		(*flags) |= VSF_XLTEXT_ALGORISM;
 	}
@@ -720,7 +720,7 @@ char * ret;
 				= TRT_CAPITA_BASIS;
 		else {
 			ret = "LineAttr.Align";
-			return ret;
+			return (char*)ret;
 		}
 		(*flags) |= VSF_XLTEXT_BATTR;
 		xsts->battr.default_lattr.flags |= TRLF_ALIGN;	
@@ -738,7 +738,7 @@ char * ret;
 			xsts->battr.default_lattr.default_dir = VSD_H_R2L;
 		else {
 			ret = "LineAttr.DefaultDir";
-			return ret;
+			return (char*)ret;
 		}
 		(*flags) |= VSF_XLTEXT_BATTR;
 		xsts->battr.default_lattr.flags |= TRLF_DEFAULT_DIR;	
