@@ -38,9 +38,11 @@ submain(int argc,char ** argv)
 	init_favt();
 	init_favt64();
 
+	gc_push(0,0,"main");
 	init_function(gblisp_top_env0,gblisp_top_env1,argc,argv);
 	init_exsh_function(gblisp_top_env0,gblisp_top_env1);
 	init_gv_cpu(gblisp_top_env0);
+	gc_pop(0,0);
 	xl_setup_file(argc,argv);
 
 	return 0;
