@@ -558,6 +558,18 @@ L_CHAR * _s_path;
 			ret = eval(env,r);
 			if ( get_type(ret) == XLT_ERROR ) {
 				d_f_ree(access_filename);
+				for ( ; get_type(ss) == XLT_PAIR ; ) {
+					lock_parse();
+					lock_mem();
+					r = car(ss);
+					ss = cdr(ss);
+					gc_pop(0,0);
+					gc_push(0,0,"Load");
+					gc_set_nl(r,gc_gb_sexp);
+					gc_set_nl(ss,gc_gb_sexp);
+					unlock_mem();
+					unlock_parse("Load");
+				}
 				gc_pop(ret,gc_gb_sexp);
 				gc_pop(ret,gc_gb_sexp);
 				set_script_path(_s_path);
