@@ -322,7 +322,7 @@ PATH_PATTERN * pp,* pp1;
 		}
 		d_f_ree(buffer2);
 	}
-	closedir(dp);
+	secure_closedir(dp);
 	d_f_ree(buffer);
 	return pp;
 }
