@@ -29,6 +29,8 @@ init_function(XLISP_ENV * env0,XLISP_ENV * env1,int argc,char ** argv)
 	init_symbols(env0,env1);
 
 // NG
+	init_ThreadControl(env1);
+
 	init_While(env0);
 	init_For(env0);
 
@@ -208,4 +210,7 @@ init_function(XLISP_ENV * env0,XLISP_ENV * env1,int argc,char ** argv)
 
 	init_DefineEval(env0);
 	init_LaunchWWW(env0);
+
+	init_ForceGC(env0);
+
 }
