@@ -108,3 +108,50 @@ extern BINARY_TABLE div_tt[XLT_MAX][XLT_MAX];
 		get_el(s,2),
 		s->h.file,s->h.line);
 }
+
+
+XL_SEXP *
+gb_shift(XLISP_ENV * e,XL_SEXP * s,XLISP_ENV * aenv,XL_SYM_FIELD * sf)
+{
+XL_SEXP * a,*b;
+L_CHAR * dir;
+int _dir;
+	dir = get_sf_attribute(sf,l_string(std_cm,"dir"));
+	if ( dir == 0 )
+		_dir = 1;
+	else if ( l_strcmp(dir,l_string(std_cm,"left")) == 0 )
+		_dir = 1;
+	else if ( l_strcmp(dir,l_string(std_cm,"right")) == 0 )
+		_dir = 0;
+	else	goto inv_param;
+	a = get_el(s,1);
+	b = get_el(s,2);
+	if ( get_type(a) != XLT_INTEGER )
+		goto type_missmatch;
+	if ( get_type(b) != XLT_INTEGER )
+		goto type_missmatch;
+	if ( _dir )
+		return get_integer(a->integer.data<<b->integer.data,a->integer.unit);
+	else	return get_integer(a->integer.data>>b->integer.data,a->integer.unit);
+inv_param:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_PROTO_INV_PARAM,
+		l_string(std_cm,"shift"),
+		list(	n_get_string("invalid parameter"),
+			0));
+type_missmatch:
+	return get_error(
+		s->h.file,
+		s->h.line,
+		XLE_SEMANTICS_TYPE_MISSMATCH,
+		l_string(std_cm,"shift"),
+		list(	n_get_string("save:type missmatch"),
+			get_string(dir),
+			0));
+}
+
+
+
+
