@@ -35,7 +35,7 @@ XL_INTEGER * s;
 }
 
 XL_SEXP*
-n_get_integer(int num,char * unit)
+n_get_integer(int num,const char * unit)
 {
 	return get_integer(num,l_string(std_cm,unit));
 }
