@@ -69,6 +69,8 @@ int abs_malloc;
 
 MEM mem_header;
 int mem_tid,mem_cnt;
+char * mem_file;
+int mem_line;
 
 #ifdef SPEED_DEBUG
 #define S_MALLOC	s_alloc
@@ -89,7 +91,7 @@ minit()
 
 
 void
-lock_mem()
+d_lock_mem(char * __file,int __line)
 {
 int tid;
 	tid = get_tid();
@@ -98,6 +100,8 @@ int tid;
 		return;
 	}
 	lock_task(mem_lock);
+	mem_file = __file;
+	mem_line = __line;
 	mem_tid = tid;
 	mem_cnt = 1;
 }
@@ -112,6 +116,8 @@ int tid;
 	mem_cnt --;
 	if ( mem_cnt == 0 ) {
 		mem_tid = 0;
+		mem_file = 0;
+		mem_line = 0;
 		unlock_task(mem_lock,"unlock_mem");
 	}
 }
@@ -124,6 +130,7 @@ void * a;
 	S_FREE(a);
 }
 
+
 void *
 xx_mmalloc(unsigned long size,void (*gc_func)(),char * __file,int __line)
 {
@@ -132,6 +139,8 @@ int i;
 char * pt;
 MEM * m;
 
+
+check_mem_header(0,"malloc-1");
 	if ( dumy_mem == 0 ) {
 		dumy_mem = S_MALLOC(1000);
 		if ( dumy_mem == 0 )
@@ -141,6 +150,7 @@ MEM * m;
 		S_FREE(dumy_mem);
 		er_panic("no memory!!");
 	}
+check_mem_header(0,"malloc-2");
 	m->m_size = size;
 	m->m_flags = 0;
 	m->file = __file;
@@ -149,11 +159,17 @@ MEM * m;
 	pt = ret;
 	for ( i = 0 ; i < size ; i ++ )
 		*pt++ = 0;
+check_mem_header(0,"malloc-3");
 	lock_mem();
+check_mem_header(0,"malloc-4");
 	INSERT_MEM(&mem_header,m);
+check_mem_header(0,"malloc-5");
 	malloc_count += size;
+check_mem_header(0,"malloc-6");
 	gc_set_nl_non_check(ret,gc_func);
+check_mem_header(0,"malloc-7");
 	unlock_mem();
+check_mem_header(0,"malloc-8");
 	return ret;
 }
 
