@@ -592,7 +592,7 @@ pt_t pt_integer = {
 void
 _print_floating_lxh(S_PRINTF_SAT * fd,ERR_ENV * ee,XL_SEXP * s,int flags)
 {
-	_e_printf(fd,ee,"%lf",s->floating.data);
+	_e_printf(fd,ee,"%.16lf",s->floating.data);
 	if ( s->floating.unit )
 		_e_printf(fd,ee,"%ls ",s->floating.unit);
 	else  	_e_printf(fd,ee," ");
@@ -640,7 +640,9 @@ int size,ss;
 		pp = s->raw.data;
 		size = s->raw.size;
 		for ( ; size ; ) {
-			ss = size;
+			if ( size > 1000 )
+				ss = 1000;
+			else	ss = size;
 		retry:
 			er = s_write(fd->st,pp,ss);
 			if ( er < 0 ) {
@@ -758,7 +760,11 @@ INDENT ind;
 ERR_ENV ee;
 S_PRINTF_SAT sat;
 
-	new_spsat(&sat,fd);
+	if ( new_spsat(&sat,fd) < 0 ) {
+		if ( erp )
+			*erp = ESYS_INVAL;
+		return -1;
+	}
 
 	ee.er = 0;
 	if ( setjmp(ee.env) ) {
@@ -779,8 +785,7 @@ S_PRINTF_SAT sat;
 	else {
 		_print_sexp(&sat,&ee,s,flags,ind);
 	}
-	finish_spsat(&sat,erp);
-	return 0;
+	return finish_spsat(&sat,erp);
 }
 
 void
