@@ -358,7 +358,7 @@ ss_printf("HTTP %s %s\n",lst->info.method,lst->info.dir);
 */
 	if ( strcmp(lst->info.method,"GET") == 0 ) {
 		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
-		ret = exec_url(&lst->info,key->s);
+		ret = exec_url(&lst->info,key->s,xli);
 		if ( ret <= 1 )
 			return ret;
 		if ( strcmp(lst->info.dir,"/cgi-bin/download.cgi") == 0 ) {
@@ -375,7 +375,7 @@ ss_printf("HTTP %s %s\n",lst->info.method,lst->info.dir);
 	}
 	else {
 		del_tick_with_data((void(*)(int))timeout_stream,(int)lst->con);
-		ret = exec_url(&lst->info,key->s);
+		ret = exec_url(&lst->info,key->s,xli);
 		if ( ret <= 1 )
 			return ret;
 	}
