@@ -803,7 +803,7 @@ XL_SEXP * data,*t;
 			}
 		}
 	}
-	closedir(dd);
+	secure_closedir(dd);
 end1:	;
 	d_f_ree(buffer);
 	d_f_ree(filename);
