@@ -16,6 +16,10 @@
 **********************************************************************/
 
 
+#define STREAM_LIB
+//#define LIBRARY
+//#define S_FILE_LIBRARY
+
 #include	"memory_debug.h"
 #include	"lock_level.h"
 #include	"pri_level.h"
@@ -25,13 +29,16 @@
 #include	"xl.h"
 #include	"XLoHTTP.h"
 #include	"xlerror.h"
+#include	"client.h"
 
+#define WRITE_ABORT_INTERVAL	240
 
 typedef struct eu_list {
 	struct eu_list *	next;
 	int			ret;
 	STREAM *		st;
 	HTTP_INFO *		info;
+	XL_INTERPRETER *	xli;
 } EU_LIST;
 
 SEM ha_lock;
@@ -53,7 +60,7 @@ int output_server_header_by_info(STREAM * s,HTTP_INFO * info);
 void output_error_print(STREAM * s,HTTP_ERR * e,char * msg,XL_SEXP * s_msg);
 void _initialize_remote(HTTP_AGENT_LIST * a);
 void return_code(STREAM * st,HTTP_INFO * of,XL_SEXP * snd);
-int _exec_url(HTTP_INFO * info,STREAM * st);
+int _exec_url(HTTP_INFO * info,STREAM * st,XL_INTERPRETER * xli);
 EU_LIST *  _delete_eu_list();
 EU_LIST * delete_eu_list();
 void _insert_eu_list(EU_LIST * inp);
@@ -94,19 +101,23 @@ int len;
 HTTP_AGENT_LIST *
 insert_http_agent_list(
 	char * path,
+	int type,
 	XLISP_ENV * env,
 	L_CHAR* remote_url,
 	HTTP_AGENT_LIST * alias,
-	XL_SEXP * initialize)
+	XL_SEXP * initialize,
+	int timeout)
 {
 HTTP_AGENT_LIST * ret;
 	lock_task(ha_lock);
 	ret = d_alloc(sizeof(*ret));
 	memset(ret,0,sizeof(*ret));
 	ret->access_tid = 0;
+	ret->type = type;
 	ret->path = copy_str(path);
 	ret->env = env;
 	ret->next = ha_root;
+	ret->timeout = timeout;
 	if ( alias ) {
 		for ( ; alias->alias_list_next ; alias = alias->alias_list_next );
 		ret->alias_root = alias;
@@ -146,6 +157,8 @@ int len;
 			continue;
 		if ( path[len] == '?' )
 			break;
+		if ( ret->path[len-1] == '/' && ret->type == HAT_PROXY )
+			break;
 	}
 	unlock_task(ha_lock,"insert_http_agent_list");
 	return ret;
@@ -265,6 +278,10 @@ HTTP_AGENT_LIST * a_target;
 		a_target = aa->alias_root;
 	else	a_target = aa;
 
+	if ( aa->type == HAT_PROXY )
+		return;
+	if ( a_target->type == HAT_PROXY )
+		return;
 	if( aa->iid > 0 ) {
 		return;
 	}
@@ -595,8 +612,126 @@ int len;
 	return ret;
 }
 
+
+typedef struct do_proxy_close_t {
+	STREAM * st;
+	STREAM * con;
+} DO_PROXY_CLOSE_T;
+void
+do_proxy_close(int data)
+{
+DO_PROXY_CLOSE_T * t;
+	t = (DO_PROXY_CLOSE_T*)data;
+ss_printf("do_proxy_close\n");
+	s_close(t->st);
+	s_close(t->con);
+}
+
 int
-_exec_url(HTTP_INFO * info,STREAM * st)
+do_proxy(HTTP_AGENT_LIST * aa,HTTP_INFO * info,STREAM * st)
+{
+HTTP_INFO o_info;
+STREAM * con;
+int err;
+URL remote;
+char * buffer;
+DO_PROXY_CLOSE_T t;
+int er;
+char * str,*target;
+char * ptr;
+int size;
+
+	if ( strcmp(info->method,"GET") ) {
+		memset(&o_info,0,sizeof(o_info));
+		o_info.content_length = -1;
+		o_info.err2 = he503;
+		output_server_header_by_info(st,&o_info);
+		s_close(st);
+		return 0;
+	}
+	get_url2(&remote,aa->remote_url);
+	if ( remote.server == 0 ) {
+		memset(&o_info,0,sizeof(o_info));
+		o_info.content_length = -1;
+		o_info.err2 = he503;
+		output_server_header_by_info(st,&o_info);
+		s_close(st);
+		free_url(&remote);
+		return 0;
+	}
+	if ( remote.port == 0 )
+		remote.port = 80;
+	str = copy_str(&info->dir[strlen(aa->path)]);
+	target = d_alloc(strlen(str)+strlen(n_string(std_cm,aa->remote_url))+3);
+	strcpy(target,n_string(std_cm,aa->remote_url));
+	strcpy(&target[strlen(n_string(std_cm,aa->remote_url))],str);
+	d_f_ree(str);
+	
+	con = new_connection(&err,
+		n_string(std_cm,remote.server),
+		0,
+		remote.port,
+		0,0);
+	if ( con == 0 ) {
+		memset(&o_info,0,sizeof(o_info));
+		o_info.content_length = -1;
+		o_info.err2 = he503;
+		output_server_header_by_info(st,&o_info);
+		s_close(st);
+		free_url(&remote);
+		d_f_ree(target);
+		return 0;
+	}
+	s_printf(con,"%s %s HTTP/1.0\r\n",
+		info->method,target);
+	if ( info->content_type )
+		s_printf(con,"Content-Type: %s\r\n",info->content_type);
+	s_printf(con,"Host: %s:%i\r\n",remote.server,remote.port);
+	s_printf(con,"\r\n");
+	buffer = d_alloc(1000);
+	t.st = st;
+	t.con = con;
+//ss_printf("LOAD %x %x %i\n",t.st,t.con,con->file.fid);
+	s_set_write_abort(st,WAT_CLOSE,WRITE_ABORT_INTERVAL);
+	for ( ; ; ) {
+		new_tick(do_proxy_close,-WRITE_ABORT_INTERVAL,(int)&t);
+		er = s_read(con,buffer,1000);
+		if ( er <= 0 ) {
+ss_printf("CON END er=%i\n",er);
+			del_tick_with_data(do_proxy_close,(int)&t);
+			break;
+		}
+		del_tick_with_data(do_proxy_close,(int)&t);
+		size = er;
+		ptr = buffer;
+		for ( ; size ; ) {
+			er = s_write(st,ptr,size);
+			if ( er < 0 )
+				break;
+			if ( er == 0 ) {
+ss_printf("WRITE ER=0\n");
+				sleep_sec(1);
+			}
+			size -= er;
+			ptr += er;
+		}
+		if ( er < 0 )
+{
+ss_printf("ST END er=%i\n",er);
+			break;
+}
+	}
+ss_printf("END\n");
+	s_close(st);
+	s_close(con);
+	free_url(&remote);
+	d_f_ree(target);
+
+	return 0;
+}
+
+int
+_exec_url(HTTP_INFO * info,STREAM * st,XL_INTERPRETER * xli)
 {
 HTTP_AGENT_LIST * aa,* a_target;
 XL_SEXP * sym;
@@ -635,6 +770,10 @@ ss_printf("DIR(%s) = %s\n",info->method,_dir);
 		a_target = aa->alias_root;
 	else	a_target = aa;
 
+	if ( a_target->type == HAT_PROXY || aa->type == HAT_PROXY ) {
+		return do_proxy(a_target,info,st);
+	}
+
 	sym = n_get_symbol(info->method);
 	sprintf(buf,"%i",info->http_ver);
 	set_attribute(sym,
@@ -807,7 +946,7 @@ EU_LIST * eu;
 	for ( ; ; ) {
 		eu = delete_eu_list();
 		gc_push(0,0,"exec_url");
-		eu->ret = _exec_url(eu->info,eu->st);
+		eu->ret = _exec_url(eu->info,eu->st,eu->xli);
 		gc_pop(0,0);
 		wakeup_task((int)eu);
 	}
@@ -818,7 +957,7 @@ EU_LIST * eu;
 
 
 int
-exec_url(HTTP_INFO * info,STREAM * st)
+exec_url(HTTP_INFO * info,STREAM * st,XL_INTERPRETER * from_xli)
 {
 //EU_LIST eu;
 int ret;
@@ -831,7 +970,7 @@ XL_INTERPRETER * xli;
 	}
 
 	gc_push(0,0,"exec_url");
-	ret = _exec_url(info,st);
+	ret = _exec_url(info,st,from_xli);
 	gc_pop(0,0);
 
 /*
