@@ -162,6 +162,8 @@ XL_SEXP * xl_fetch_log();
 unsigned int last_log_ins_time;
 unsigned int last_log_del_time;
 
+int log_active_flag;
+
 void
 setup_value(XLISP_ENV * env0,char ** table,int max)
 {
@@ -886,12 +888,25 @@ XL_INTERPRETER * xli;
 	xli->a_type = XLA_SELF;
 	setup_i(xli);
 
+	lock_task(lock_log);
+	log_active_flag = 1;
+	unlock_task(lock_log,"");
 	for ( ; ; ) {
 		llpl_check(0);
 		ln = delete_queue(&log_queue,0,0,0);
 		if ( ln == 0 ) {
 			llpl_check(1);
+
+			lock_task(lock_log);
+			log_active_flag = 0;
+			wakeup_task((int)&log_active_flag);
+			unlock_task(lock_log,"");
+
 			ln = delete_queue(&log_queue,0,0,1);
+
+			lock_task(lock_log);
+			log_active_flag = 1;
+			unlock_task(lock_log,"");
 		}
 last_log_del_time = get_xltime();
 
@@ -1445,9 +1460,9 @@ int er;
 		}
 	}
 	if ( ip )
-		a->ip = inet_addr(n_string(std_cm,ip));
+		a->ip = inet_addr_xl(n_string(std_cm,ip));
 	if ( mask )
-		a->mask = inet_addr(n_string(std_cm,mask));
+		a->mask = inet_addr_xl(n_string(std_cm,mask));
 	if ( div_nos )
 		a->div_nos = atoi(n_string(std_cm,div_nos));
 	if ( size )
@@ -1609,7 +1624,7 @@ log_print_sexp(
 	int level,
 	int layer,
 	LOG_NODE_DATA * opt,
-	char * str,
+	const char * str,
 	XL_SEXP * s,
 	int flags)
 {
@@ -1644,3 +1659,15 @@ LOG_ACTION * a;
 	lc->action_list = a;
 	set_log_condition(lc);
 }
+
+void
+sync_log()
+{
+	lock_task(lock_log);
+	for ( ; log_active_flag && log_queue.total_cnt ; ) {
+		sleep_task((int)&log_active_flag,lock_log);
+		lock_task(lock_log);
+	}
+	unlock_task(lock_log,"");
+}
+
