@@ -130,7 +130,7 @@ _save_file_stage(STREAM * st,int ind,P_STAGE * ps)
 	else	s_printf(st,"%sSTAGE(%i) %i\n",
 			_get_ind(ind),ps->dont_remove_sub_progressive,ps->id);
 	if ( ps->message )
-		s_printf(st,"%s%i %ls\n",_get_ind(ind+1),ps->message);
+		s_printf(st,"%s %ls\n",_get_ind(ind+1),ps->message);
 	if ( ps->start_time == 0 )
 		s_printf(st,"%sNot Ready\n",_get_ind(ind+1));
 	else {
