@@ -442,15 +442,36 @@ remote_session_http(
 	int session_lock_enable,
 	REMOTE_SESSION_OPT * opt)
 {
-	for ( ; get_type(cmd) == XLT_PAIR ; ) {
-		if ( get_type(cdr(cmd)) == XLT_NULL ) {
-			return one_session(u,car(cmd),opt,f,ln,0);
-		}
-		else {
-			one_session(u,car(cmd),opt,f,ln,1);
+XL_SEXP * ret;
+int mode;
+	if ( native_proxy_session == 0 ) {
+	direct:
+		for ( ; get_type(cmd) == XLT_PAIR ; ) {
+			if ( get_type(cdr(cmd)) == XLT_NULL ) {
+				return one_session(u,car(cmd),opt,f,ln,0);
+			}
+			else {
+				one_session(u,car(cmd),opt,f,ln,1);
+			}
 		}
+		return 0;
 	}
-	return 0;
+	ret = native_proxy_send_session(
+		&mode,
+		env,
+		id,
+		u,
+		_a_agent,
+		_a_login_mode,
+		_a_center_cmd,
+		cmd,
+		f,
+		ln,
+		session_lock_enable,
+		opt);
+	if ( mode == NPS_DIRECT )
+		goto direct;
+	return ret;
 }
 
 
