@@ -26,6 +26,9 @@ foreach a (packages/*/*)
 end
 
 rm packages/skeleton/old/main.html
+rm packages/skeleton/old/gblib_old.js
 cp -rf except/skeleton.old.main.html packages/skeleton/old/main.html
+cp -rf except/gblib_old.js packages/skeleton/old/gblib.js
+chmod 0755 packages/skeleton/old/gblib.js
 
 popd
